ShellCompleter class

Bridges the completion package to an Artisanal CommandRunner.

Use ShellCompleter.generate to produce a shell completion script for your executable, and shellCompleter on CommandRunner to enable automatic tab-completion at runtime.

Constructors

ShellCompleter(ArgParser _parser)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete(List<String> args, String compLine, int compPoint) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(String executableName) String
generateAll(List<String> executableNames) String