BarChartProps class final

Props for bar charts.

Inheritance

Constructors

BarChartProps({String? id, required int width, required int height, String? title, String? titleColor, String? backgroundColor, ChartBorderStyle? borderStyle, String? borderColor, ChartMargins? margins, AxisOptions? xAxis, AxisOptions? yAxis, GridOptions? grid, LegendOptions? legend, List<String>? colors, required List<DataSeries> series, List<String>? labels, String? barChar, ChartOrientation? orientation, bool? grouped, int? barWidth, int? gap})
const

Properties

backgroundColor → String?
finalinherited
barChar → String?
final
barWidth → int?
final
borderColor → String?
finalinherited
borderStyle → ChartBorderStyle?
finalinherited
colors → List<String>?
finalinherited
gap → int?
final
grid → GridOptions?
finalinherited
grouped → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
finalinherited
id → String?
finalinherited
labels → List<String>?
final
legend → LegendOptions?
finalinherited
margins → ChartMargins?
finalinherited
orientation → ChartOrientation?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → List<DataSeries>
final
title → String?
finalinherited
titleColor → String?
finalinherited
width → int
finalinherited
xAxis → AxisOptions?
finalinherited
yAxis → AxisOptions?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited