CodeLanguageProfile class final

Inheritance

Constructors

CodeLanguageProfile({required String lineCommentPrefix, CodeBlockCommentDelimiters? blockCommentDelimiters, Map<String, String> autoPairs = defaultCodeAutoPairs, Map<String, String> closingToOpening = defaultCodeClosingToOpening, String languageId = 'default', List<String> aliases = const <String>[]})
const

Properties

aliases → List<String>
Alternate identifiers that resolve to this adapter (e.g. py, yml).
final
autoPairs → Map<String, String>
final
blockCommentDelimiters → CodeBlockCommentDelimiters?
final
closingToOpening → Map<String, String>
final
comments → EditorCommentConfig
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
languageId → String
Stable language identifier, e.g. dart, python, markdown.
final
lineCommentPrefix → String
final
pairs → EditorPairConfig
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extraIndentForNewline(EditorIndentContext context) → String
Optional extra indent string (beyond EditorIndentContext.baseIndent) for a newline at context. Returns '' for no extra indent.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldIncreaseIndent(EditorIndentContext context) → bool
Whether a newline after context.lineBeforeCursor should add one indent level. The default covers C-style {[( openers; languages with extra rules (Python/YAML :) override this.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited