EditorCompletionKind enum

Broad category used to decorate and rank a completion.

Inheritance
Available extensions

Values

text → const EditorCompletionKind
method → const EditorCompletionKind
function → const EditorCompletionKind
constructor → const EditorCompletionKind
field → const EditorCompletionKind
variable → const EditorCompletionKind
type → const EditorCompletionKind
module → const EditorCompletionKind
property → const EditorCompletionKind
keyword → const EditorCompletionKind
snippet → const EditorCompletionKind
file → const EditorCompletionKind

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EditorCompletionKind>
A constant List of the values in this enum, in order of their declaration.