FlickerStats class final

Aggregate counts from a flicker scan.

Constructors

FlickerStats({required int totalBytes, required int synchronizedBytes, required int unsynchronizedBytes, required int frameStarts, required int frameEnds, required int infoCount, required int warningCount, required int errorCount})
Creates flicker-analysis statistics.
const

Properties

errorCount int
Number of error events.
final
frameEnds int
Number of synchronized-output end markers.
final
frameStarts int
Number of synchronized-output start markers.
final
hashCode int
The hash code for this object.
no setterinherited
infoCount int
Number of informational events.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncCoverage double
Fraction of visible output that was synchronized.
no setter
synchronizedBytes int
Visible bytes observed inside synchronized output brackets.
final
totalBytes int
Total scanned string length.
final
unsynchronizedBytes int
Visible bytes observed outside synchronized output brackets.
final
warningCount int
Number of warning events.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts these stats into a serialization-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited