FoldRange class final

Foldable line range (both ends inclusive, 0-based).

Constructors

FoldRange({required int startLine, required int endLine, FoldKind kind = FoldKind.indent})
const

Properties

endLine → int
final
hashCode → int
The hash code for this object.
no setterinherited
kind → FoldKind
final
lineCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLine → int
final

Methods

contains(int line) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited