FontWeight enum

The terminal-supported intensity of a glyph.

Terminals expose bold and dim as text intensities rather than arbitrary numeric font weights.

Inheritance
Available extensions

Values

normal → const FontWeight

Normal terminal intensity.

bold → const FontWeight

Bold or increased terminal intensity.

dim → const FontWeight

Dim or faint terminal intensity.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<FontWeight>
A constant List of the values in this enum, in order of their declaration.