GaugeThreshold class final

A gauge threshold stop.

Constructors

GaugeThreshold({required double value, required String color})
const

Properties

color → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
Normalized 0..1 threshold upper bound.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited