KittyImage class

Utilities for the Kitty Graphics Protocol.

See: https://sw.kovidgoyal.net/kitty/graphics-protocol/

Constructors

KittyImage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

delete({int? imageId, int quiet = 2}) String
Deletes a previously displayed image by its imageId.
deleteAll({int quiet = 2}) String
Deletes all images from the terminal.
encode(Image image, {int? id, int chunkSize = _maxChunkSize, int? columns, int? rows, int quiet = 2}) String
Encodes an image into Kitty Graphics Protocol escape sequences.
encodePng(List<int> pngBytes, {int? id, int chunkSize = _maxChunkSize, int? columns, int? rows, int quiet = 2}) String
Encodes pre-encoded PNG bytes into Kitty Graphics Protocol escape sequences.
getNextImageId() int
Returns the next unique image ID.