RemotePluginCursor class final

Constructors

RemotePluginCursor({required int column, required int row, bool visible = true, RemotePluginCursorShape shape = RemotePluginCursorShape.block, bool blink = false})
const
RemotePluginCursor.fromJson(JsonObject json)
factory

Properties

final
column int
final
hashCode int
The hash code for this object.
no setterinherited
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape RemotePluginCursorShape
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JsonObject
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited