RemotePluginServiceRequest class final

Inheritance

Constructors

RemotePluginServiceRequest({required String requestId, required String service, required String method, JsonObject params = const <String, Object?>{}})
const
RemotePluginServiceRequest.fromPayload(JsonObject payload)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageType RemotePluginMessageType
no setteroverride
method String
final
params → JsonObject
final
payloadJson → JsonObject
no setteroverride
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String
final

Methods

encodeJson() String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JsonObject
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited