SequenceNote class

A note displayed over participants.

Constructors

SequenceNote({required List<String> over, required String label, SequenceNotePosition position = SequenceNotePosition.over})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
final
over → List<String>
final
position → SequenceNotePosition
Placement requested by Mermaid (over, left of, or right of).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited