SparklineProps class final

Props for compact sparklines.

Constructors

SparklineProps({String? id, required List<double> data, required int width, int? height, String? color, bool? showMinMax, SparklineStyle? style, String? title, String? titleColor, String? backgroundColor})
const

Properties

backgroundColor → String?
final
color → String?
final
data → List<double>
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMinMax → bool?
final
style → SparklineStyle?
final
title → String?
final
titleColor → String?
final
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited