TextExtmarkOptions class final

Constructors

TextExtmarkOptions({required int startOffset, required int endOffset, String type = textDefaultExtmarkType, bool virtual = false, String? styleKey, int priority = 0, Object? data})
const

Properties

data → Object?
final
endOffset → int
final
hashCode → int
The hash code for this object.
no setterinherited
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startOffset → int
final
styleKey → String?
final
type → String
final
virtual → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited