TextSyntaxLineWindow class final

Constructors

TextSyntaxLineWindow({required int startLine, required int endLine})
const

Properties

endLine → int
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLine → int
final

Methods

endOffsetIn(TextDocument document) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startOffsetIn(TextDocument document) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited