Verbosity enum

Verbosity levels for console output.

Used to control how much output is displayed based on the -v flag.

  • quiet: No output (except errors)
  • normal: Standard output
  • verbose: More detailed output (-v)
  • veryVerbose: Even more details (-vv)
  • debug: Maximum verbosity (-vvv)
Inheritance
Available extensions

Values

quiet → const Verbosity

No output (except errors). Triggered by -q or --quiet.

normal → const Verbosity

Standard output level.

verbose → const Verbosity

Verbose output. Triggered by -v.

veryVerbose → const Verbosity

Very verbose output. Triggered by -vv.

debug → const Verbosity

Debug-level output. Triggered by -vvv.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Verbosity>
A constant List of the values in this enum, in order of their declaration.