AnticipateConfig class

Configuration for anticipate/autocomplete component.

Constructors

AnticipateConfig({int maxSuggestions = 5, String highlightColor = '36', String pointer = '❯', int minCharsToSearch = 1})
Creates anticipate configuration.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
highlightColor → String
ANSI color code for highlighting selected suggestion.
final
maxSuggestions → int
Maximum number of suggestions to show.
final
minCharsToSearch → int
Minimum characters needed before showing suggestions.
final
pointer → String
Pointer character for selected suggestion.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited