ConfirmKeyMap class

Key bindings for the confirm component.

Inheritance

Constructors

ConfirmKeyMap({KeyBinding? yes, KeyBinding? no, KeyBinding? confirm, KeyBinding? cancel, KeyBinding? toggleLeft, KeyBinding? toggleRight})

Properties

cancel KeyBinding
Cancel the confirmation.
final
chords List<({String id, KeyBinding key, KeyBinding prefix})>?
Optional multi-key chord bindings.
getter/setter pairinherited
confirm KeyBinding
Confirm current selection with Enter.
final
fullHelp List<List<KeyBinding>>
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
no KeyBinding
Deny with 'n'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortHelp List<KeyBinding>
Bindings for the short help view.
getter/setter pairinherited
toggleLeft KeyBinding
Toggle selection left (to Yes).
final
toggleRight KeyBinding
Toggle selection right (to No).
final
yes KeyBinding
Confirm with 'y'.
final

Methods

firstMatch(KeyMsg msg) KeyBinding?
Returns the first enabled KeyBinding that matches msg, or null.
inherited
handle(KeyMsg msg) Cmd?
Returns the command from the first matching handler, or null.
inherited
intercept(KeyMsg msg) bool
Returns true if a matching binding's KeyBinding.action was called.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited