CursorBlinkMsg class

Message indicating the cursor should toggle its blink state.

Inheritance

Constructors

CursorBlinkMsg({required int id, required int tag})
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
The ID of the cursor this message is for.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int
Tag to prevent duplicate blink messages.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited