DebugOverlayMode enum

Which sections the debug overlay displays.

Use DebugOverlayModel.cycleMode to cycle through modes.

Inheritance
Available extensions

Values

metrics → const DebugOverlayMode

Only render metrics (FPS, frame time, etc.) — the original behavior.

messages → const DebugOverlayMode

Only recent messages dispatched through the program.

output → const DebugOverlayMode

Only captured output from intercepted print() calls.

all → const DebugOverlayMode

All sections combined.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DebugOverlayMode>
A constant List of the values in this enum, in order of their declaration.