DiffCommentLineHighlightKind enum

The visual role of a commentable diff line.

Inheritance
Available extensions

Values

thread → const DiffCommentLineHighlightKind

A line with an existing review thread.

range → const DiffCommentLineHighlightKind

A line inside the currently selected multi-line comment range.

selected → const DiffCommentLineHighlightKind

The active keyboard/mouse-selected line.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DiffCommentLineHighlightKind>
A constant List of the values in this enum, in order of their declaration.