ListKeyMap class

Key map for list navigation.

Inheritance

Constructors

ListKeyMap({KeyBinding? cursorUp, KeyBinding? cursorDown, KeyBinding? nextPage, KeyBinding? prevPage, KeyBinding? goToStart, KeyBinding? goToEnd, KeyBinding? filter, KeyBinding? clearFilter, KeyBinding? acceptWhileFiltering, KeyBinding? cancelWhileFiltering, KeyBinding? quit, KeyBinding? forceQuit, KeyBinding? showFullHelp, KeyBinding? closeFullHelp})
Creates a list key map with default bindings.

Properties

acceptWhileFiltering KeyBinding
Accept filter while filtering.
final
cancelWhileFiltering KeyBinding
Cancel filtering.
final
chords List<({String id, KeyBinding key, KeyBinding prefix})>?
Optional multi-key chord bindings.
getter/setter pairinherited
clearFilter KeyBinding
Clear current filter.
final
closeFullHelp KeyBinding
Close full help.
final
cursorDown KeyBinding
Move cursor down.
final
cursorUp KeyBinding
Move cursor up.
final
filter KeyBinding
Start filtering.
final
forceQuit KeyBinding
Force quit the list.
final
fullHelp List<List<KeyBinding>>
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
goToEnd KeyBinding
Go to end.
final
goToStart KeyBinding
Go to start.
final
hashCode int
The hash code for this object.
no setterinherited
nextPage KeyBinding
Go to next page.
final
prevPage KeyBinding
Go to previous page.
final
quit KeyBinding
Quit the list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortHelp List<KeyBinding>
Bindings for the short help view.
getter/setter pairinherited
showFullHelp KeyBinding
Show full help.
final

Methods

firstMatch(KeyMsg msg) KeyBinding?
Returns the first enabled KeyBinding that matches msg, or null.
inherited
handle(KeyMsg msg) Cmd?
Returns the command from the first matching handler, or null.
inherited
intercept(KeyMsg msg) bool
Returns true if a matching binding's KeyBinding.action was called.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited