ModalChrome class final
Pure-data modal chrome. Stored by the caller alongside domain state.
Constructors
- ModalChrome({String title = '', int width = 0, int maxHeight = 0, int padding = 1})
-
const
Properties
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxHeight → int
-
Maximum box height including chrome;
0means unbounded.final - padding → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- width → int
-
Fixed box width;
0sizes to content.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited