MultiSelectionMadeMsg<T> class
Message sent when multiple items are selected.
Constructors
-
MultiSelectionMadeMsg(List<
T> items, List<int> indices) -
const
Properties
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
→ List<
int> -
The indices of the selected items.
final
-
items
→ List<
T> -
The selected items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited