NumberInputKeyMap class

Key bindings for NumberInputModel.

Inheritance

Constructors

NumberInputKeyMap({KeyBinding? increment, KeyBinding? decrement, KeyBinding? deleteBackward, KeyBinding? submit, KeyBinding? cancel})
Creates a key map with default bindings.

Properties

cancel KeyBinding
Cancel the prompt.
final
chords List<({String id, KeyBinding key, KeyBinding prefix})>?
Optional multi-key chord bindings.
getter/setter pairinherited
decrement KeyBinding
Decrement the value by step.
final
deleteBackward KeyBinding
Delete the last typed character.
final
fullHelp List<List<KeyBinding>>
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
increment KeyBinding
Increment the value by step.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortHelp List<KeyBinding>
Bindings for the short help view.
getter/setter pairinherited
submit KeyBinding
Submit the current value.
final

Methods

firstMatch(KeyMsg msg) KeyBinding?
Returns the first enabled KeyBinding that matches msg, or null.
inherited
handle(KeyMsg msg) Cmd?
Returns the command from the first matching handler, or null.
inherited
intercept(KeyMsg msg) bool
Returns true if a matching binding's KeyBinding.action was called.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited