ProgressBarSetMsg class final

Inheritance

Constructors

ProgressBarSetMsg({required int id, required int current, required int total})
const

Properties

current int
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited