SanitizerOptions class

Options for configuring the sanitizer behavior.

Constructors

SanitizerOptions({String tabReplacement = ' ', String newlineReplacement = '\n'})
Creates sanitizer options.

Properties

hashCode → int
The hash code for this object.
no setterinherited
newlineReplacement → String
String to replace newlines with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabReplacement → String
String to replace tabs with.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited