SearchSelectionMadeMsg<T> class
Message sent when a search result is selected.
Constructors
- SearchSelectionMadeMsg(T item, int index)
-
const
Properties
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The index of the selected item in the original list.
final
- item → T
-
The selected item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited