StopwatchTickMsg class

Message sent when the stopwatch ticks.

Inheritance

Constructors

StopwatchTickMsg(DateTime time, int tag, int id)
const

Properties

dropWhenInputQueued → bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
The stopwatch ID this tick belongs to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → int
The tag to identify which stopwatch instance this tick belongs to.
final
time → DateTime
The time when the tick occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited