SuggestKeyMap class

Key bindings for SuggestModel.

Inheritance

Constructors

SuggestKeyMap({KeyBinding? moveUp, KeyBinding? moveDown, KeyBinding? moveFirst, KeyBinding? moveLast, KeyBinding? accept, KeyBinding? deleteBackward, KeyBinding? moveCursorLeft, KeyBinding? moveCursorRight, KeyBinding? cancel})
Creates a key map with default bindings.

Properties

accept KeyBinding
Accept the current input or highlighted suggestion.
final
cancel KeyBinding
Cancel the prompt.
final
chords List<({String id, KeyBinding key, KeyBinding prefix})>?
Optional multi-key chord bindings.
getter/setter pairinherited
deleteBackward KeyBinding
Delete the character before the cursor.
final
fullHelp List<List<KeyBinding>>
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
moveCursorLeft KeyBinding
Move text cursor left (clears dropdown selection).
final
moveCursorRight KeyBinding
Move text cursor right (clears dropdown selection).
final
moveDown KeyBinding
Move selection down in the dropdown.
final
moveFirst KeyBinding
Jump to first suggestion.
final
moveLast KeyBinding
Jump to last suggestion.
final
moveUp KeyBinding
Move selection up in the dropdown.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortHelp List<KeyBinding>
Bindings for the short help view.
getter/setter pairinherited

Methods

firstMatch(KeyMsg msg) KeyBinding?
Returns the first enabled KeyBinding that matches msg, or null.
inherited
handle(KeyMsg msg) Cmd?
Returns the command from the first matching handler, or null.
inherited
intercept(KeyMsg msg) bool
Returns true if a matching binding's KeyBinding.action was called.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited