WizardCompletedMsg class

Message sent when the entire wizard is completed.

Inheritance

Constructors

WizardCompletedMsg(Map<String, dynamic> answers)
const

Properties

answers Map<String, dynamic>
Map of step keys to their answers.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited