Directory class

Stub for dart:io Directory.

Implemented types

Constructors

Directory(String path)

Properties

hashCode int
The hash code for this object.
no setterinherited
parent Directory
no setter
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTemp(String s) Future<Directory>
exists() Future<bool>
override
list({bool recursive = false}) Stream<FileSystemEntity>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stat() Future<FileStat>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

systemTemp Directory
no setter