FileStat class

Stub for dart:io FileStat.

Properties

hashCode int
The hash code for this object.
no setterinherited
mode int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter
type FileSystemEntityType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

stat(String path) Future<FileStat>