FileSystemEntity class abstract

Stub for dart:io FileSystemEntity.

Implementers

Constructors

FileSystemEntity()

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exists() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stat() Future<FileStat>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited