HttpHeaders class abstract

Stub for dart:io HttpHeaders.

Constructors

HttpHeaders()

Properties

contentType ContentTypeStub?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String name, Object value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

acceptHeader → const String
userAgentHeader → const String