Isolate class

Stub for dart:isolate Isolate.

Constructors

Isolate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run<R>(FutureOr<R> computation(), {String? debugName}) Future<R>
Web stub: runs computation directly on the current thread.