GlamourBlockStyle class
Represents StyleBlock in glamour.
Constructors
- GlamourBlockStyle({GlamourPrimitiveStyle style = const GlamourPrimitiveStyle(), int? margin, int? indent, String? indentToken})
-
const
-
GlamourBlockStyle.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent → int?
-
final
- indentToken → String?
-
final
- margin → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GlamourPrimitiveStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited