GlamourCodeBlockStyle class

Represents StyleCodeBlock in glamour.

Constructors

GlamourCodeBlockStyle({GlamourBlockStyle style = const GlamourBlockStyle(), String? theme, ChromaTheme? chroma})
const
GlamourCodeBlockStyle.fromJson(Map<String, dynamic> json)
factory

Properties

chroma ChromaTheme?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style GlamourBlockStyle
final
theme String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited