GlamourListStyle class

Represents StyleList in glamour.

Constructors

GlamourListStyle({GlamourBlockStyle style = const GlamourBlockStyle(), int? levelIndent})
const
GlamourListStyle.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
levelIndent int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style GlamourBlockStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited