GlamourPrimitiveStyle class

Represents StylePrimitive in glamour.

This maps closely to artisanal's Style, but includes additional structure properties like prefixes and suffixes.

Constructors

GlamourPrimitiveStyle({String? blockPrefix, String? blockSuffix, String? prefix, String? suffix, Color? color, Color? backgroundColor, bool? bold, bool? italic, bool? underline, bool? blink, bool? crossedOut, bool? faint, bool? conceal, bool? inverse, bool? upper, bool? lower, bool? title, String? format})
const
GlamourPrimitiveStyle.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor Color?
final
final
blockPrefix String?
final
blockSuffix String?
final
bold bool?
final
color Color?
final
conceal bool?
final
crossedOut bool?
final
faint bool?
final
format String?
final
hashCode int
The hash code for this object.
no setterinherited
inverse bool?
final
italic bool?
final
lower bool?
final
prefix String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix String?
final
title bool?
final
toStyle Style
Converts to an artisanal Style builder, excluding structure props.
no setter
underline bool?
final
upper bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited