GlamourTableStyle class

Represents StyleTable in glamour.

Constructors

GlamourTableStyle({GlamourBlockStyle style = const GlamourBlockStyle(), String? centerSeparator, String? columnSeparator, String? rowSeparator})
const
GlamourTableStyle.fromJson(Map<String, dynamic> json)
factory

Properties

centerSeparator String?
final
columnSeparator String?
final
hashCode int
The hash code for this object.
no setterinherited
rowSeparator String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style GlamourBlockStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited