GlamourTaskStyle class

Represents StyleTask in glamour.

Constructors

GlamourTaskStyle({GlamourPrimitiveStyle style = const GlamourPrimitiveStyle(), String ticked = '[x] ', String unticked = '[ ] '})
const
GlamourTaskStyle.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style GlamourPrimitiveStyle
final
ticked String
final
unticked String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited