liquid library

Liquid tag template adapters for Artisanal.

Experimental: this API is still evolving and may change in minor releases.

Classes

LiquidTemplate
Convenience wrapper for liquify templates.
StringRenderTarget
Render target that captures output into a raw string.
UvBufferTarget
Render target that converts Liquify output into a UV Buffer.

Extensions

LiquidTemplateExtensions on Template
Convenience extensions on liquify Template for UV buffer rendering.

Functions

registerLiquidUiTags({Environment? environment}) → void
Registers Liquid UI tags for terminal layout.