PhysicsSettings class final

Global physics settings (Forge2D uses module-level settings).

Constructors

PhysicsSettings({int velocityIterations = 10, int positionIterations = 10})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
positionIterations int
Number of position iterations per step.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
velocityIterations int
Number of velocity iterations per step.
final

Methods

apply() → void
Applies these settings to the global forge2d configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited