MatchResult class

Result of scoring a query against a title.

Constructors

MatchResult({required double score, required MatchType matchType, List<int> matchPositions = const [], List<EvidenceEntry> evidence = const []})
const
MatchResult.noMatch()
Create a no-match result.
const

Properties

evidence List<EvidenceEntry>
Evidence entries explaining the score.
final
hashCode int
The hash code for this object.
no setterinherited
matchPositions List<int>
Positions of matched characters in the title.
final
matchType MatchType
Type of match detected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
Computed relevance score (posterior probability, 0.0–1.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited