MatchType enum

Type of match between query and title.

Ordered from strongest to weakest: exact > prefix > wordStart > substring > fuzzy > noMatch.

Inheritance
Available extensions

Values

noMatch → const MatchType

No characters found.

fuzzy → const MatchType

Characters found in order but with gaps.

substring → const MatchType

Query found as contiguous substring.

wordStart → const MatchType

Query matches start of word boundaries.

prefix → const MatchType

Title starts with query.

exact → const MatchType

Query equals title exactly.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
priorOdds double
Prior odds ratio P(relevant) / P(not_relevant) for this match type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MatchType>
A constant List of the values in this enum, in order of their declaration.