RankedResults class
Result of ranking a set of match results.
Constructors
-
RankedResults({required List<
RankedItem> items, required RankingSummary summary}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
RankedItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → RankingSummary
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited