RankingSummary class

Summary statistics for a ranked result set.

Constructors

RankingSummary({required int count, required int stableCount, required int tieGroupCount, required double medianGap})
const

Properties

count int
final
hashCode int
The hash code for this object.
no setterinherited
medianGap double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stableCount int
final
tieGroupCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited