ArcSegments class

Arc segment and circle-segment characters for spinning animations (U+25D8–U+25E1).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

leftHalf → const String
Left half circle ◐.
lowerHalf → const String
Lower half circle ◡.
lowerHalfCircle → const String
Lower half circle ◑.
lowerLeftArc → const String
Lower-left quadrant arc ◟.
lowerRightArc → const String
Lower-right quadrant arc ◞.
rightHalf → const String
Right half circle ◓.
upperHalf → const String
Upper half circle ◠.
upperHalfCircle → const String
Upper half circle ◒.
upperLeftArc → const String
Upper-left quadrant arc ◜.
upperRightArc → const String
Upper-right quadrant arc ◝.