Arrows class

Common arrow glyphs used in key help and navigation labels.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

down → const String
Down arrow ↓.
left → const String
Left arrow ←.
Right arrow →.
up → const String
Up arrow ↑.