BlockMedium class

Medium-weight block elements (U+25B0–U+25B1).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const String
Medium empty block ▱ (U+25B1).
solid → const String
Medium solid block ▰ (U+25B0).