BorderSides class

Controls which sides of a border are visible.

Used in conjunction with Border to selectively show/hide sides.

Style()
    .border(Border.rounded)
    .borderSides(BorderSides(top: true, bottom: true))

Constructors

BorderSides({bool top = true, bool bottom = true, bool left = true, bool right = true})
Creates border side visibility settings.
const

Properties

bottom → bool
Whether the bottom border is visible.
final
hasAny → bool
Whether any side is visible.
no setter
hashCode → int
The hash code for this object.
no setteroverride
left → bool
Whether the left border is visible.
final
Whether the right border is visible.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → bool
Whether the top border is visible.
final

Methods

copyWith({bool? top, bool? bottom, bool? left, bool? right}) → BorderSides
Creates a copy with the specified values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

all → const BorderSides
Show all sides.
bottomOnly → const BorderSides
Show only bottom side.
horizontal → const BorderSides
Show only horizontal sides (top and bottom).
none → const BorderSides
Show no sides (same as no border).
topOnly → const BorderSides
Show only top side.
vertical → const BorderSides
Show only vertical sides (left and right).