BrailleChars class

Braille pattern characters for progress indicators.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

full → const String
Full braille pattern ⣿ (U+28FF).
topRow → const String
Pattern with only top row ⣀ (U+2880).