Circles class

Circle glyphs (U+25CB–U+25D5).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const String
Empty circle ○ (U+25CB).
fill25 → const String
25% fill ◔ (U+25D4) — upper-right quadrant.
fill50 → const String
50% fill ◑ (U+25D1) — lower half.
fill75 → const String
75% fill ◕ (U+25D5) — all but upper-left.
filled → const String
Filled circle ● (U+25CF).