parse method
Parses tagged text into a list of segments.
Use this if you need access to the parsed structure before rendering.
Implementation
List<TagSegment> parse(String text) {
final tokens = _tokenize(text);
return _parse(tokens);
}
Parses tagged text into a list of segments.
Use this if you need access to the parsed structure before rendering.
List<TagSegment> parse(String text) {
final tokens = _tokenize(text);
return _parse(tokens);
}