DotChars class

Dot and marker characters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bullet → const String
Bullet • (U+2022).
middle → const String
Middle dot · (U+00B7).
small → const String
Small black square ⬝ (U+2B1D).