HorizontalAlign enum

Horizontal alignment options.

Inheritance
Available extensions

Values

left → const HorizontalAlign

Align content to the left.

center → const HorizontalAlign

Align content to the center.

Align content to the right.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
position → double

Available on HorizontalAlign, provided by the HorizontalAlignPosition extension

Returns the fractional position (0.0 = left, 0.5 = center, 1.0 = right).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<HorizontalAlign>
A constant List of the values in this enum, in order of their declaration.