ListEnumerators class

Predefined list enumerators.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alphabet(ListItems items, int index) → String
Alphabetic (a. b. c.).
alphabetUpper(ListItems items, int index) → String
Uppercase alphabetic (A. B. C.).
arabic(ListItems items, int index) → String
Arabic numerals (1. 2. 3.).
asterisk(ListItems items, int index) → String
Asterisk enumerator (*).
bullet(ListItems items, int index) → String
Bullet enumerator (•).
custom(String fn(int index)) → ListEnumeratorFunc
Creates a custom enumerator from a simple index function.
dash(ListItems items, int index) → String
Dash enumerator (-).
fixed(String symbol) → ListEnumeratorFunc
Creates a fixed enumerator that always returns the same string.
roman(ListItems items, int index) → String
Roman numerals (I. II. III.).
romanLower(ListItems items, int index) → String
Lowercase roman numerals (i. ii. iii.).