ListItem class abstract

A single item in a list.

Constructors

ListItem()

Properties

children → ListItems
The children of this item (for nested lists).
no setter
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether this item is hidden.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The value/content of this item.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited