active property

List<String> active
final

Characters used for active (head/trail) positions.

When multiple characters are provided they are mapped across the trail gradient — the first is the brightest head position and subsequent entries serve as the trailing gradient shapes.

Implementation

final List<String> active;