ScannerChars class

Predefined scanner animation character sets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

blocks → const ScannerCharSet
Blocks style: solid block for active, small dot for inactive.
diamonds → const ScannerCharSet
Diamonds style: diamond shapes for active, middle dot for inactive.