SparseBlocks class
Sparse block shapes (U+25A0–U+25AB).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const String
- Empty square □ (U+25A1).
- smallEmpty → const String
- Small empty square ▫ (U+25AB).
- smallSolid → const String
- Small solid square ▪ (U+25AA).
- solid → const String
- Solid square ■ (U+25A0).