StatusChars class

Status indicator symbols.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

check → const String
Check mark ✓ (U+2713).
cross → const String
Ballot X ✗ (U+2717).
skipped → const String
Circled division slash ⊘ (U+2298) — skipped step.
x → const String
Multiplication X ✕ (U+2715).