StyleData class final

Constructors

StyleData({bool bold = false, bool italic = false, bool underline = false, UnderlineStyle underlineStyle = UnderlineStyle.single, bool strikethrough = false, bool dim = false, bool inverse = false, bool blink = false, Color? foreground, Color? background, Color? borderForeground, Color? borderBackground, Color? borderTopForeground, Color? borderRightForeground, Color? borderBottomForeground, Color? borderLeftForeground, Color? borderTopBackground, Color? borderRightBackground, Color? borderBottomBackground, Color? borderLeftBackground, List<Color> borderForegroundBlend = const [], int borderForegroundBlendOffset = 0, int? width, int? height, int? maxWidth, int? maxHeight, Padding padding = Padding.zero, Margin margin = Margin.zero, HorizontalAlign align = HorizontalAlign.left, VerticalAlign alignVertical = VerticalAlign.top, Border? border, BorderSides borderSides = BorderSides.all, bool inline = false, bool wrapAnsi = false, String transform(String)?, String paddingChar = ' ', String marginChar = ' ', String whitespaceChar = ' ', Color? whitespaceForeground, String? stringValue, int tabWidth = 4, bool underlineSpaces = false, bool strikethroughSpaces = false, bool colorWhitespace = true, String? hyperlinkUrl, String hyperlinkParams = '', Color? marginBackground, Color? underlineColor})
const

Properties

align → HorizontalAlign
final
alignVertical → VerticalAlign
final
background → Color?
final
final
bold → bool
final
border → Border?
final
borderBackground → Color?
final
borderBottomBackground → Color?
final
borderBottomForeground → Color?
final
borderForeground → Color?
final
borderForegroundBlend → List<Color>
final
borderForegroundBlendOffset → int
final
borderLeftBackground → Color?
final
borderLeftForeground → Color?
final
borderRightBackground → Color?
final
borderRightForeground → Color?
final
borderSides → BorderSides
final
borderTopBackground → Color?
final
borderTopForeground → Color?
final
colorWhitespace → bool
final
dim → bool
final
foreground → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
hyperlinkParams → String
final
hyperlinkUrl → String?
final
inline → bool
final
inverse → bool
final
italic → bool
final
margin → Margin
final
marginBackground → Color?
final
marginChar → String
final
maxHeight → int?
final
maxWidth → int?
final
padding → Padding
final
paddingChar → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strikethrough → bool
final
strikethroughSpaces → bool
final
stringValue → String?
final
tabWidth → int
final
transform → String Function(String)?
final
underline → bool
final
underlineColor → Color?
final
underlineSpaces → bool
final
underlineStyle → UnderlineStyle
final
whitespaceChar → String
final
whitespaceForeground → Color?
final
width → int?
final
wrapAnsi → bool
final

Methods

copyWith({bool? bold, bool? italic, bool? underline, UnderlineStyle? underlineStyle, bool? strikethrough, bool? dim, bool? inverse, bool? blink, Color? foreground, Color? background, Color? borderForeground, Color? borderBackground, Color? borderTopForeground, Color? borderRightForeground, Color? borderBottomForeground, Color? borderLeftForeground, Color? borderTopBackground, Color? borderRightBackground, Color? borderBottomBackground, Color? borderLeftBackground, List<Color>? borderForegroundBlend, int? borderForegroundBlendOffset, int? width, int? height, int? maxWidth, int? maxHeight, Padding? padding, Margin? margin, HorizontalAlign? align, VerticalAlign? alignVertical, Border? border, BorderSides? borderSides, bool? inline, bool? wrapAnsi, String transform(String)?, String? paddingChar, String? marginChar, String? whitespaceChar, Color? whitespaceForeground, String? stringValue, int? tabWidth, bool? underlineSpaces, bool? strikethroughSpaces, bool? colorWhitespace, String? hyperlinkUrl, String? hyperlinkParams, Color? marginBackground, Color? underlineColor}) → StyleData
merge(StyleData overlay) → StyleData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited