Triangles class

Triangular indicator glyphs (U+25B2–U+25C0).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

down → const String
Down-pointing triangle ▼ (U+25BC).
left → const String
Left-pointing triangle ◀ (U+25C0).
Right-pointing triangle ▶ (U+25B6).
up → const String
Up-pointing triangle ▲ (U+25B2).