notifySizeChanged method
Pushes a resize event into the backend and updates size.
Implementation
void notifySizeChanged(TerminalDimensions size) {
if (_disposed) return;
_size = size;
_resizeController.add(size);
}
Pushes a resize event into the backend and updates size.
void notifySizeChanged(TerminalDimensions size) {
if (_disposed) return;
_size = size;
_resizeController.add(size);
}