resizeStream property
Stream of terminal resize events, if the backend can emit them.
Implementation
@override
Stream<TerminalDimensions>? get resizeStream => _resizeController.stream;
Stream of terminal resize events, if the backend can emit them.
@override
Stream<TerminalDimensions>? get resizeStream => _resizeController.stream;