isTerminal property
bool
get
isTerminal
Whether the backend is connected to a real terminal-like surface.
Implementation
bool get isTerminal;
Whether the backend is connected to a real terminal-like surface.
bool get isTerminal;