syntaxHighlighting property

bool syntaxHighlighting
final

Whether to apply syntax highlighting to fenced code blocks.

When enabled, code blocks with a language specifier (e.g., ```dart) will be syntax highlighted using the syntaxTheme.

Implementation

final bool syntaxHighlighting;