textStyle property
Style for normal body/paragraph text.
When set, this style is applied to all regular paragraph text, list item text, and other non-heading, non-code content. This is useful for ensuring readable foreground colors when the terminal background differs from the default.
If null, no styling is applied to body text (it uses the terminal's default foreground color).
Implementation
final Style? textStyle;