bindOptions method
Called by Program to pass the resolved options for service extension queries. This is set internally and should not be called by consumers.
Implementation
void bindOptions(ProgramOptions options) {
_options = options;
}
Called by Program to pass the resolved options for service extension queries. This is set internally and should not be called by consumers.
void bindOptions(ProgramOptions options) {
_options = options;
}