BatchMsg class

Message containing multiple messages to be processed sequentially.

Used internally by the runtime for batching messages together.

Inheritance

Constructors

BatchMsg(List<Msg> messages)
Creates a batch message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messages List<Msg>
The list of messages to process.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited