ClipboardMsg class final

Clipboard content message.

Only emitted when UV input decoding is enabled and the terminal reports a clipboard payload (OSC 52 response).

Inheritance

Constructors

ClipboardMsg({required ClipboardSelection selection, required String content})
Creates a clipboard message with the given selection target and content.
const

Properties

content String
The clipboard content string.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection ClipboardSelection
The clipboard selection target (system, primary, or unknown).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited