requestWindowPixelSizeReport static method
Request the terminal to report its window size in pixels.
Terminals that support xterm window ops respond to CSI 14 t with
CSI 4 ; <height> ; <width> t, which UV decoding maps to
WindowPixelSizeMsg.
Implementation
static Cmd requestWindowPixelSizeReport() => writeRaw('\x1b[14t');