ColorPaletteMsg class final

Message containing a terminal palette entry color.

Only emitted when UV input decoding is enabled and the terminal reports an OSC 4 palette color response.

Inheritance

Constructors

ColorPaletteMsg({required int index, required String hex})
Creates a terminal palette color message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hex String
The palette color reported by the terminal (hex string).
final
index int
The palette slot index that was reported.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited