ColorProfileMsg class

Message sent when the terminal color profile is detected or changed.

Inheritance

Constructors

ColorProfileMsg(ColorProfile profile)
Creates a color profile detection message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
profile ColorProfile
The detected terminal color profile.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override