ColorSchemeMsg class

Message sent when the terminal reports its preferred light/dark scheme.

Inheritance

Constructors

ColorSchemeMsg({required bool dark})
Creates a terminal color-scheme message.
const

Properties

dark bool
Whether the terminal reports a dark color scheme.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override