ComponentHost mixin

A mixin for Models that host one or more ViewComponents.

This provides helpers for delegating messages and commands to child components.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateComponent<T extends Model, P extends Model>(T component, Msg msg, void setter(T)) → (P, Cmd?)
Helper to update a child component and return the parent model.

Operators

operator ==(Object other) → bool
The equality operator.
inherited