CursorColorMsg class final

Message containing the terminal's cursor color.

Only emitted when UV input decoding is enabled and the terminal reports a cursor color (OSC 12).

Inheritance

Constructors

CursorColorMsg({required String hex})
Creates a cursor color detection message from a hex color string.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hex String
The cursor color reported by the terminal (hex string).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited