CursorColorMsg constructor
const
CursorColorMsg({
- required String hex,
Creates a cursor color detection message from a hex color string.
Implementation
const CursorColorMsg({required this.hex});
Creates a cursor color detection message from a hex color string.
const CursorColorMsg({required this.hex});