CursorPositionMsg class

Message sent when the terminal reports the cursor position.

Inheritance

Constructors

CursorPositionMsg(int x, int y)
Creates a cursor-position message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
The zero-based cursor column.
final
y int
The zero-based cursor row.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override