DevToolsMessageEntry class final

A recorded message dispatch entry for the message log.

Constructors

DevToolsMessageEntry({required DateTime timestamp, required String messageType, required String summary, required Duration processingTime})
Creates a message log entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
messageType String
The runtime type name of the message.
final
processingTime Duration
How long the message took to process (from onProcessed).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
A short human-readable summary of the message.
final
timestamp DateTime
Wall-clock time when the message was dispatched.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this entry to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited