DiffLine class

A single parsed line from a unified diff.

Constructors

DiffLine({required DiffLineType type, required String content, int? oldLineNumber, int? newLineNumber})
Creates a new diff line.
const

Properties

content String
The raw content of this line.
final
hashCode int
The hash code for this object.
no setterinherited
newLineNumber int?
The line number in the new file (null for removed lines / headers).
final
oldLineNumber int?
The line number in the old file (null for added lines / headers).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DiffLineType
The type of this diff line.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited