DiffLineType enum

The type of a parsed diff line.

Inheritance
Available extensions

Values

fileHeader → const DiffLineType

File header line (diff --git, index, ---/+++).

hunkHeader → const DiffLineType

Hunk header line (@@ ... @@).

added → const DiffLineType

Added line (+).

removed → const DiffLineType

Removed line (-).

context → const DiffLineType

Context (unchanged) line.

empty → const DiffLineType

Empty/separator line.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DiffLineType>
A constant List of the values in this enum, in order of their declaration.