DiffViewMode enum

The display mode for the diff viewer.

Inheritance
Available extensions

Values

unified → const DiffViewMode

Unified diff — additions and deletions shown inline.

sideBySide → const DiffViewMode

Side-by-side diff — old file on the left, new file on the right.

pretty → const DiffViewMode

Pretty diff — clean file headers, colored line backgrounds, single line-number column.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DiffViewMode>
A constant List of the values in this enum, in order of their declaration.