EditHistoryController<Action, State, Marker> class final

Constructors

EditHistoryController({required int maxEntries, required EditHistoryStateEquals<State> sameState, required EditHistoryCoalescePredicate<Action, State, Marker> canCoalesce, required EditHistoryMarkerBuilder<Action, State, Marker> markerForState})

Properties

canCoalesce EditHistoryCoalescePredicate<Action, State, Marker>
final
canRedo bool
no setter
canUndo bool
no setter
hashCode int
The hash code for this object.
no setterinherited
markerForState EditHistoryMarkerBuilder<Action, State, Marker>
final
maxEntries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameState EditHistoryStateEquals<State>
final

Methods

beginAction(Action action, {bool breakChain = false}) → void
breakCoalescing() → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordUndoSnapshot(State captureState()) → void
redo({required State captureState(), required void restoreState(State state)}) bool
runFrame<T>({required State captureState(), required T body(), void onCommittedChange()?}) → T
toString() String
A string representation of this object.
inherited
undo({required State captureState(), required void restoreState(State state)}) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited