EditorState class final

Constructors

EditorState({int line = 0, int column = 0})

Properties

column int
no setter
cursor TextPosition
no setter
hashCode int
The hash code for this object.
no setterinherited
hasSelection bool
no setter
line int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection?
no setter

Methods

applyColumnDeltas(Map<int, int> deltas, {required int lineLength(int line)}) → void
beginSelection() → void
clearSelection() → void
collapseSelection() → void
extendSelectionTo(TextPosition extent) → void
moveCursorTo(TextPosition position, {bool clearSelection = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectedLineRange() → ({int endLine, int startLine})
selectRange({required TextPosition base, required TextPosition extent, TextPosition? cursor}) → void
setCursor({required int line, required int column}) → void
setSelection({required TextPosition base, required TextPosition extent, TextPosition? cursor}) → void
shiftRowsInRange({required int startLine, required int endLine, required int delta, required int maxLine, required int lineLength(int line)}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited