ExecResult class

Result of executing an external process.

Constructors

ExecResult({required int exitCode, required String stdout, required String stderr})
const

Properties

exitCode → int
The exit code of the process.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → String
Standard error from the process.
final
stdout → String
Standard output from the process.
final
success → bool
Whether the process exited successfully (exit code 0).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited