FrameArea class final

A rectangular region in a structured terminal Frame.

Coordinates are zero-based and relative to the frame's viewport.

Constructors

FrameArea(int x, int y, int width, int height)
Creates an area from its origin and dimensions.
const

Properties

bottom int
The first row outside this area.
no setter
hashCode int
The hash code for this object.
no setteroverride
height int
Height in terminal cells.
final
isEmpty bool
Whether this area has no drawable cells.
no setter
The first column outside this area.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Width in terminal cells.
final
x int
Horizontal origin.
final
y int
Vertical origin.
final

Methods

centered({required int width, required int height}) FrameArea
Returns an area of at most width by height, centered within this area.
inset({int left = 0, int top = 0, int right = 0, int bottom = 0}) FrameArea
Returns this area with the given edge insets removed.
intersect(FrameArea other) FrameArea
Returns the overlap between this area and other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override