wantsFrameTicks property
bool
get
wantsFrameTicks
Whether the model wants to receive frame tick messages.
Implementation
bool get wantsFrameTicks;
Whether the model wants to receive frame tick messages.
bool get wantsFrameTicks;