KeyChordInterceptor class final

Interceptor that turns prefix key sequences into chord messages.

Inheritance

Constructors

KeyChordInterceptor({required List<KeyChordBinding> bindings, Duration? timeout, ProgramInterceptor? inner})

Properties

hashCode int
The hash code for this object.
no setterinherited
inner ProgramInterceptor?
Optional interceptor to compose underneath the chord layer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
How long to wait for the continuation key before cancelling.
final
wantsNativeFrames bool
Whether this interceptor needs native cell snapshots after each render.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProcessed(Msg msg, Duration elapsed) → void
Called after a message has been processed.
inherited
onRendered({required int renderGeneration, required Object view, required DegradationLevel degradationLevel, required Duration renderDuration, int? width, int? height, TerminalNativeFrame? nativeFrame, TerminalNativeDeltaFrame? nativeDelta, TerminalNativeCellDeltaFrame? nativeCellDelta, List<TerminalNativeSpanDelta>? nativeSpanDelta}) → void
Called after a render has completed.
inherited
onSend(Msg msg) Msg?
Called for each message before it is queued.
override
onStart(void send(Msg msg)) → void
Called once after program initialization.
override
onStop() → void
Called during program cleanup.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited