timeout property

Duration? timeout
final

How long to wait for the continuation key before cancelling.

When null (the default) the interceptor waits indefinitely for the continuation key, matching opencode-style behavior. Set a duration to enable automatic cancellation after a period of inactivity.

Implementation

final Duration? timeout;