KeyChordResolvedMsg class final

Message emitted when a chord resolves to a configured binding.

Inheritance

Constructors

KeyChordResolvedMsg({required String id, required Key prefix, required Key key})
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The resolved chord identifier.
final
key Key
The continuation key that completed the chord.
final
prefix Key
The prefix key that started the chord.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited