shortHelp property
Bindings for the short help view.
These are displayed in a single line at the bottom of the screen.
Implementation
List<KeyBinding> shortHelp;
Bindings for the short help view.
These are displayed in a single line at the bottom of the screen.
List<KeyBinding> shortHelp;