KeyboardEnhancements class

KeyboardEnhancements describes the requested keyboard enhancement features.

Constructors

KeyboardEnhancements({bool reportEventTypes = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reportEventTypes → bool
Whether to request the terminal to report key repeat and release events.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited