KeyboardEnhancementsMsg class

Message sent when keyboard enhancements are reported.

Inheritance

Constructors

KeyboardEnhancementsMsg({bool reportEventTypes = false})
Creates a keyboard enhancements capability message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
reportEventTypes bool
Whether the terminal supports reporting event types.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override