explicitSyntaxTheme property
Explicit syntax theme (not adaptive).
Use this to force a specific theme regardless of background.
Implementation
final ChromaTheme? explicitSyntaxTheme;
Explicit syntax theme (not adaptive).
Use this to force a specific theme regardless of background.
final ChromaTheme? explicitSyntaxTheme;