ModeReportMsg class

Message sent when the terminal replies to a mode status query.

Inheritance

Constructors

ModeReportMsg({required int mode, required ModeReportValue value})
Creates a terminal mode report message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
mode int
The reported terminal mode number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ModeReportValue
The reported mode state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override