ModeReportValue enum

The reported state of a terminal mode query.

Inheritance
Available extensions

Values

notRecognized → const ModeReportValue

The terminal did not recognize the requested mode.

reset → const ModeReportValue

The mode is currently reset/disabled.

set → const ModeReportValue

The mode is currently set/enabled.

permanentlySet → const ModeReportValue

The mode is permanently set/enabled.

permanentlyReset → const ModeReportValue

The mode is permanently reset/disabled.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ModeReportValue>
A constant List of the values in this enum, in order of their declaration.