MultiSearchModel<T> class

A multi-select search/filter component.

Inheritance

Constructors

MultiSearchModel({required List<T> items, String title = '', String hint = '(Space to toggle, ^a to toggle all, Enter to confirm)', String placeholder = 'Type to search...', String noResultsText = 'No matches found', bool showTitle = true, bool showHint = true, bool showHelp = true, bool showPagination = true, bool highlightMatches = true, int height = 10, int initialIndex = 0, Set<int>? initialSelected, String display(T)?, SearchFilterFunc<T>? filter, MultiSearchKeyMap? keyMap, SearchStyles? styles})

Properties

cursor int
no setter
display String Function(T)?
final
filteredItems List<FilteredSearchItem<T>>
no setter
hashCode int
The hash code for this object.
no setterinherited
highlightMatches bool
final
hint String
final
items List<T>
no setter
keyMap MultiSearchKeyMap
final
noResultsText String
final
placeholder String
final
query String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItems List<T>
no setter
showHelp bool
final
showHint bool
final
showPagination bool
final
showTitle bool
final
styles SearchStyles
final
title String
final

Methods

init() Cmd?
Returns an optional command to execute on program startup.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Msg msg) → (MultiSearchModel<T>, Cmd?)
Updates the component state in response to a message.
override
view() String
Renders the current model state for display.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited