NumberInputKeyMap class
Key bindings for NumberInputModel.
- Implemented types
Constructors
- NumberInputKeyMap({KeyBinding? increment, KeyBinding? decrement, KeyBinding? deleteBackward, KeyBinding? submit, KeyBinding? cancel})
- Creates a key map with default bindings.
Properties
- cancel → KeyBinding
-
Cancel the prompt.
final
- decrement → KeyBinding
-
Decrement the value by step.
final
- deleteBackward → KeyBinding
-
Delete the last typed character.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- increment → KeyBinding
-
Increment the value by step.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submit → KeyBinding
-
Submit the current value.
final
Methods
-
fullHelp(
) → List< List< KeyBinding> > -
Returns bindings for the full help view, grouped by columns.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortHelp(
) → List< KeyBinding> -
Returns bindings for the short help view.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited