fullHelp method
Returns bindings for the full help view, grouped by columns.
Each inner list represents a column of help items.
Implementation
@override
List<List<KeyBinding>> fullHelp() => [
[increment, decrement],
[deleteBackward, submit, cancel],
];