NumberInputStyles class

Visual styles for NumberInputModel.

Constructors

NumberInputStyles({Style? prompt, Style? value, Style? placeholder, Style? hint, Style? error, Style? dimmed})
Creates styles with sensible defaults.

Properties

dimmed Style
Style for dimmed/secondary text.
final
error Style
Style for validation error messages.
final
hashCode int
The hash code for this object.
no setterinherited
hint Style
Style for hint text shown below the input.
final
placeholder Style
Style for placeholder text.
final
prompt Style
Style for the label/prompt.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Style
Style for the typed value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited