OutputLogEntry class

A single entry in an OutputLog.

Captures a line of output along with its source and timestamp.

Constructors

OutputLogEntry({required String line, required OutputSource source, required DateTime timestamp})
Creates an output log entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
line String
The captured output line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source OutputSource
Where the output originated from.
final
timestamp DateTime
When the output was captured.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited