OutputSource enum

The origin of a captured output line.

Used by CapturedOutputMsg to distinguish between output that was originally written to stdout (via print()) and output written to stderr.

Inheritance
Available extensions

Values

stdout → const OutputSource

Output captured from print() / zone print handler (stdout).

stderr → const OutputSource

Output captured from stderr writes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OutputSource>
A constant List of the values in this enum, in order of their declaration.