PasteMsg class

Message sent when bracketed paste content is received.

Only available when bracketed paste mode is enabled.

Inheritance

Constructors

PasteMsg(String content)
Creates a paste message.
const

Properties

content String
The pasted text content.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override