PasteTextMsg class

Message used by the runtime to deliver collapsed large rune bursts as a single text payload (paste-like behavior).

Inheritance

Constructors

PasteTextMsg(String content)
Creates a text-paste message.
const

Properties

content String
Full pasted/inserted text payload.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override