PrimaryDeviceAttributesMsg class

Message sent when the terminal replies with primary device attributes.

Inheritance

Constructors

PrimaryDeviceAttributesMsg(List<int> attrs)
Creates a primary device attributes message.
const

Properties

attrs List<int>
The raw DA1 attribute list.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override