onSend method

Msg? onSend(
  1. Msg msg
)

Called for each message before it is queued.

Return the same message to keep it, a modified message to transform it, or null to drop it.

Implementation

Msg? onSend(Msg msg) => msg;