blockInputWhileReplay property

bool blockInputWhileReplay
final

Whether terminal input should be ignored while replay is active.

When true, stdin key/mouse/paste events are dropped while the replay stream is emitting messages. Useful for deterministic profiling.

Implementation

final bool blockInputWhileReplay;