mouse property

bool mouse
final

Whether to enable mouse tracking.

When true, mouse events (clicks, motion, wheel) are reported as MouseMsg messages.

This enables MouseMode.cellMotion unless mouseMode is set explicitly. Use MouseMode.allMotion for passive hover behavior such as tooltips, hover styling, and MouseRegion enter/exit callbacks that should fire without a mouse button being held.

Implementation

final bool mouse;