ProgramRenderMonitor class final

Higher-level render activity monitor built on the live render hook.

Inheritance

Constructors

ProgramRenderMonitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats ProgramRenderStats
Current aggregated statistics.
no setter
wantsNativeFrames bool
Whether this interceptor needs native cell snapshots after each render.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProcessed(Msg msg, Duration elapsed) → void
Called after a message has been processed.
inherited
onRendered({required int renderGeneration, required Object view, required DegradationLevel degradationLevel, required Duration renderDuration, int? width, int? height, TerminalNativeFrame? nativeFrame, TerminalNativeDeltaFrame? nativeDelta, TerminalNativeCellDeltaFrame? nativeCellDelta, List<TerminalNativeSpanDelta>? nativeSpanDelta}) → void
Called after a render has completed.
override
onSend(Msg msg) Msg?
Called for each message before it is queued.
inherited
onStart(void send(Msg msg)) → void
Called once after program initialization.
inherited
onStop() → void
Called during program cleanup.
inherited
reset() → void
Clears all accumulated render activity.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited