ProgramRenderRecorder class final

Program interceptor that records deterministic render snapshots.

Inheritance

Constructors

ProgramRenderRecorder()

Properties

hashCode int
The hash code for this object.
no setterinherited
lastSnapshot ProgramRenderSnapshot?
Most recently captured snapshot, if any.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshots List<ProgramRenderSnapshot>
Recorded snapshots in capture order.
no setter
wantsNativeFrames bool
Whether this interceptor needs native cell snapshots after each render.
no setteroverride

Methods

clear() → void
Removes all recorded snapshots and resets the local sequence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProcessed(Msg msg, Duration elapsed) → void
Called after a message has been processed.
inherited
onRendered({required int renderGeneration, required Object view, required DegradationLevel degradationLevel, required Duration renderDuration, int? width, int? height, TerminalNativeFrame? nativeFrame, TerminalNativeDeltaFrame? nativeDelta, TerminalNativeCellDeltaFrame? nativeCellDelta, List<TerminalNativeSpanDelta>? nativeSpanDelta}) → void
Called after a render has completed.
override
onSend(Msg msg) Msg?
Called for each message before it is queued.
inherited
onStart(void send(Msg msg)) → void
Called once after program initialization.
inherited
onStop() → void
Called during program cleanup.
inherited
snapshotsSince(int generation) List<ProgramRenderSnapshot>
Returns snapshots whose render generation is greater than generation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited