Projectile class

A simple projectile integrator mirroring harmonica/projectile.go.

Constructors

Projectile(double deltaTime, Point initialPosition, Vector initialVelocity, Vector initialAcceleration)

Properties

acceleration → Vector
no setter
deltaTime → double
final
hashCode → int
The hash code for this object.
no setterinherited
position → Point
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
velocity → Vector
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update() → Point
Advance one frame and return the new position.

Operators

operator ==(Object other) → bool
The equality operator.
inherited