RenderBudgetState class

The current state of a RenderBudgetController.

Constructors

RenderBudgetState({required DegradationLevel level, required Duration frameBudget, required Duration lastRenderDuration, required int overBudgetStreak, required int recoveryStreak})
Creates render budget state.
const

Properties

frameBudget Duration
The frame budget being enforced.
final
hashCode int
The hash code for this object.
no setterinherited
lastRenderDuration Duration
The last measured render duration.
final
level DegradationLevel
The active degradation level.
final
overBudgetStreak int
The current consecutive over-budget streak.
final
recoveryStreak int
The current consecutive recovery streak.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited