RenderMetricsModel class abstract

Optional interface for models that want render metrics updates.

When implemented, the runtime only starts the metrics timer if wantsRenderMetrics is true.

Constructors

RenderMetricsModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wantsRenderMetrics bool
Whether the model wants to receive render metrics updates.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited