RepaintMsg class

Message sent to force a repaint of the view.

This bypasses the skip-if-unchanged optimization and forces a full re-render of the current view.

Useful when external factors have changed the terminal state or when the view needs to be refreshed.

Inheritance

Constructors

RepaintMsg()
Creates a repaint message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited