ReplayAction class final

Replay action schema used by TUI scenario JSON files.

Constructors

ReplayAction({required String type, int repeat = 1, int ms = 0, String value = '', String key = '', String direction = 'down', int x = 0, int y = 0, int x2 = 0, int y2 = 0, int steps = 8, String eventType = '', Map<String, Object?> eventFields = const <String, Object?>{}})
const
ReplayAction.fromJson(Map<String, dynamic> json)
factory

Properties

customEvent → ReplayCustomEvent?
no setter
direction → String
final
eventFields → Map<String, Object?>
final
eventType → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
final
ms → int
final
repeat → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps → int
final
type → String
final
value → String
final
x → int
final
x2 → int
final
y → int
final
y2 → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toMessages() → List<Msg>
Expands this action into one or more low-level replay messages.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited