ReplayCoordinateInterceptor class final

Coordinate interceptor that scales replay mouse coordinates to current runtime window dimensions.

Inheritance

Constructors

ReplayCoordinateInterceptor({required int sourceWidth, required int sourceHeight, int sourceRightFixedWidth = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceHeight → int
final
sourceRightFixedWidth → int
final
sourceWidth → int
final
wantsNativeFrames → bool
Whether this interceptor needs native cell snapshots after each render.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProcessed(Msg msg, Duration elapsed) → void
Called after a message has been processed.
override
onRendered({required int renderGeneration, required Object view, required DegradationLevel degradationLevel, required Duration renderDuration, int? width, int? height, TerminalNativeFrame? nativeFrame, TerminalNativeDeltaFrame? nativeDelta, TerminalNativeCellDeltaFrame? nativeCellDelta, List<TerminalNativeSpanDelta>? nativeSpanDelta}) → void
Called after a render has completed.
inherited
onSend(Msg msg) → Msg?
Called for each message before it is queued.
override
onStart(void send(Msg msg)) → void
Called once after program initialization.
inherited
onStop() → void
Called during program cleanup.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited