ReplayEventDirective class final

Hook decision produced for ReplayCustomEvent actions.

Constructors

ReplayEventDirective.emit(Iterable<Msg> messages, {Duration delay = Duration.zero})
Continue replay and emit messages.
factory
ReplayEventDirective.quit({Iterable<Msg> messages = const <Msg>[], Duration delay = Duration.zero})
Emit QuitMsg and stop replay after optionally emitting messages.
factory
ReplayEventDirective.stop({Iterable<Msg> messages = const <Msg>[], Duration delay = Duration.zero})
Stop replay after optionally emitting messages.
factory

Properties

control ReplayEventControl
Replay control after emitting messages.
final
delay Duration
Optional delay to apply before messages are emitted.
final
hashCode int
The hash code for this object.
no setterinherited
messages List<Msg>
Optional messages to inject when this event is encountered.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

proceed → const ReplayEventDirective
Continue replay without changes.