ReplayEventMsg class final

Replay message emitted for custom event actions.

Inheritance

Constructors

ReplayEventMsg(ReplayCustomEvent event)
const

Properties

event ReplayCustomEvent
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited