ReplayHarnessConfig class final

Configuration for replay harness commands.

Constructors

ReplayHarnessConfig({String? scenarioPath, required String? tracePath, required String scriptFilter, required String sessionOut, required String? scenarioOut, required String scenarioName, required String scenarioDescription, required double speed, required int minSleepUs, required int leadInMs, required int screenWidth, required int screenHeight, required int fixedRightWidth, required bool blockInput, required bool loop, required bool keepOpen, required int timeoutSeconds, required bool convertOnly, required bool captureTrace, required String traceOut, required String traceTags, required bool captureDispatch, required int summaryCount, required int maxSpanUs, required int? traceFromUs, required int? traceToUs, required bool traceIncludeHoverMoves, String? error})
const

Properties

blockInput bool
final
captureDispatch bool
final
captureTrace bool
final
convertOnly bool
final
error String?
final
fixedRightWidth int
final
hashCode int
The hash code for this object.
no setterinherited
keepOpen bool
final
leadInMs int
final
loop bool
final
maxSpanUs int
final
minSleepUs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioDescription String
final
scenarioName String
final
scenarioOut String?
final
scenarioPath String?
final
screenHeight int
final
screenWidth int
final
scriptFilter String
final
sessionOut String
final
speed double
final
summaryCount int
final
timeoutSeconds int
final
traceFromUs int?
final
traceIncludeHoverMoves bool
final
traceOut String
final
tracePath String?
final
traceTags String
final
traceToUs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromArgResults(ArgResults parsed) ReplayHarnessConfig