ReplayMouseMsg class final

Replay-only mouse message marker.

This message still behaves as MouseMsg for model update logic, but can be targeted by ReplayCoordinateInterceptor so live terminal mouse input is not scaled.

Inheritance

Constructors

ReplayMouseMsg({required MouseAction action, required MouseButton button, required int x, required int y, bool ctrl = false, bool alt = false, bool shift = false})
const

Properties

action MouseAction
The type of mouse action.
finalinherited
alt bool
Whether Alt was held.
finalinherited
button MouseButton
The mouse button involved.
finalinherited
ctrl bool
Whether Ctrl was held.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasModifier bool
Whether any modifier key is held.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift bool
Whether Shift was held.
finalinherited
x int
The column position (0-based).
finalinherited
y int
The row position (0-based).
finalinherited

Methods

copyWith({MouseAction? action, MouseButton? button, int? x, int? y, bool? ctrl, bool? alt, bool? shift}) MouseMsg
Creates a copy of this message with some fields replaced.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited