ReplayScreen class final

Screen metadata captured for replay coordinate scaling.

Constructors

ReplayScreen({int width = 0, int height = 0, int fixedRightWidth = 0})
const
ReplayScreen.fromJson(Map<String, dynamic> json)
factory

Properties

fixedRightWidth → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited