ReplayTraceConversionOptions class final

Trace conversion options for ReplayTraceConverter.

Constructors

ReplayTraceConversionOptions({String? name, String description = 'Generated from trace', int screenWidth = 0, int screenHeight = 0, int fixedRightWidth = 0, int? fromUs, int? toUs, int minSleepUs = 30000, bool includeHoverMoves = false, bool includeCustomEvents = true})
const

Properties

description → String
final
fixedRightWidth → int
final
fromUs → int?
final
hashCode → int
The hash code for this object.
no setterinherited
includeCustomEvents → bool
final
includeHoverMoves → bool
final
minSleepUs → int
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenHeight → int
final
screenWidth → int
final
toUs → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited