ReplayTraceConversionResult class final

Conversion output returned by ReplayTraceConverter.convertFile.

Constructors

ReplayTraceConversionResult({required String tracePath, required ReplayScenario scenario, required int eventCount, required int actionCount, required int skippedCount, required int inferredScreenWidth, required int inferredScreenHeight})
const

Properties

actionCount int
final
eventCount int
final
hashCode int
The hash code for this object.
no setterinherited
inferredScreenHeight int
final
inferredScreenWidth int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenario ReplayScenario
final
skippedCount int
final
tracePath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited