SearchStyles class
Styles for the search component.
Constructors
- SearchStyles({Style? title, Style? prompt, Style? item, Style? selectedItem, Style? matchHighlight, Style? cursor, Style? dimmed, Style? noResults, Style? selectedIcon, Style? unselectedIcon, String? selectedIconChar, String? unselectedIconChar, String? cursorPrefix, String? itemPrefix})
-
Creates default styles.
factory
- SearchStyles.defaults()
-
Creates default styles.
factory
Properties
- cursor → Style
-
Style for the cursor indicator.
final
- cursorPrefix → String
-
Prefix shown before the selected item.
final
- dimmed → Style
-
Style for dimmed elements.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → Style
-
Style for unselected items.
final
- itemPrefix → String
-
Prefix shown before non-selected items.
final
- matchHighlight → Style
-
Style for matched characters.
final
- noResults → Style
-
Style for "no results" message.
final
- prompt → Style
-
Style for the search prompt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIcon → Style
-
Style for selected item icon.
final
- selectedIconChar → String
-
Character for selected items.
final
- selectedItem → Style
-
Style for the currently highlighted item.
final
- title → Style
-
Style for the title.
final
- unselectedIcon → Style
-
Style for unselected item icon.
final
- unselectedIconChar → String
-
Character for unselected items.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited