SecondaryDeviceAttributesMsg class

Message sent when the terminal replies with secondary device attributes.

Inheritance

Constructors

SecondaryDeviceAttributesMsg(List<int> attrs)
Creates a secondary device attributes message.
const

Properties

attrs List<int>
The raw DA2 attribute list.
final
dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override