ShortcutContinuation class final

One which-key row for the next key in a pending sequence.

Constructors

ShortcutContinuation({required String keyLabel, required String description, required String group, required String actionId, required ShortcutBinding binding})
const

Properties

actionId → String
final
binding → ShortcutBinding
final
description → String
final
group → String
final
hashCode → int
The hash code for this object.
no setterinherited
keyLabel → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited