SplitHandle class final

Geometry for a split handle used by resize/snap calculations.

Constructors

SplitHandle({required String splitId, required PaneSplitDirection direction, required int x, required int y, required int width, required int height})
const

Properties

boundaryX int
Horizontal (left-to-right) boundary coordinate for this split.
no setter
boundaryY int
Vertical (top-to-bottom) boundary coordinate for this split.
no setter
direction PaneSplitDirection
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitId String
final
width int
final
x int
final
y int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited