isActive property
bool
get
isActive
Whether the probe is currently active and should receive messages.
Implementation
bool get isActive;
Whether the probe is currently active and should receive messages.
bool get isActive;