StartupProbeRunner class final

Runs startup probes and optionally buffers messages while they are active.

Constructors

StartupProbeRunner(List<StartupProbe> _probes)

Properties

hasActiveProbe → bool
Whether any startup probe is currently active.
no setter
hasBufferedMessages → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wasAborted → bool
no setter

Methods

abort() → void
Aborts the currently active probe, if any.
drain(void process(Msg msg)) → void
Drains buffered messages to process.
intercept(Msg msg, StartupProbeContext ctx) → bool
Intercepts messages while any probe is active.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runAll(StartupProbeContext ctx) → Future<void>
Runs probes sequentially.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited