StringSinkTuiRenderer class

A renderer that writes to a StringSink (for testing).

Implemented types

Constructors

StringSinkTuiRenderer(StringSink sink)
Creates a renderer that writes all output to sink.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics → RenderMetrics?
Returns render performance metrics, or null if not supported.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → StringSink
The sink to write to.
final

Methods

clear() → void
Clears the rendered content.
override
dispose() → void
Disposes of renderer resources.
override
flush() → Future<void>
Flushes any buffered output.
override
initialize() → void
Initializes terminal state needed before the first render.
override
invalidate() → void
Resets internal diff / cache state so the next render call produces a full redraw, without performing any terminal I/O.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Object view) → void
Renders the view to the terminal.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited