shortHelp method
Returns bindings for the short help view.
These are displayed in a single line at the bottom of the screen.
Implementation
@override
List<KeyBinding> shortHelp() => [moveUp, moveDown, accept, cancel];
Returns bindings for the short help view.
These are displayed in a single line at the bottom of the screen.
@override
List<KeyBinding> shortHelp() => [moveUp, moveDown, accept, cancel];