SuggestSubmittedMsg class

Emitted when the user accepts a value (typed or from the dropdown).

Inheritance

Constructors

SuggestSubmittedMsg(String value)
Creates a submitted message with the accepted value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The accepted value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited