TerminalColorSchemeState class final

Tracks terminal color-scheme preference separately from terminal colors.

Constructors

TerminalColorSchemeState({bool? hasDarkColorScheme})
const

Properties

hasDarkColorScheme bool?
Whether the terminal or host prefers a dark color scheme.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Msg msg) TerminalColorSchemeState

Operators

operator ==(Object other) bool
The equality operator.
inherited