TerminalDirtySpan class

Dirty cell range captured from the UV buffer.

Constructors

TerminalDirtySpan({required int start, required int end})
Creates a dirty span snapshot.
const

Properties

end int
Exclusive end cell index.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
Inclusive start cell index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited