TerminalNativeCellDeltaFrame class

Delta snapshot containing changed cells between two native frames.

Constructors

TerminalNativeCellDeltaFrame({required int width, required int height, required List<TerminalNativeLineDelta> lines})
Creates a cell-delta snapshot.
const
TerminalNativeCellDeltaFrame.between(TerminalNativeFrame? previous, TerminalNativeFrame current)
Computes changed cells between previous and current.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
Height of the compared frames.
final
isEmpty bool
Whether this delta contains any changed cells.
no setter
lines List<TerminalNativeLineDelta>
Lines containing changed cells.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spanDeltas List<TerminalNativeSpanDelta>
Returns grouped current-value spans derived from changed cells.
no setter
width int
Width of the compared frames.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited