TerminalNativeFrame class

Native cell-buffer snapshot of rendered terminal output.

Constructors

TerminalNativeFrame({required int width, required int height, required List<TerminalNativeLine> lines})
Creates a native frame snapshot.
const
TerminalNativeFrame.fromBuffer(Buffer buffer)
Captures a native frame from a UV buffer.
factory
TerminalNativeFrame.fromScreenBuffer(ScreenBuffer screen)
Captures a native frame from a UV screen.
factory

Properties

dirtyLines List<TerminalNativeLine>
Returns only lines that carried dirty spans in the backing buffer.
no setter
hashCode int
The hash code for this object.
no setterinherited
height int
Height of the backing cell buffer.
final
lines List<TerminalNativeLine>
Captured native lines.
final
plainText String
ANSI-like textual reconstruction of the native frame.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Width of the backing cell buffer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inspect(Object view, {required int width, required int height, bool wrap = true}) TerminalNativeFrame
Renders view into a temporary UV screen buffer and captures its cells.