TerminalNativeLineDelta class

One changed line in a cell-delta snapshot.

Constructors

TerminalNativeLineDelta({required int index, required List<TerminalNativeCellDelta> cells})
Creates a line-delta snapshot.
const

Properties

cells List<TerminalNativeCellDelta>
Changed cells on this line.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Zero-based line index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited