TerminalNativeLink class

Snapshot of UV link metadata.

Constructors

TerminalNativeLink({required String url, required String params})
Creates a native link snapshot.
const
Builds a snapshot from a UV link.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isZero bool
Whether this link is empty.
no setter
params String
Link parameter string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Link target URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited