TerminalNativeSpanDelta class

Grouped span deltas for one line.

Constructors

TerminalNativeSpanDelta({required int index, required List<TerminalNativeSpan> spans})
Creates a span-delta line record.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
Zero-based line index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans List<TerminalNativeSpan>
Current-value spans reconstructed from changed cells.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited