TerminalNativeStyle class

Snapshot of UV cell style metadata.

Constructors

TerminalNativeStyle({required TerminalNativeColor? fg, required TerminalNativeColor? bg, required TerminalNativeColor? underlineColor, required UnderlineStyle underline, required int attrs, required int packedKey})
Creates a native style snapshot.
const
TerminalNativeStyle.fromStyle(UvStyle style)
Builds a snapshot from a UV style.
factory

Properties

attrs int
UV attribute bitmask.
final
bg TerminalNativeColor?
Background color, when present.
final
fg TerminalNativeColor?
Foreground color, when present.
final
hashCode int
The hash code for this object.
no setterinherited
isZero bool
Whether this style has no metadata.
no setter
packedKey int
Stable packed style key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underline UnderlineStyle
Underline mode.
final
underlineColor TerminalNativeColor?
Underline color, when present.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited