TerminalRenderLine class

Parsed representation of a rendered terminal line.

Constructors

TerminalRenderLine({required String raw, required String statePrefix})
Creates a parsed render line.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
plainText String
The ANSI-stripped visible text for this line.
no setter
raw String
Raw line content as it appeared in the rendered frame.
final
rendered String
The line as it should be rendered standalone.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statePrefix String
ANSI state that must be applied before raw when rendering this line in isolation.
final
visibleWidth int
The visible width of the rendered line.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override