TerminalState class

Terminal state snapshot for saving/restoring.

This class captures the current state of terminal modes for saving and restoring during operations like external process execution.

Constructors

TerminalState({required bool rawModeEnabled, required bool altScreenEnabled, required bool cursorHidden, required bool mouseEnabled, required bool bracketedPasteEnabled})
const
TerminalState.capture(Terminal terminal)
factory

Properties

altScreenEnabled bool
final
bracketedPasteEnabled bool
final
cursorHidden bool
final
hashCode int
The hash code for this object.
no setterinherited
mouseEnabled bool
final
rawModeEnabled bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(Terminal terminal) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited