TerminalThemeHost mixin

Mixin for models/components that want terminal theme state with minimal boilerplate.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalTheme TerminalThemeState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateTerminalTheme(Msg msg) → void
Updates terminalTheme if msg carries theme information.

Operators

operator ==(Object other) bool
The equality operator.
inherited