TertiaryDeviceAttributesMsg class

Message sent when the terminal replies with tertiary device attributes.

Inheritance

Constructors

TertiaryDeviceAttributesMsg(String value)
Creates a tertiary device attributes message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The decoded DA3 identifier string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override