setValue method

void setValue(
  1. String v
)

Sets the value of the textarea (method form for API compatibility).

This is equivalent to using the value setter and exists for parity with the upstream bubbletea Go library. Prefer using model.value = v in Dart.

Implementation

void setValue(String v) {
  value = v;
}