uppercaseSelectionOrLine method
Uppercases the selected range, or the current line when there is no selection.
Implementation
bool uppercaseSelectionOrLine() {
return _transformSelectionOrLineShared((text) => text.toUpperCase());
}
Uppercases the selected range, or the current line when there is no selection.
bool uppercaseSelectionOrLine() {
return _transformSelectionOrLineShared((text) => text.toUpperCase());
}