TextCommandResult class final

Constructors

TextCommandResult({List<String>? graphemes, required int cursorOffset, int? selectionBaseOffset, int? selectionExtentOffset, TextDocument? document, TextDocumentChange? documentChange, bool changed = true})
const

Properties

changed bool
final
cursorOffset int
final
document TextDocument?
final
documentChange TextDocumentChange?
final
explicitGraphemes List<String>?
no setter
graphemes List<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionBaseOffset int?
final
selectionExtentOffset int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited