TextDiagnosticRange class final
Constructors
- TextDiagnosticRange({required int startOffset, required int endOffset, required TextDiagnosticSeverity severity, String? code, String? message, String? source})
-
const
Properties
- code → String?
-
final
- endOffset → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → TextDiagnosticSeverity
-
final
- source → String?
-
final
- startOffset → int
-
final
Methods
-
normalized(
) → TextDiagnosticRange -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override