TextDocument class final
Constructors
- TextDocument({String text = ''})
-
TextDocument.fromFlatGraphemes(Iterable<
String> graphemes) -
TextDocument.fromLineTexts(List<
String> lineTexts, {List<int> ? lineLengths}) -
TextDocument.fromParsedLines(List<
List< lines, {bool seedLineGraphemeCaches = true})String> >
Properties
- debugDistinctSourceCount → int
-
no setter
- debugHasMaterializedLineTextCache → bool
-
no setter
- debugHasTextCache → bool
-
no setter
- debugJoinedSourceTextCount → int
-
no setter
- debugLineGraphemeCacheCount → int
-
no setter
- debugMaterializedSourceLineTextCount → int
-
no setter
- debugPieceBackedLeafCount → int
-
no setter
- debugPieceCount → int
-
no setter
- debugReferencedSourceCount → int
-
no setter
- debugSourceBackedLeafCount → int
-
no setter
- debugStorageDepth → int
-
no setter
- debugStorageSegmentCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
no setter
- lineCount → int
-
no setter
-
lines
→ List<
List< String> > -
no setter
-
lineTexts
→ List<
String> -
no setter
-
lineViews
→ List<
List< String> > -
no setter
- revision → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageIdentity → Object
-
no setter
- text → String
-
no setter
Methods
-
clampPosition(
TextPosition position) → TextPosition -
copy(
) → TextDocument -
flattenWithNewlines(
) → List< String> -
graphemeAt(
int offset) → String? -
graphemesInRange(
{required int startOffset, required int endOffset}) → List< String> -
lineAt(
int index) → String -
lineEndOffset(
int index, {bool includeTrailingNewline = false}) → int -
lineGraphemesAt(
int index) → List< String> -
lineLength(
int index) → int -
lineStartOffset(
int index) → int -
matchesOffsetRange(
{required int startOffset, required List< String> graphemes}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offsetForPosition(
TextPosition position) → int -
positionForOffset(
int offset) → TextPosition -
replaceLines(
List< List< lines) → voidString> > -
replaceLineTextRange(
{required int startLine, required int endLine, required List< String> replacementLineTexts}) → TextDocumentChange -
replaceLineTexts(
List< String> lineTexts) → void -
replaceOffsetRange(
{required int startOffset, required int endOffset, List< String> replacement = const <String>[]}) → TextDocumentChange -
replaceText(
String text) → void -
replaceTextRange(
{required int startOffset, required int endOffset, String replacement = ''}) → TextDocumentChange -
textBetweenLines(
{required int startLine, required int endLine}) → String -
textInRange(
{required int startOffset, required int endOffset}) → String -
toString(
) → String -
A string representation of this object.
inherited
-
wordBoundaryAt(
TextPosition position) → ({TextPosition end, TextPosition start})
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited