TextExtmark class final

Constructors

TextExtmark({required int id, required String type, required int startOffset, required int endOffset, bool virtual = false, String? styleKey, int priority = 0, Object? data})
const

Properties

data Object?
final
endOffset int
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
isEmpty bool
no setter
length int
no setter
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOffset int
final
styleKey String?
final
type String
final
virtual bool
final

Methods

clamp(int maxLength) TextExtmark
containsOffset(int offset) bool
normalized() TextExtmark
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override