TextHighlightRange class final

Constructors

TextHighlightRange({required int startOffset, required int endOffset})
const

Properties

endOffset int
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOffset int
final

Methods

clamp(int maxLength) TextHighlightRange
normalized() TextHighlightRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override