collapseLargePaste property
Whether very large paste payloads should be collapsed into a reference
token (e.g. [Pasted ~37 lines]) instead of inserting full text.
Implementation
bool collapseLargePaste;
Whether very large paste payloads should be collapsed into a reference
token (e.g. [Pasted ~37 lines]) instead of inserting full text.
bool collapseLargePaste;