setValue method

void setValue(
  1. String s
)

Sets the value of the text input (method form for API compatibility).

This is equivalent to using the value setter and exists for parity with the upstream bubbletea Go library. Prefer using model.value = s in Dart.

Implementation

void setValue(String s) {
  value = s;
}