TextInputStyles class

Styles for the text input.

Groups all style configuration for a TextInputModel:

  • focused: Styles applied when the input is focused
  • blurred: Styles applied when the input is not focused
  • cursor: Cursor appearance settings

Constructors

TextInputStyles({TextInputStyleState? focused, TextInputStyleState? blurred, TextInputCursorStyle? cursor})
Creates a text input styles configuration.

Properties

blurred TextInputStyleState
Styles used when the input is blurred (not focused).
getter/setter pair
cursor TextInputCursorStyle
Cursor appearance settings.
getter/setter pair
focused TextInputStyleState
Styles used when the input is focused.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited