TextLineDecoration class final

Constructors

TextLineDecoration({required int lineIndex, required String styleKey, String? lineNumberMarker, String? lineNumberStyleKey})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
lineIndex int
final
lineNumberMarker String?
final
lineNumberStyleKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleKey String
final

Methods

clamp(int lineCount) TextLineDecoration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override