TextLineStateSnapshot class final

Available extensions

Constructors

TextLineStateSnapshot({required TextPosition cursor, TextPosition? selectionBase, TextPosition? selectionExtent})
const
TextLineStateSnapshot.collapsed({required TextPosition cursor})
factory
TextLineStateSnapshot.selection({required TextPosition base, required TextPosition extent, TextPosition? cursor, bool preserveCollapsedSelection = false})
factory

Properties

cursor TextPosition
final
hashCode int
The hash code for this object.
no setterinherited
hasSelection bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection?
no setter
selectionBase TextPosition?
final
selectionExtent TextPosition?
final

Methods

clamp({required int lineCount, required int lineLength(int line), bool preserveCollapsedSelection = false}) TextLineStateSnapshot
clearSelection({TextPosition? cursor}) TextLineStateSnapshot
duplicateSelectedLinesAboveCommand(List<String> lines) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

duplicateSelectedLinesBelowCommand(List<String> lines) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

moveSelectedLinesCommand(List<String> lines, {required int direction}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renumberNumberedListCommand(List<String> lines, {int startAt = 1}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

toggleChecklistStateCommand(List<String> lines, {String checkedMarker = 'x'}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

toggleHeadingPrefixCommand(List<String> lines, {int level = 1}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

toggleLinePrefixCommand(List<String> lines, {required String prefix, bool addSpaceWhenNonEmpty = true, bool skipBlankLinesWhenChecking = true}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

toggleNumberedListCommand(List<String> lines, {int startAt = 1}) TextLineCommandResult

Available on TextLineStateSnapshot, provided by the TextLineStateCommandExtensions extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited