TextPasteChunkStep class final
Constructors
-
TextPasteChunkStep({required List<
int> runes, required int start, required int end, required int totalRunes, TextPasteSession? nextSession}) -
const
Properties
- end → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
no setter
- nextSession → TextPasteSession?
-
final
-
runes
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
final
- totalRunes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited