TextPasteController class final

Constructors

TextPasteController({TextPasteReferenceStore? references})

Properties

buffer Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPendingChunkedPaste bool
no setter
lastRef String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPendingChunkedPaste() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunked(String content, {required int chunkSize}) TextPasteChunkStep?
storeCollapsed(String content, {required int lineCount}) TextPasteReference
takeNextChunk({required int chunkSize}) TextPasteChunkStep?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited