TextPastePlan class final

Constructors

TextPastePlan({required TextPasteMode mode, required int lineCount, required int runeCount})
const

Properties

chunked bool
no setter
collapse bool
no setter
hashCode int
The hash code for this object.
no setterinherited
lineCount int
final
mode TextPasteMode
final
runeCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited