TextPasteReference class final

Constructors

TextPasteReference({required String uri, required String content, required int lineCount})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
lineCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
no setter
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited