TextPasteReferenceStore class final

Constructors

TextPasteReferenceStore()

Properties

buffer Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
lastRef String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
store(String content, {required int lineCount}) TextPasteReference
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited