TextPatternDiagnosticRule class final

Constructors

TextPatternDiagnosticRule({required String pattern, required TextDiagnosticSeverity severity, String? code, String? message, String? source, bool caseSensitive = false, bool wholeWord = false})
const

Properties

caseSensitive bool
final
code String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
pattern String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity TextDiagnosticSeverity
final
source String?
final
wholeWord bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited