TextPositionDiagnosticRange class final

Constructors

TextPositionDiagnosticRange({required int startLine, required int startColumn, required int endLine, required int endColumn, required TextDiagnosticSeverity severity, String? code, String? message, String? source})
const

Properties

code String?
final
endColumn int
final
endLine int
final
hashCode int
The hash code for this object.
no setteroverride
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity TextDiagnosticSeverity
final
source String?
final
startColumn int
final
startLine int
final

Methods

clamp(TextDocument document) TextPositionDiagnosticRange
normalized() TextPositionDiagnosticRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOffsetRange(TextDocument document) TextDiagnosticRange
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override