TextSyntaxBuildResult<State> class final

Constructors

TextSyntaxBuildResult({required List<TextDecorationRange> decorations, State? state})
const
TextSyntaxBuildResult.patch({required TextSyntaxDecorationPatch? patch, State? state})
const

Properties

decorations List<TextDecorationRange>
final
hashCode int
The hash code for this object.
no setterinherited
patch TextSyntaxDecorationPatch?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → State?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited