TextSyntaxProvider<State> class abstract

Constructors

TextSyntaxProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(String text, {TextDocument? document, String? language, TextSyntaxSnapshot<State>? previous, TextDocumentChange? change}) TextSyntaxBuildResult<State>
buildDocument(TextDocument document, {String? language, TextSyntaxSnapshot<State>? previous, TextDocumentChange? change}) TextSyntaxBuildResult<State>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited