TextSyntaxSnapshot<State> class final

Constructors

TextSyntaxSnapshot({String? text, required List<TextDecorationRange> decorations, required String? language, TextDocument? document, State? state, TextDocumentChange? change})

Properties

change TextDocumentChange?
final
decorations List<TextDecorationRange>
final
document TextDocument?
final
hashCode int
The hash code for this object.
no setterinherited
language String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → State?
final
text String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited