TextVisualCursorPosition class final

Constructors

TextVisualCursorPosition({required int visualRow, required int column, required int displayColumn, required int startOffset, required int endOffset})
const

Properties

column int
final
displayColumn int
final
endOffset int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOffset int
final
visualRow int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited