TraceEventType class final
Structured trace event names emitted by TuiTrace.event.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- inputBatch → const String
- Batch of parsed input messages from either the UV or key parser.
- windowSize → const String
- Terminal window size observed by the runtime.