inputBatch constant
String
const inputBatch
Batch of parsed input messages from either the UV or key parser.
Implementation
static const String inputBatch = 'input.batch';
Batch of parsed input messages from either the UV or key parser.
static const String inputBatch = 'input.batch';