TraceSessionSelection class final

Selected trace session information.

Constructors

TraceSessionSelection({required String sourcePath, required String outPath, required int sessionIndex, required int sessionCount, required int startLine, required int endLine, required String? script})
const

Properties

endLine → int
final
hashCode → int
The hash code for this object.
no setterinherited
outPath → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → String?
final
sessionCount → int
final
sessionIndex → int
final
sourcePath → String
final
startLine → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited