TraceSessionSplit class final

Session data from splitting trace logs.

Constructors

TraceSessionSplit({required int index, required int startLine, required int endLine, required List<String> lines})
const

Properties

endLine int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
lines List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script String?
no setter
startLine int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited