UndoCommandJournalEntry class final

Journal envelope for one command or transaction.

Constructors

UndoCommandJournalEntry({required String type, Map<String, Object?> payload = const <String, Object?>{}})
Creates a serializable journal entry.
const
UndoCommandJournalEntry.fromJson(Map<String, Object?> json)
Creates a journal entry from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, Object?>
Serialized command payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Command kind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this entry.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited