undo abstract method
void
undo(
- State state
Restores state to the value before this command ran.
Implementation
void undo(State state);
Restores state to the value before this command ran.
void undo(State state);