degradation property
Optional degraded content stages used by the runtime when render frames exceed the configured budget.
Implementation
final ViewDegradation? degradation;
Optional degraded content stages used by the runtime when render frames exceed the configured budget.
final ViewDegradation? degradation;