ViewportKeyMap class

Key bindings for viewport navigation.

Implemented types

Constructors

ViewportKeyMap({KeyBinding? pageDown, KeyBinding? pageUp, KeyBinding? halfPageUp, KeyBinding? halfPageDown, KeyBinding? down, KeyBinding? up, KeyBinding? left, KeyBinding? right, KeyBinding? copy})
Creates a key mapping configuration for viewport navigation.

Properties

copy KeyBinding
Key binding for copying selected text.
final
down KeyBinding
Key binding for scrolling one line down.
final
halfPageDown KeyBinding
Key binding for scrolling half a page down.
final
halfPageUp KeyBinding
Key binding for scrolling half a page up.
final
hashCode int
The hash code for this object.
no setterinherited
left KeyBinding
Key binding for scrolling left.
final
pageDown KeyBinding
Key binding for scrolling one page down.
final
pageUp KeyBinding
Key binding for scrolling one page up.
final
Key binding for scrolling right.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
up KeyBinding
Key binding for scrolling one line up.
final

Methods

fullHelp() List<List<KeyBinding>>
Returns bindings for the full help view, grouped by columns.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortHelp() List<KeyBinding>
Returns bindings for the short help view.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited