WindowPixelSizeMsg class

Message sent when the terminal window reports its pixel dimensions.

This comes from xterm-style window operation replies such as CSI 4 ; h ; w t or the pixel-size half of in-band CSI 48 ; rows ; cols ; height ; width t reports when UV input decoding is enabled.

Inheritance

Constructors

WindowPixelSizeMsg(int width, int height)
Creates a window pixel-size message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
height int
The window height in pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The window width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override