WindowSizeMsg class

Message sent when the terminal window is resized.

Contains the new dimensions of the terminal in columns (width) and rows (height).

Example

@override
(Model, Cmd?) update(Msg msg) {
  return switch (msg) {
    WindowSizeMsg(:final width, :final height) =>
      (copyWith(termWidth: width, termHeight: height), null),
    _ => (this, null),
  };
}
Inheritance

Constructors

WindowSizeMsg(int width, int height)
Creates a window size message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
height int
The terminal height in rows.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The terminal width in columns.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override