isZero property
bool
get
isZero
Returns true if this zone info represents an unknown/invalid zone.
Implementation
bool get isZero => id.isEmpty;
Returns true if this zone info represents an unknown/invalid zone.
bool get isZero => id.isEmpty;