run method
Runs the scanner and returns the input with markers stripped.
Implementation
String run() {
while (true) {
final state = _scanMain();
if (state == null) break;
}
return input;
}
Runs the scanner and returns the input with markers stripped.
String run() {
while (true) {
final state = _scanMain();
if (state == null) break;
}
return input;
}