Attr class abstract final

Text attributes (bitmask).

Upstream: third_party/ultraviolet/cell.go (AttrBold, AttrFaint, ...).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bold → const int
conceal → const int
faint → const int
italic → const int
reverse → const int
strikethrough → const int