line method

Line? line(
  1. int y
)

Returns the line at y, or null if out of bounds.

Returns the line at y, or null if out of bounds.

Implementation

Line? line(int y) => (y < 0 || y >= lines.length) ? null : lines[y];