setCellOwned method

void setCellOwned(
  1. int x,
  2. int y,
  3. Cell? cell
)

Sets the cell at (x, y) and consumes ownership of cell.

The cell is disposed when the write is rejected because it is out of bounds, outside the active scissor, or equal to the existing cell. Call setCell when the cell is borrowed or may be reused.

Implementation

void setCellOwned(int x, int y, Cell? cell) =>
    _setCell(x, y, cell, takeOwnership: true);