BufferRenderSink class final

A render sink that owns double-buffered render targets.

This lets you customize render targets (via bufferFactory) and apply filters without mutating the original Buffer.

Constructors

BufferRenderSink({int width = 0, int height = 0, BufferFactory? bufferFactory})

Properties

buffer Buffer
The last rendered buffer (front buffer).
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Buffer source, List<BufferFilter> filters, {double dt = 0}) Buffer
Render source through filters into this sink.
resize(int width, int height) → void
Resize internal buffers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited