CancelReader class

CancelReader provides a cancelable reader interface.

Constructors

CancelReader(Stream<List<int>> _source)
Creates a new CancelReader from the given source.
CancelReader.stdin()
Creates a new CancelReader from stdin.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isCanceled bool
Returns true if the reader has been canceled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<List<int>>
Returns a stream of data from the reader.
no setter

Methods

cancel() Future<void>
Cancels the reader.
close() Future<void>
Closes the reader and cleans up resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Starts reading from the source.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited