cancel method
Cancels the reader.
Returns a future that completes when the reader is successfully canceled.
Implementation
Future<void> cancel() async {
_isCanceled = true;
await _subscription?.cancel();
_subscription = null;
}
Cancels the reader.
Returns a future that completes when the reader is successfully canceled.
Future<void> cancel() async {
_isCanceled = true;
await _subscription?.cancel();
_subscription = null;
}