empty method
void
empty()
Sets this cell to a space with width 1.
Implementation
void empty() {
_releasePooledContent();
_width = 1;
_contentKind = _CellContentKind.space;
_contentValue = 0;
}
Sets this cell to a space with width 1.
void empty() {
_releasePooledContent();
_width = 1;
_contentKind = _CellContentKind.space;
_contentValue = 0;
}