linkId property
int?
get
linkId
The pooled link id for this cell, if any.
This is primarily useful for diagnostics and tests.
Implementation
int? get linkId => _linkId == 0 ? null : _linkId;
The pooled link id for this cell, if any.
This is primarily useful for diagnostics and tests.
int? get linkId => _linkId == 0 ? null : _linkId;