outputWidth property
int
get
outputWidth
Width used by terminal diff traversal and cursor accounting.
Implementation
int get outputWidth => diffOption.width ?? _width;
Width used by terminal diff traversal and cursor accounting.
int get outputWidth => diffOption.width ?? _width;