ClearAreaScreen class abstract

Optional fast-path: clear an area of the screen.

Upstream: third_party/ultraviolet/screen (ClearArea).

Implemented types

Constructors

ClearAreaScreen()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bounds() Rectangle
Returns the screen bounds as a Rectangle.
inherited
cellAt(int x, int y) Cell?
Returns the cell at (x, y) or null if out of bounds.
inherited
clearArea(Rectangle area) → void
Clears area of the screen to empty cells.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCell(int x, int y, Cell? cell) → void
Sets the cell at (x, y) to cell.
inherited
toString() String
A string representation of this object.
inherited
widthMethod() WidthMethod
Returns the active grapheme width measurement method.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited