ClipboardEvent class final

Clipboard selection and content (OSC 52).

Inheritance

Constructors

ClipboardEvent({String content = '', int selection = ClipboardSelection.none})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection int
final

Methods

clipboard() int
Returns the clipboard selection value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited