ColorPaletteEvent class final

Palette color report for an index.

Inheritance

Constructors

ColorPaletteEvent(int index, UvRgb? color)
const

Properties

color UvRgb?
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited