CompositeFilter class
Runs multiple filters as one reusable filter.
This is useful for packaging opinionated looks such as CRT-style or atmosphere-style presets without requiring every caller to manually build a filter stack at each render site.
- Inheritance
-
- Object
- BufferFilter
- CompositeFilter
Constructors
-
CompositeFilter(List<
BufferFilter> filters)
Properties
-
filters
→ List<
BufferFilter> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Buffer source, Buffer target, double dt) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited