Cursor class

Represents a cursor on the terminal screen.

A cursor has a position, an optional color, a shape, and a blink state.

Upstream: third_party/ultraviolet/uv.go (Cursor).

Constructors

Cursor({required Position position, Object? color, CursorShape shape = CursorShape.block, bool blink = true})
Cursor.at(int x, int y)
Returns a new cursor with default settings at the given position.
factory

Properties

Whether the cursor should blink.
getter/setter pair
color Object?
Color of the cursor (opaque; type is consumer-defined).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position Position
Position of the cursor on the screen.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape CursorShape
Shape of the cursor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited