Drawable can draw itself into a Screen.
Upstream: third_party/ultraviolet/buffer.go (Drawable).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bounds(
) → Rectangle - Returns the bounds required to draw this drawable.
-
draw(
Screen screen, Rectangle area) → void -
Draws this drawable into
screenwithinarea. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited