EventDecoder class final

A high-performance ANSI input decoder.

It decodes raw byte sequences from the terminal into structured Events, including key presses, mouse movements, and terminal responses.

Constructors

EventDecoder({LegacyKeyEncoding? legacy, bool useTerminfo = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
legacy ↔ LegacyKeyEncoding
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useTerminfo ↔ bool
getter/setter pair

Methods

decode(List<int> buf, {bool allowIncompleteEsc = false}) → (int, Event?)
Decode the first event in buf.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseControl(int b) → Event
parseUtf8(List<int> buf) → (int, Event?)
parseUtf8At(List<int> buf, int offset) → (int, Event?)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited