ITerm2ImageDrawable class final

A Drawable that renders an image using the iTerm2 Image Protocol.

This drawable uses the iTerm2 inline image protocol to display high-resolution images in compatible terminals. It supports scaling to a specific number of columns and rows.

Implemented types

Constructors

ITerm2ImageDrawable(Image image, {String? name, int? columns, int? rows})

Properties

columns → int?
final
hashCode → int
The hash code for this object.
no setterinherited
image → Image
final
name → String?
final
rows → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bounds() → Rectangle
Returns the bounds required to draw this drawable.
override
draw(Screen screen, Rectangle area) → void
Draws this drawable into screen within area.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited