Key class final

UV-style key event.

Constructors

Key({String text = '', int mod = 0, required int code, int shiftedCode = 0, int baseCode = 0, bool isRepeat = false})
const

Properties

baseCode int
final
code int
final
hashCode int
The hash code for this object.
no setteroverride
isRepeat bool
final
mod int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftedCode int
final
text String
final

Methods

keystroke() String
matchString(String s, [String? s2, String? s3, String? s4, String? s5]) bool
matchStrings(Iterable<String> patterns) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override