KeyboardEnhancementsEvent class final

Kitty keyboard enhancements support report.

Inheritance

Constructors

KeyboardEnhancementsEvent(int flags)
const

Properties

flags → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsKeyDisambiguation → bool
no setter
supportsKeyReleases → bool
no setter
supportsUniformKeyLayout → bool
no setter

Methods

contains(int enhancements) → bool
Returns whether all enhancements bits are present in flags.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited