id property
Unique image identifier used for caching and later deletion.
Auto-assigned if not provided at construction time.
Implementation
final int id;
Unique image identifier used for caching and later deletion.
Auto-assigned if not provided at construction time.
final int id;