KittyOptions class final

Options parsed from a Kitty graphics report.

Constructors

KittyOptions({String action = '', int id = 0, int number = 0, int quiet = 0})
const

Properties

action String
Kitty graphics action (a=), e.g. t for transmit.
final
hashCode int
The hash code for this object.
no setteroverride
id int
Image id (i=).
final
number int
Image number (I=).
final
quiet int
Quiet level (q=).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override