Layer class final

Layer represents a visual layer with content and positioning.

Constructors

Layer(Drawable drawable, [List<Layer> layers = const []])

Properties

drawable ↔ Drawable
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
id ↔ String
getter/setter pair
layers → List<Layer>
Child layers attached to this layer.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair
z ↔ int
getter/setter pair

Methods

addLayers(List<Layer> layers) → Layer
Adds layers as children of this layer.
getLayer(String lookupId) → Layer?
Returns the first layer with lookupId, searching descendants.
maxZ() → int
Returns the maximum z-order in this subtree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setId(String value) → Layer
Sets the stable id used for lookup and hit testing.
setX(int value) → Layer
Sets the horizontal position in cells.
setY(int value) → Layer
Sets the vertical position in cells.
setZ(int value) → Layer
Sets the z-order for this layer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited