LayerHit class final

Constructors

LayerHit({String id = '', Layer? layer, Rectangle? bounds})
const

Properties

bounds → Rectangle?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isEmpty → bool
Whether this hit contains no layer.
no setter
layer → Layer?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited