Link class final

Terminal hyperlink metadata (OSC 8).

Carries a target url and optional params for terminals supporting OSC 8 hyperlinks.

Constructors

Link({String url = '', String params = ''})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isZero → bool
Whether this link has no URL or parameters.
no setter
params → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override