OwnedCellScreen class abstract

Optional fast-path: set a cell that the caller will not reuse.

Implementations may take ownership of cell instead of cloning it. Use this only for freshly created cells that are not shared with another screen or line.

Implemented types

Constructors

OwnedCellScreen()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bounds() Rectangle
Returns the screen bounds as a Rectangle.
inherited
cellAt(int x, int y) Cell?
Returns the cell at (x, y) or null if out of bounds.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCell(int x, int y, Cell? cell) → void
Sets the cell at (x, y) to cell.
inherited
setCellOwned(int x, int y, Cell? cell) → void
Sets the cell at (x, y) and may take ownership of cell.
toString() String
A string representation of this object.
inherited
widthMethod() WidthMethod
Returns the active grapheme width measurement method.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited