PackedCell class final

Fixed-size packed representation of a Cell.

This is structured into four machine-word lanes so it can be compared as a small SIMD-sized tuple in hot diff paths.

Constructors

PackedCell({required int word0, required int word1, required int word2, required int word3})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
word0 int
final
word1 int
final
word2 int
final
word3 int
final
words List<int>
Returns a copy of the words as a fixed-length list for compact inspection.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override