ProgressBar class final

A progress bar state + value.

The value is clamped to 0..100 and is ignored when state is ProgressBarState.none or ProgressBarState.indeterminate.

Constructors

ProgressBar(ProgressBarState state, int value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ProgressBarState
final
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited