Side class final

UvBorder primitives.

Upstream: third_party/ultraviolet/border.go.

Constructors

Side({String content = '', UvStyle style = const UvStyle(), Link link = const Link()})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style UvStyle
final

Methods

copyWith({String? content, UvStyle? style, Link? link}) Side
Returns a copy of this side with updated fields.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited