copyWith method
Returns a copy of this side with updated fields.
Implementation
Side copyWith({String? content, UvStyle? style, Link? link}) => Side(
content: content ?? this.content,
style: style ?? this.style,
link: link ?? this.link,
);
Returns a copy of this side with updated fields.
Side copyWith({String? content, UvStyle? style, Link? link}) => Side(
content: content ?? this.content,
style: style ?? this.style,
link: link ?? this.link,
);