SizeNotifier class

Stub SizeNotifier for platforms without SIGWINCH.

Constructors

SizeNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<void>
Stream that receives terminal size change notifications.
no setter

Methods

getSize() → (int, int)
Returns the current cell size of the terminal window.
getWindowSize() → ({({int height, int width}) cells, ({int height, int width}) pixels})
Returns the current size of the terminal window in cells and pixels.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Starts listening for window size changes.
stop() Future<void>
Stops the notifier and cleans up resources.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited