prependString method
Adds the given string to the top of the terminal screen.
Implementation
void prependString(String s) {
_prepend.add(s);
}
Adds the given string to the top of the terminal screen.
void prependString(String s) {
_prepend.add(s);
}