toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer();
  buf.writeln('TerminalCapabilities(');
  buf.writeln('  hasKittyGraphics: $hasKittyGraphics,');
  buf.writeln('  hasSixel: $hasSixel,');
  buf.writeln('  hasITerm2: $hasITerm2,');
  buf.writeln('  hasKeyboardEnhancements: $hasKeyboardEnhancements,');
  buf.writeln('  primaryAttributes: $primaryAttributes,');
  buf.writeln('  backgroundColor: ${backgroundColor ?? "null"},');
  if (palette.isEmpty) {
    buf.writeln('  palette: {}');
  } else {
    buf.writeln('  palette: {');
    palette.forEach((index, color) {
      buf.writeln('    $index: $color,');
    });
    buf.writeln('  }');
  }
  buf.writeln(')');
  return buf.toString();
}