displayRows property
int
get
displayRows
Display height in terminal cells, clamped to a usable minimum.
Implementation
int get displayRows => math.max(1, rows ?? 1);
Display height in terminal cells, clamped to a usable minimum.
int get displayRows => math.max(1, rows ?? 1);