displaysImage property
bool
get
displaysImage
Whether this sequence displays graphics at the current cursor location.
Implementation
bool get displaysImage => action == 'T' || action == 'p';
Whether this sequence displays graphics at the current cursor location.
bool get displaysImage => action == 'T' || action == 'p';