TerminalGraphicsFrame class final

Retained graphics state visible in a rendered frame.

Constructors

TerminalGraphicsFrame({required bool hasRetainedGraphics, required Set<int> retainedImageIds, int untrackedGraphicsFingerprint = 0})
const
TerminalGraphicsFrame.scan(String value)
Scans value for retained graphics visible in the frame.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasRetainedGraphics → bool
Whether this frame contains retained terminal graphics.
final
retainedImageIds → Set<int>
Retained image IDs displayed by this frame.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
untrackedGraphicsFingerprint → int
Stable-in-process fingerprint for retained graphics without image IDs.
final

Methods

deletionSequencesSince(TerminalGraphicsFrame previous, {int quiet = 2}) → Iterable<String>
Deletion sequences needed before rendering this frame after previous.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const TerminalGraphicsFrame
Empty retained graphics frame.