TerminalRenderer class abstract

Abstract base class for UV terminal renderers.

TerminalRenderer defines the interface that both the ANSI terminal renderer (UvTerminalRenderer) and the canvas renderer (CanvasTerminalRenderer) implement.

Constructors

TerminalRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
lastFlushedOutput String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableBracketedPaste() → void
disableFocusReporting() → void
disableMouseAllEvents() → void
enableBracketedPaste() → void
enableFocusReporting() → void
enableMouseAllEvents() → void
enterAltScreen() → void
erase() → void
exitAltScreen() → void
flush() → void
height() int
hideCursor() → void
moveTo(int x, int y) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
popKeyboardEnhancements() → void
prependString(Buffer newbuf, String str) → void
pushKeyboardEnhancements(int flags) → void
queryBackgroundColor() → void
queryColorScheme() → void
queryCursorColor() → void
queryForegroundColor() → void
queryKeyboardEnhancements() → void
queryKittyGraphics() → void
queryPrimaryDeviceAttributes() → void
querySecondaryDeviceAttributes() → void
queryTerminalVersion() → void
queryTertiaryDeviceAttributes() → void
render(Buffer newbuf) → void
resize(int width, int height) → void
setBackspace(bool v) → void
setColorProfile(Profile profile) → void
setFullscreen(bool v) → void
setHasTab(bool v) → void
setLogger(void logger(String message)?) → void
setRelativeCursor(bool v) → void
setScrollOptim(bool v) → void
setSynchronizedOutput(bool v) → void
setTabStops(int width) → void
showCursor() → void
toString() String
A string representation of this object.
inherited
width() int
writeString(String s) int

Operators

operator ==(Object other) bool
The equality operator.
inherited