UvCellPaint class final

Effective colors for one cell, after attributes and palette resolution.

Constructors

UvCellPaint({required UvRgb foreground, required UvRgb background, required UvRgb underlineColor})
const

Properties

background → UvRgb
final
foreground → UvRgb
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underlineColor → UvRgb
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited