UvRgb class final

24-bit RGBA color.

Inheritance

Constructors

UvRgb(int r, int g, int b, {int a = 255})
const

Properties

a → int
final
b → int
final
g → int
final
hashCode → int
The hash code for this object.
no setteroverride
r → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override