UvStyle class final

Style attributes for a terminal Cell.

Constructors

UvStyle({UvColor? fg, UvColor? bg, UvColor? underlineColor, UnderlineStyle underline = UnderlineStyle.none, int attrs = 0})
const

Properties

attrs → int
final
bg → UvColor?
final
fg → UvColor?
final
hashCode → int
The hash code for this object.
no setteroverride
isZero → bool
Whether this style has no attributes or colors set.
no setter
packedKey → int
A compact metadata fingerprint for this style.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underline → UnderlineStyle
final
underlineColor → UvColor?
final

Methods

copyWith({UvColor? fg, bool clearFg = false, UvColor? bg, bool clearBg = false, UvColor? underlineColor, bool clearUnderlineColor = false, UnderlineStyle? underline, int? attrs}) → UvStyle
Returns a copy of this style with selected fields updated.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override