setHasTab method
Configures whether horizontal tab can be used for cursor movement.
Implementation
void setHasTab(bool v) {
if (v) {
_caps |= _Cap.ht;
} else {
_caps &= ~_Cap.ht;
}
}
Configures whether horizontal tab can be used for cursor movement.
void setHasTab(bool v) {
if (v) {
_caps |= _Cap.ht;
} else {
_caps &= ~_Cap.ht;
}
}