WindowOpEvent class final

Window operation report (OSC 7/11/… payloads).

Inheritance

Constructors

WindowOpEvent({required int op, required List<int> args})
const

Properties

args → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
op → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited