Alignment class

Constructors

Alignment(double x, double y)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bottomCenter → const Alignment
bottomLeft → const Alignment
bottomRight → const Alignment
center → const Alignment
centerLeft → const Alignment
centerRight → const Alignment
topCenter → const Alignment
topLeft → const Alignment
topRight → const Alignment