AlwaysStoppedAnimation<T> class

An Animation that is always stopped at a given value.

Useful as a default or placeholder animation.

Inheritance

Constructors

AlwaysStoppedAnimation(T _value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isAnimating bool
Whether this animation is currently running (forward or reverse).
no setterinherited
isCompleted bool
Whether this animation is stopped at the end.
no setterinherited
isDismissed bool
Whether this animation is stopped at the beginning.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AnimationStatus
The current status of this animation.
no setteroverride
value → T
The current value of the animation.
no setteroverride

Methods

addListener(void listener()) → void
Register listener to be called when the object notifies.
override
addStatusListener(AnimationStatusListener listener) → void
Registers a listener that is called when the animation status changes.
override
drive<U>(Animatable<U> child) Animation<U>
Chains this animation with an Animatable to produce a derived Animation of a different type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener()) → void
Remove a previously registered listener.
override
removeStatusListener(AnimationStatusListener listener) → void
Removes a previously registered status listener.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited