transform abstract method

T transform(
  1. double t
)

Returns the value of this animatable at the given t.

t is typically in the range 0.0 to 1.0 but may extend beyond that range for curves that overshoot.

Implementation

T transform(double t);