child property

Widget? child
final

An optional child widget that does not depend on the animation.

This is passed through to the builder callback. If a subtree does not change based on the animation value, it's more efficient to build it once and pass it here rather than rebuilding it on every animation frame.

Implementation

final Widget? child;