id property
Object
get
id
The unique identity of this controller, used to match tick messages.
Implementation
Object get id => _id;
The unique identity of this controller, used to match tick messages.
Object get id => _id;