unregisterAnimationController method

bool unregisterAnimationController(
  1. AnimationController controller
)

Unregisters a controller so it no longer receives tick dispatch and is no longer automatically disposed.

Returns true if the controller was found and removed.

Implementation

bool unregisterAnimationController(AnimationController controller) {
  return _controllers.remove(controller);
}