AnimationStyle class

Configurable animation durations and curves for route transitions.

Matches Flutter's AnimationStyle API for route animations.

AnimationStyle(
  duration: Duration(milliseconds: 150),
  curve: Curves.easeOut,
)

Constructors

AnimationStyle({Duration? duration, Duration? reverseDuration, Curve? curve, Curve? reverseCurve})
Creates an AnimationStyle with the given properties.
const

Properties

curve Curve?
The curve of the forward (appearance) transition.
final
duration Duration?
The duration of the forward (appearance) transition.
final
hashCode int
The hash code for this object.
no setteroverride
reverseCurve Curve?
The curve of the reverse (dismissal) transition.
final
reverseDuration Duration?
The duration of the reverse (dismissal) transition.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

defaults → const AnimationStyle
An animation style with default values.