defaults constant

AnimationStyle const defaults

An animation style with default values.

Consumers that accept an AnimationStyle parameter usually have their own fallback defaults when fields are null. Use this constant when you need to explicitly opt into defaults without specifying custom values.

Implementation

static const AnimationStyle defaults = AnimationStyle._defaults();