currentStepIndex property
int
get
currentStepIndex
Zero-based index of the currently active step, or -1 when idle.
Implementation
int get currentStepIndex => _currentStepIndex;
Zero-based index of the currently active step, or -1 when idle.
int get currentStepIndex => _currentStepIndex;