AnimationTimelineStep.callback constructor

AnimationTimelineStep.callback(
  1. TimelineStepCallback callback, {
  2. String? label,
})

Runs synchronous orchestration logic as one timeline step.

The callback may return a Cmd that will be merged with the command used to start the following step when this callback completes immediately.

Implementation

factory AnimationTimelineStep.callback(
  TimelineStepCallback callback, {
  String? label,
}) = _CallbackStep;