AnimationTimelineStep.forward constructor

AnimationTimelineStep.forward(
  1. AnimationController controller, {
  2. String? label,
  3. double? from,
  4. double? reverseFrom,
  5. Curve curve,
  6. Curve? reverseCurve,
})

Runs an AnimationController toward its upper bound.

When the timeline is playing in reverse, this step automatically runs the same controller back toward its lower bound.

Implementation

factory AnimationTimelineStep.forward(
  AnimationController controller, {
  String? label,
  double? from,
  double? reverseFrom,
  Curve curve,
  Curve? reverseCurve,
}) = _ControllerForwardStep;