themeMode property
Controls whether the shell follows the terminal background or forces a specific light/dark theme choice.
Implementation
final ThemeMode themeMode;
Controls whether the shell follows the terminal background or forces a specific light/dark theme choice.
final ThemeMode themeMode;