getGlyph method
Get the glyph for a character, or a fallback if not found.
Implementation
AsciiGlyph getGlyph(String char) {
return glyphs[char.toUpperCase()] ??
glyphs[char] ??
_createFallbackGlyph(char);
}
Get the glyph for a character, or a fallback if not found.
AsciiGlyph getGlyph(String char) {
return glyphs[char.toUpperCase()] ??
glyphs[char] ??
_createFallbackGlyph(char);
}