AsciiGlyph class
Represents a single ASCII art character glyph.
Constructors
-
AsciiGlyph(List<
String> lines) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The height of this glyph in lines.
no setter
-
lines
→ List<
String> -
The lines that make up this glyph.
Each line should have the same width for proper rendering.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
The width of this glyph in characters.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited