AsyncSnapshot<T> class final

Constructors

AsyncSnapshot.nothing()
const
AsyncSnapshot.withData(AsyncConnectionState state, T data)
const
AsyncSnapshot.withError(AsyncConnectionState state, Object error, [StackTrace? stackTrace])
const

Properties

connectionState AsyncConnectionState
final
data → T?
final
error Object?
final
hasData bool
no setter
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final

Methods

inState(AsyncConnectionState state) AsyncSnapshot<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited