BorderRadius class

Constructors

BorderRadius.all(int radius)
const
BorderRadius.only({int topLeft = 0, int topRight = 0, int bottomLeft = 0, int bottomRight = 0})
const

Properties

bottomLeft int
final
bottomRight int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft int
final
topRight int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited