loosen method
Returns a copy with the minimum constraints removed (set to zero), keeping the maximum constraints unchanged.
Implementation
BoxConstraints loosen() {
return BoxConstraints(maxWidth: maxWidth, maxHeight: maxHeight);
}
Returns a copy with the minimum constraints removed (set to zero), keeping the maximum constraints unchanged.
BoxConstraints loosen() {
return BoxConstraints(maxWidth: maxWidth, maxHeight: maxHeight);
}