BoxDecoration class

Inheritance

Constructors

BoxDecoration({Color? color, Border? border, BorderRadius? borderRadius, Gradient? gradient})
const

Properties

border Border?
final
borderRadius BorderRadius?
final
color Color?
finalinherited
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited