BoxFit enum
How an image should be inscribed into a box.
Values
- fill → const BoxFit
-
Fill the target box by distorting the aspect ratio.
- contain → const BoxFit
-
As large as possible while fully contained in the box (letterboxed).
- cover → const BoxFit
-
As small as possible while covering the entire box (cropped).
- fitWidth → const BoxFit
-
Scale to match the box width, height may overflow or be smaller.
- fitHeight → const BoxFit
-
Scale to match the box height, width may overflow or be smaller.
- none → const BoxFit
-
No scaling; display at natural size.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited