hadBuildThisFrame property

bool get hadBuildThisFrame

Whether any elements were rebuilt during the current frame's build phase.

Set to true at the start of beginFrame if there are dirty elements, then cleared in endFrame. Render objects can check this to decide whether cached paint output is still valid.

Implementation

bool get hadBuildThisFrame => _hadBuildThisFrame;