hasPaintDirty property
bool
get
hasPaintDirty
Whether a repaint has been requested for the current frame.
Implementation
bool get hasPaintDirty => _needsPaint;
Whether a repaint has been requested for the current frame.
bool get hasPaintDirty => _needsPaint;