queueMountInitCmd method
Queues an init command produced by a newly mounted element.
Implementation
void queueMountInitCmd(Cmd? cmd) {
if (!_captureMountInitCmds || cmd == null) return;
_pendingMountInitCmds.add(cmd);
}
Queues an init command produced by a newly mounted element.
void queueMountInitCmd(Cmd? cmd) {
if (!_captureMountInitCmds || cmd == null) return;
_pendingMountInitCmds.add(cmd);
}