scheduleBuildFor method
Schedules element to rebuild in the next build scope.
Implementation
void scheduleBuildFor(Element element) {
_dirty.add(element);
}
Schedules element to rebuild in the next build scope.
void scheduleBuildFor(Element element) {
_dirty.add(element);
}