Number of rows to drop from the top before applying height. This lets ClipRect render a middle band [top, top + height) of the child, which is useful for scrolling a tall child through a fixed window.
[top, top + height)
final int? top;