group property
Group name for section headers. Items with the same group are displayed under a shared header.
Implementation
final String? group;
Group name for section headers. Items with the same group are displayed under a shared header.
final String? group;