Cubic class
A cubic Bezier curve defined by two control points.
The curve passes through (0,0) and (1,1).
Properties
- a → double
-
The x coordinate of the first control point.
final
- b → double
-
The y coordinate of the first control point.
final
- c → double
-
The x coordinate of the second control point.
final
- d → double
-
The y coordinate of the second control point.
final
- flipped → Curve
-
Returns a new curve that is the reverse of this one.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transform(
double t) → double -
Returns the value of the curve at point
t.inherited -
transformInternal(
double t) → double -
Override this method to define the curve's behavior.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited