Curve class abstract

A mapping of the unit interval to the unit interval.

A curve must map t=0.0 to 0.0 and t=1.0 to 1.0.

Constructors

Curve()
const

Properties

flipped Curve
Returns a new curve that is the reverse of this one.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
transform(double t) double
Returns the value of the curve at point t.
transformInternal(double t) double
Override this method to define the curve's behavior.

Operators

operator ==(Object other) bool
The equality operator.
inherited