flipped property
Curve
get
flipped
Returns a new curve that is the reverse of this one.
Implementation
Curve get flipped => FlippedCurve(this);
Returns a new curve that is the reverse of this one.
Curve get flipped => FlippedCurve(this);