decelerate constant
Curve
const decelerate
A curve where the rate of change starts out quickly and then decelerates.
Implementation
static const Curve decelerate = _DecelerateCurve();
A curve where the rate of change starts out quickly and then decelerates.
static const Curve decelerate = _DecelerateCurve();