easeIn constant
Curve
const easeIn
A cubic animation curve that starts slowly and ends quickly.
Implementation
static const Curve easeIn = Cubic(0.42, 0.0, 1.0, 1.0);
A cubic animation curve that starts slowly and ends quickly.
static const Curve easeIn = Cubic(0.42, 0.0, 1.0, 1.0);