easeInOut constant
Curve
const easeInOut
A cubic animation curve that starts slowly, speeds up, then ends slowly.
Implementation
static const Curve easeInOut = Cubic(0.42, 0.0, 0.58, 1.0);
A cubic animation curve that starts slowly, speeds up, then ends slowly.
static const Curve easeInOut = Cubic(0.42, 0.0, 0.58, 1.0);