easeOut constant
Curve
const easeOut
A cubic animation curve that starts quickly and ends slowly.
Implementation
static const Curve easeOut = Cubic(0.0, 0.0, 0.58, 1.0);
A cubic animation curve that starts quickly and ends slowly.
static const Curve easeOut = Cubic(0.0, 0.0, 0.58, 1.0);