barrierColor property
The color of the barrier behind the dialog.
When null, no visible barrier color is rendered but the barrier still intercepts taps when barrierDismissible is true.
Implementation
final Color? barrierColor;
The color of the barrier behind the dialog.
When null, no visible barrier color is rendered but the barrier still intercepts taps when barrierDismissible is true.
final Color? barrierColor;