barrierLabel property
Accessibility label for the barrier.
Used by screen readers to describe the dismiss action.
Implementation
final String? barrierLabel;
Accessibility label for the barrier.
Used by screen readers to describe the dismiss action.
final String? barrierLabel;