useSafeArea property
Whether to wrap the dialog with SafeArea.
When true, the dialog avoids terminal insets if any are reported.
Implementation
final bool useSafeArea;
Whether to wrap the dialog with SafeArea.
When true, the dialog avoids terminal insets if any are reported.
final bool useSafeArea;