category property
Group/category name. Items with the same category are grouped under a shared section header.
Implementation
final String? category;
Group/category name. Items with the same category are grouped under a shared section header.
final String? category;