pop method
Pop the top dialog from the stack.
Returns true if a dialog was popped, false if the stack was empty.
Implementation
bool pop() {
if (_stack.isEmpty) return false;
setState(() {
_stack.removeLast();
});
return true;
}
Pop the top dialog from the stack.
Returns true if a dialog was popped, false if the stack was empty.
bool pop() {
if (_stack.isEmpty) return false;
setState(() {
_stack.removeLast();
});
return true;
}