buttonBackground property
Background color for action buttons in their default state. Defaults to Theme.resolvedSurfaceVariant.
Implementation
final Color? buttonBackground;
Background color for action buttons in their default state. Defaults to Theme.resolvedSurfaceVariant.
final Color? buttonBackground;