buttonForeground property
Text color for action buttons in their default state. Defaults to Theme.onSurface.
Implementation
final Color? buttonForeground;
Text color for action buttons in their default state. Defaults to Theme.onSurface.
final Color? buttonForeground;