footerBackground property
Background color for the footer bar in inline prompt panels. Defaults to Theme.resolvedSurfaceVariant.
Implementation
final Color? footerBackground;
Background color for the footer bar in inline prompt panels. Defaults to Theme.resolvedSurfaceVariant.
final Color? footerBackground;