side property
Which diff side this comment belongs to (addition/removal). Used to align the block under the correct column in side-by-side view.
Implementation
final DiffCommentSide? side;
Which diff side this comment belongs to (addition/removal). Used to align the block under the correct column in side-by-side view.
final DiffCommentSide? side;