Drawer class
A slide-out panel that overlays content from the left or right.
The Drawer displays its child with an optional dimmed backdrop and
reveals the drawer widget from side when open is true.
The drawer is dismissible by clicking the backdrop when dismissible is true. Use width to control the drawer's width in cells.
Example:
Drawer(
open: _showSidebar,
side: SidebarSide.left,
drawer: ListView(
children: [Text('Menu Item 1'), Text('Menu Item 2')],
),
child: MainContent(),
)
- Inheritance
-
- Object
- Widget
- StatelessWidget
- Drawer
Constructors
Properties
- accessibilityLabel → String?
-
Optional accessibility label.
no setterinherited
- accessibilityRole → String
-
Optional accessibility role.
no setterinherited
- backdropColor → Color?
-
final
- backdropOpacity → double
-
final
- child → Widget
-
final
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- degradationSignal → WidgetDegradationSignal
-
Signal that controls this widget's render budget behavior.
no setterinherited
- dismissible → bool
-
final
- drawer → Widget
-
final
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- onDismiss → CmdCallback?
-
final
- open → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → SidebarSide
-
final
- theme → Theme
-
Access the current theme.
no setterinherited
- width → int
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the UI represented by this widget.
override
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRenderAt(
DegradationLevel degradationLevel, {required bool subtreeHasFocusedWidget}) → bool -
Whether this widget should participate in the current render when
degradationLevelis active.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
view(
) → Object -
Renders the widget to a string or View.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited