EdgeInsets class

Constructors

EdgeInsets.all(num value)
const
EdgeInsets.only({num top = 0, num right = 0, num bottom = 0, num left = 0})
const
EdgeInsets.symmetric({num vertical = 0, num horizontal = 0})
const

Properties

bottom num
final
hashCode int
The hash code for this object.
no setterinherited
isZero bool
no setter
left num
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top num
final

Methods

copyWith({num? top, num? right, num? bottom, num? left}) EdgeInsets
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(EdgeInsets other) EdgeInsets
operator -(EdgeInsets other) EdgeInsets
operator ==(Object other) bool
The equality operator.
inherited

Constants

zero → const EdgeInsets