EditorThemeData class

Theme data for editable text surfaces such as TextArea, TextEditor, CodeEditor, and MarkdownEditor.

This gives editor surfaces their own shell/body/utility chroming so they don't have to infer everything from generic panel tokens.

Constructors

EditorThemeData({Color? shellBackground, Color? inactiveShellBackground, Color? activeShellBorderColor, Color? inactiveShellBorderColor, Color? bodyBackground, Color? inactiveBodyBackground, Color? activeBodyBorderColor, Color? inactiveBodyBorderColor, Color? utilityBackground, Color? utilityBorderColor, Color? titleForeground, Color? inactiveTitleForeground, Color? metaForeground, Color? inactiveMetaForeground, Color? focusedPromptForeground, Color? blurredPromptForeground, Color? focusedTextForeground, Color? blurredTextForeground, Color? focusedPlaceholderForeground, Color? blurredPlaceholderForeground, Color? focusedLineNumberForeground, Color? blurredLineNumberForeground, Color? focusedCursorLineBackground, Color? blurredCursorLineBackground, Color? focusedCursorLineNumberForeground, Color? blurredCursorLineNumberForeground, Color? searchMatchBackground, Color? searchMatchUnderlineColor})
const

Properties

activeBodyBorderColor Color?
Border color of the editable text well while active.
final
activeShellBorderColor Color?
Border color of the outer editor shell while active.
final
blurredCursorLineBackground Color?
Active-line background while the text surface is blurred.
final
blurredCursorLineNumberForeground Color?
Active-line line-number foreground while blurred.
final
blurredLineNumberForeground Color?
Line-number foreground while the text surface is blurred.
final
blurredPlaceholderForeground Color?
Placeholder foreground while the text surface is blurred.
final
blurredPromptForeground Color?
Prompt foreground while the text surface is blurred.
final
blurredTextForeground Color?
Text foreground while the text surface is blurred.
final
bodyBackground Color?
Background of the editable text well while active.
final
focusedCursorLineBackground Color?
Active-line background while the text surface is focused.
final
focusedCursorLineNumberForeground Color?
Active-line line-number foreground while focused.
final
focusedLineNumberForeground Color?
Line-number foreground while the text surface is focused.
final
focusedPlaceholderForeground Color?
Placeholder foreground while the text surface is focused.
final
focusedPromptForeground Color?
Prompt foreground while the text surface is focused.
final
focusedTextForeground Color?
Text foreground while the text surface is focused.
final
hashCode int
The hash code for this object.
no setterinherited
inactiveBodyBackground Color?
Background of the editable text well while inactive.
final
inactiveBodyBorderColor Color?
Border color of the editable text well while inactive.
final
inactiveMetaForeground Color?
Meta/status foreground while the editor is inactive.
final
inactiveShellBackground Color?
Background of the outer editor shell while inactive.
final
inactiveShellBorderColor Color?
Border color of the outer editor shell while inactive.
final
inactiveTitleForeground Color?
Title foreground while the editor is inactive.
final
metaForeground Color?
Meta/status foreground while the editor is active.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchMatchBackground Color?
Background applied to passive search matches.
final
searchMatchUnderlineColor Color?
Underline color applied to passive search matches.
final
shellBackground Color?
Background of the outer editor shell while active.
final
titleForeground Color?
Title foreground while the editor is active.
final
utilityBackground Color?
Background of utility bars such as find and go-to-line.
final
utilityBorderColor Color?
Border color of utility bars while inactive.
final

Methods

copyWith({Color? shellBackground, Color? inactiveShellBackground, Color? activeShellBorderColor, Color? inactiveShellBorderColor, Color? bodyBackground, Color? inactiveBodyBackground, Color? activeBodyBorderColor, Color? inactiveBodyBorderColor, Color? utilityBackground, Color? utilityBorderColor, Color? titleForeground, Color? inactiveTitleForeground, Color? metaForeground, Color? inactiveMetaForeground, Color? focusedPromptForeground, Color? blurredPromptForeground, Color? focusedTextForeground, Color? blurredTextForeground, Color? focusedPlaceholderForeground, Color? blurredPlaceholderForeground, Color? focusedLineNumberForeground, Color? blurredLineNumberForeground, Color? focusedCursorLineBackground, Color? blurredCursorLineBackground, Color? focusedCursorLineNumberForeground, Color? blurredCursorLineNumberForeground, Color? searchMatchBackground, Color? searchMatchUnderlineColor}) EditorThemeData
Copy with selective overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited