ElasticInOutCurve class

An elastic curve that overshoots and oscillates at both ends.

The period parameter controls the duration of the oscillation.

Inheritance

Constructors

ElasticInOutCurve([double period = 0.4])
Creates an elastic-in-out curve with the given period.
const

Properties

flipped Curve
Returns a new curve that is the reverse of this one.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
period double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
transform(double t) double
Returns the value of the curve at point t.
inherited
transformInternal(double t) double
Override this method to define the curve's behavior.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited