mount method
Mounts this element under parent and performs its initial build.
Implementation
void mount(Element? parent) {
this.parent = parent;
_owner?.queueMountInitCmd(widget.handleInit());
markNeedsBuild();
rebuild();
}
Mounts this element under parent and performs its initial build.
void mount(Element? parent) {
this.parent = parent;
_owner?.queueMountInitCmd(widget.handleInit());
markNeedsBuild();
rebuild();
}