update method
Updates the tree with a new root widget configuration.
Implementation
void update(Widget widget) {
rootWidget = widget;
_root.update(widget);
}
Updates the tree with a new root widget configuration.
void update(Widget widget) {
rootWidget = widget;
_root.update(widget);
}