EvidenceTerm class

A single evidence term in a DecisionCard.

Constructors

EvidenceTerm({required String label, required double factor, required EvidenceDirection direction})
const

Properties

direction EvidenceDirection
Direction of the evidence.
final
factor double
Numeric factor or weight (e.g., Bayes factor).
final
hashCode int
The hash code for this object.
no setterinherited
label String
Name of the evidence (e.g., "change_rate").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited