children property
Child widgets that receive forwarded messages.
Override this to declare child widgets. The framework automatically forwards messages to all children before calling handleUpdate.
Implementation
@override
final List<Widget> children;
Child widgets that receive forwarded messages.
Override this to declare child widgets. The framework automatically forwards messages to all children before calling handleUpdate.
@override
final List<Widget> children;