FlippedCurve class
A curve that is the reverse of another curve.
This is the flipped version of curve: it evaluates 1.0 - curve.transform(1.0 - t).
Constructors
- FlippedCurve(Curve curve)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transform(
double t) → double -
Returns the value of the curve at point
t.inherited -
transformInternal(
double t) → double -
Override this method to define the curve's behavior.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited