isTrapped property
Whether this scope traps focus within its subtree.
When true, focus cannot move to widgets outside this scope.
Implementation
final bool isTrapped;
Whether this scope traps focus within its subtree.
When true, focus cannot move to widgets outside this scope.
final bool isTrapped;