accessibilityLabel property
Optional accessibility label.
Return null when the node should not expose a custom label.
Implementation
String? get accessibilityLabel => null;
Optional accessibility label.
Return null when the node should not expose a custom label.
String? get accessibilityLabel => null;