accessibilityRole property
Optional accessibility role.
This defaults to the widget's runtime type and can be overridden to provide a stable role for a11y tooling.
Implementation
String get accessibilityRole => runtimeType.toString();
Optional accessibility role.
This defaults to the widget's runtime type and can be overridden to provide a stable role for a11y tooling.
String get accessibilityRole => runtimeType.toString();