children property
Child widgets that receive forwarded messages.
Override this to declare child widgets. The framework automatically forwards messages to all children before calling handleUpdate.
Implementation
List<Widget> get children => const [];
Child widgets that receive forwarded messages.
Override this to declare child widgets. The framework automatically forwards messages to all children before calling handleUpdate.
List<Widget> get children => const [];