GestureDetector class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- GestureDetector
Constructors
- GestureDetector({required Widget child, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCallback? onTap, GestureTapCancelCallback? onTapCancel, GestureDoubleTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, GestureLongPressEndCallback? onLongPressEnd, GestureDragStartCallback? onDragStart, GestureDragUpdateCallback? onDragUpdate, GestureDragEndCallback? onDragEnd, MouseEnterCallback? onEnter, MouseExitCallback? onExit, GestureWheelCallback? onWheel, HitTestBehavior behavior = HitTestBehavior.deferToChild, bool enabled = true, bool captureMouse = true, Key? key})
Properties
- behavior → HitTestBehavior
-
final
- captureMouse → bool
-
final
- child → Widget
-
final
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- enabled → bool
-
final
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- onDoubleTap → GestureDoubleTapCallback?
-
final
- onDragEnd → GestureDragEndCallback?
-
final
- onDragStart → GestureDragStartCallback?
-
final
- onDragUpdate → GestureDragUpdateCallback?
-
final
- onEnter → MouseEnterCallback?
-
final
- onExit → MouseExitCallback?
-
final
- onLongPress → GestureLongPressCallback?
-
final
- onLongPressEnd → GestureLongPressEndCallback?
-
final
- onLongPressStart → GestureLongPressStartCallback?
-
final
- onTap → GestureTapCallback?
-
final
- onTapCancel → GestureTapCancelCallback?
-
final
- onTapDown → GestureTapDownCallback?
-
final
- onTapUp → GestureTapUpCallback?
-
final
- onWheel → GestureWheelCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → Theme
-
Access the current theme.
no setterinherited
Methods
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable State associated with this widget.
override
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
view(
) → Object -
Renders the widget to a string or View.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited