commentAnchorIndexAt method
Returns the index of the comment anchor occupying renderLine.
Implementation
int? commentAnchorIndexAt(int renderLine, {DiffCommentSide? side}) {
return _model.commentAnchorIndexAt(renderLine, side: side);
}
Returns the index of the comment anchor occupying renderLine.
int? commentAnchorIndexAt(int renderLine, {DiffCommentSide? side}) {
return _model.commentAnchorIndexAt(renderLine, side: side);
}