nearestCommentAnchor method
Returns the nearest comment anchor at or after renderLine.
Implementation
DiffCommentAnchor? nearestCommentAnchor(int renderLine) {
return _model.nearestCommentAnchor(renderLine);
}
Returns the nearest comment anchor at or after renderLine.
DiffCommentAnchor? nearestCommentAnchor(int renderLine) {
return _model.nearestCommentAnchor(renderLine);
}