commentBlocks property

List<DiffCommentBlock> commentBlocks
final

Inline comment blocks rendered as widgets between diff lines. When empty, the viewer renders the diff as a plain text proxy. When non-empty, the viewer composes a scrollable column of diff lines interleaved with these rich comment widgets.

Implementation

final List<DiffCommentBlock> commentBlocks;