fitContentHeight property

bool fitContentHeight
final

Whether to auto-size height to rendered content line count.

Useful when embedding the viewer inside a parent scroll container and wanting no internal blank fill area.

Implementation

final bool fitContentHeight;