onCommentAnchorSelected property
Called when a commentable diff line is selected with the mouse.
Implementation
final Cmd? Function(DiffCommentAnchor anchor)? onCommentAnchorSelected;
Called when a commentable diff line is selected with the mouse.
final Cmd? Function(DiffCommentAnchor anchor)? onCommentAnchorSelected;