HeatmapChart constructor

HeatmapChart({
  1. required List<List<double>> grid,
  2. int? width,
  3. int? height,
  4. ChartRamp? ramp,
  5. bool useBackground = true,
  6. String glyph = ' ',
  7. bool showGrid = false,
  8. int gridRows = 3,
  9. int gridCols = 3,
  10. UvStyle? gridStyle,
  11. List<String>? xLabels,
  12. List<String>? yLabels,
  13. UvStyle? labelStyle,
  14. List<ChartLegendEntry>? legendEntries,
  15. int legendColumns = 1,
  16. int legendRowGap = 0,
  17. ChartLegendPosition legendPosition = ChartLegendPosition.topRight,
  18. int legendPadding = 1,
  19. int? crosshairX,
  20. int? crosshairY,
  21. UvStyle? crosshairStyle,
  22. Key? key,
})

Creates a HeatmapChart with the given grid data and display options.

When width or height is null the chart fills the available constraint space (responsive mode).

Set crosshairX and crosshairY to draw a crosshair overlay at that position (e.g. from mouse hover).

Implementation

HeatmapChart({
  required this.grid,
  this.width,
  this.height,
  this.ramp,
  this.useBackground = true,
  this.glyph = ' ',
  this.showGrid = false,
  this.gridRows = 3,
  this.gridCols = 3,
  this.gridStyle,
  this.xLabels,
  this.yLabels,
  this.labelStyle,
  this.legendEntries,
  this.legendColumns = 1,
  this.legendRowGap = 0,
  this.legendPosition = ChartLegendPosition.topRight,
  this.legendPadding = 1,
  this.crosshairX,
  this.crosshairY,
  this.crosshairStyle,
  super.key,
});