HistoryEntry class

A single entry in the undo/redo history.

Constructors

HistoryEntry({required String description, bool isRedo = false})
const

Properties

description String
Human-readable description of the command.
final
hashCode int
The hash code for this object.
no setterinherited
isRedo bool
Whether this entry is in the redo (future) stack.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited