HitTestElementEntry class
Result of an element-level hit test — pairs an Element with the local coordinates at which its render object was hit.
Constructors
- HitTestElementEntry({required Element element, required double localX, required double localY})
-
const
Properties
- element → Element
-
The hit element.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localX → double
-
Local X coordinate relative to the hit render object.
final
- localY → double
-
Local Y coordinate relative to the hit render object.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited