HitTestEntry class

A single entry in a HitTestResult, linking a render object to the local coordinates at which it was hit.

Constructors

HitTestEntry(Object renderObject, {double localX = 0, double localY = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
localX double
X coordinate in the render object's local coordinate space.
final
localY double
Y coordinate in the render object's local coordinate space.
final
renderObject Object
The render object that was hit.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited