HitTestResult class

Accumulated result of a hit test, ordered deepest-first.

Constructors

HitTestResult()

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
path List<HitTestEntry>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(HitTestEntry entry) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited