Icons class

Constructors

Icons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

add → const IconData
arrowDown → const IconData
arrowLeft → const IconData
arrowRight → const IconData
arrowUp → const IconData
check → const IconData
close → const IconData
remove → const IconData
star → const IconData