ImageData class

Data class holding a decoded image.

Constructors

ImageData(Image image)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
Height of the image in pixels.
no setter
image → Image
The decoded image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Width of the image in pixels.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited