ImageProvider class abstract

Abstract base class for providing images to the Image widget.

Subclasses must implement resolve to asynchronously produce an ImageData instance.

Constructors

ImageProvider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<ImageData>
Resolves and returns the image data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited