ImageRenderMode enum

Preferred rendering backend for the Image widget.

Inheritance
Available extensions

Values

auto → const ImageRenderMode

Pick the best available protocol using UV's terminal capability hints.

kitty → const ImageRenderMode

Force Kitty graphics protocol output.

iterm2 → const ImageRenderMode

Force iTerm2 inline image protocol output.

sixel → const ImageRenderMode

Force Sixel graphics output.

unicodeBlocks → const ImageRenderMode

Force portable half-block / unicode rendering.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageRenderMode>
A constant List of the values in this enum, in order of their declaration.