lerp method
Returns the interpolated value for the given animation parameter t.
By default, this uses the +, -, and * operators on T.
Subclasses override this for types that do not support those operators.
Implementation
@override
int lerp(double t) {
return (begin! + (end! - begin!) * t).round();
}