builder property

Widget Function(BuildContext context, BoxConstraints constraints) builder
final

Called to build the widget tree with the available constraints.

The constraints are derived from the nearest MediaQuery ancestor, providing the terminal width and height as max constraints.

Implementation

final Widget Function(BuildContext context, BoxConstraints constraints)
builder;