accentForeground property
Semantic accent color for row markers or important tokens. Defaults to Theme.primary.
Implementation
final Color? accentForeground;
Semantic accent color for row markers or important tokens. Defaults to Theme.primary.
final Color? accentForeground;