Listenable class abstract

An object that maintains a list of listeners.

Listeners are notified when the object changes. This is the base type for Animation and is consumed by AnimatedBuilder / ListenableBuilder.

Constructors

Listenable()
const
Listenable.merge(Iterable<Listenable?> listenables)
Creates a Listenable that triggers when any of listenables fires.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
Register listener to be called when the object notifies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener()) → void
Remove a previously registered listener.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited