builder property
Called every time the listenable notifies.
The child argument is the same widget passed to this ListenableBuilder's constructor.
Implementation
final Widget Function(BuildContext context, Widget? child) builder;
Called every time the listenable notifies.
The child argument is the same widget passed to this ListenableBuilder's constructor.
final Widget Function(BuildContext context, Widget? child) builder;