LongPressEndDetails class

Details for the end of a long-press gesture.

Constructors

LongPressEndDetails({required Offset globalPosition, required Offset localPosition})
const

Properties

globalPosition Offset
final
hashCode int
The hash code for this object.
no setterinherited
localPosition Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited