duration property
How long the pointer must be held before the long-press triggers.
Implementation
Duration duration = const Duration(milliseconds: 500);
How long the pointer must be held before the long-press triggers.
Duration duration = const Duration(milliseconds: 500);