MemoryImage class

An ImageProvider that loads an image from raw bytes.

Image(image: MemoryImage(myPngBytes))
Inheritance

Constructors

MemoryImage(Uint8List bytes, {int? decodeFrame})
const

Properties

bytes Uint8List
The raw image bytes (PNG, JPEG, etc.).
final
decodeFrame int?
Optional frame index to decode for animated image formats.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<ImageData>
Resolves and returns the image data.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override