onGenerateRoute property
Called to generate a route for a given RouteSettings.
Used when the named route is not found in routes.
Implementation
final RouteFactory? onGenerateRoute;
Called to generate a route for a given RouteSettings.
Used when the named route is not found in routes.
final RouteFactory? onGenerateRoute;