allowedContentTypes property
Optional allow-list of MIME types such as image/png or image/*.
Empty means any content type is allowed unless it matches blockedContentTypes.
Implementation
final Set<String> allowedContentTypes;
Optional allow-list of MIME types such as image/png or image/*.
Empty means any content type is allowed unless it matches blockedContentTypes.
final Set<String> allowedContentTypes;