Offset class

An offset in terminal cell units (column, row).

Constructors

Offset(double dx, double dy)
const

Properties

dx double
final
dy double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(Offset other) Offset
operator -(Offset other) Offset
operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Offset