maxHeight property
The maximum height constraint to impose on the child. If null, the parent's max height constraint is used.
Implementation
final double? maxHeight;
The maximum height constraint to impose on the child. If null, the parent's max height constraint is used.
final double? maxHeight;