maxWidth property
The maximum width constraint to impose on the child. If null, the parent's max width constraint is used.
Implementation
final double? maxWidth;
The maximum width constraint to impose on the child. If null, the parent's max width constraint is used.
final double? maxWidth;