minHeight property
The minimum height constraint to impose on the child. If null, the parent's min height constraint is used.
Implementation
final double? minHeight;
The minimum height constraint to impose on the child. If null, the parent's min height constraint is used.
final double? minHeight;