minWidth property
The minimum width constraint to impose on the child. If null, the parent's min width constraint is used.
Implementation
final double? minWidth;
The minimum width constraint to impose on the child. If null, the parent's min width constraint is used.
final double? minWidth;