remove method

void remove()

Removes this entry from its overlay.

After calling this method, the entry is no longer displayed and its builder will not be called again.

Implementation

void remove() {
  _overlayState?.removeEntry(this);
}