OverlayState class
State for Overlay, providing methods to insert and remove entries.
Constructors
Properties
- context ↔ BuildContext
-
The build context for this state.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this state is currently mounted in the element tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ Overlay
-
The current configuration for this state.
getter/setter pairinherited
Methods
-
build(
BuildContext context) → Widget -
Builds the widget subtree for this state.
override
-
clear(
) → void - Removes all entries.
-
didUpdateWidget(
covariant Overlay oldWidget) → Cmd? -
Called when the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this state is permanently removed from the tree.
override
-
handleInit(
) → Cmd? -
Called once when the widget tree is first mounted.
inherited
-
handleIntercept(
Msg msg) → Cmd? -
Called before children during message dispatch.
inherited
-
handleUpdate(
Msg msg) → Cmd? -
Called after children during message dispatch.
inherited
-
initState(
) → void -
Called when the state is inserted into the tree.
override
-
insert(
OverlayEntry entry) → void -
Inserts an
entryat the top of the overlay stack. -
insertAbove(
OverlayEntry entry, {required OverlayEntry below}) → void -
Inserts an
entryabovebelowin the overlay stack. -
insertAll(
Iterable< OverlayEntry> entries) → void -
Inserts all
entriesat the top of the overlay stack. -
insertBelow(
OverlayEntry entry, {required OverlayEntry above}) → void -
Inserts an
entrybelowabovein the overlay stack. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeEntry(
OverlayEntry entry) → void -
Removes an
entryfrom the overlay. -
setState(
void fn()) → void -
Notifies the framework that this state's internal data has changed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited