PageRoute<T> class

A full-screen page route.

Creates a single opaque OverlayEntry that renders the page content. This is the standard route type for pushing a new screen.

navigator.push(PageRoute(
  builder: (context) => SettingsScreen(),
  settings: RouteSettings(name: '/settings'),
));
Inheritance

Constructors

PageRoute({required RouteWidgetBuilder builder, RouteSettings? settings})
Creates a page route with the given builder.

Properties

builder RouteWidgetBuilder
Builds the page content.
final
completer Completer<T?>?
The Completer that completes when this route is popped.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
Back-reference to the NavigatorState managing this route.
getter/setter pairinherited
overlayEntries List<OverlayEntry>
The overlay entries this route has created.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings
Metadata for this route (name, arguments).
finalinherited

Methods

canPop() bool
Whether this route can be popped.
inherited
createOverlayEntries() Iterable<OverlayEntry>
Creates the overlay entries for this route.
override
dispose() → void
Disposes this route, removing all its overlay entries.
inherited
install() → void
Installs this route, creating its overlay entries.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited