Rect class

A rectangle defined by offset + size, in terminal cell units.

Constructors

Rect.fromLTWH(double left, double top, double width, double height)
const
Rect.fromOffsetAndSize(Offset offset, Size size)

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
final
left double
final
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final
width double
final

Methods

contains(double x, double y) bool
Returns true if the point (x, y) is inside this rectangle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited