RenderMetricsInjector class

Global bus for injecting render metrics from anywhere.

Any running WidgetApp listens to this stream and applies updates.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<RenderMetricsInjection>
Stream consumed by WidgetApp.
no setter

Methods

clearMetrics() → void
Clears all custom overlay metric lines.
inject(RenderMetricsInjection injection) → void
Injects a full RenderMetricsInjection payload.
injectRuntime(RenderMetrics metrics) → void
Injects runtime renderer metrics.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMetric(String key) → void
Removes one custom overlay metric line.
setMetric(String key, Object? value) → void
Adds or updates one custom overlay metric line.
setMetrics(Map<String, Object?> entries, {bool replace = false}) → void
Adds or updates many custom overlay metric lines.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RenderMetricsInjector
final