RenderObject class abstract

A render object represents a layout/paintable node.

Constructors

RenderObject()

Properties

children List<RenderObject>
final
constraints BoxConstraints
getter/setter pair
element Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offset Offset
Position relative to the parent render object, computed during layout.
getter/setter pair
paintDirty bool
Whether this render object (or a descendant in its subtree) needs paint.
no setter
parent RenderObject?
getter/setter pair
parentData Object?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
getter/setter pair

Methods

attach(RenderObject child) → void
clearPaintDirty() → void
Marks this render object's paint state as clean.
clearPaintDirtySubtree() → void
Marks this render object and all descendants as paint-clean.
detach(RenderObject child) → void
dispose() → void
hitTest(HitTestResult result, {required double localX, required double localY}) bool
Performs hit-testing at (localX, localY) in this object's coordinate space. Adds matching entries to result, deepest first.
layout(BoxConstraints constraints) → void
markDescendantNeedsPaint() → void
Called when a descendant render object's paint output has changed.
markNeedsPaintOnly() → void
Marks this render object as needing paint without invalidating descendant-specific paint caches.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited