RenderText class
Renders a text string with constraints.
- Inheritance
-
- Object
- RenderObject
- RenderBox
- RenderText
Constructors
- RenderText({required String text, bool softWrap = true})
Properties
-
children
→ List<
RenderObject> -
finalinherited
- constraints ↔ BoxConstraints
-
getter/setter pairinherited
- element ↔ Object?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset ↔ Offset
-
Position relative to the parent render object, computed during layout.
getter/setter pairinherited
- paintDirty → bool
-
Whether this render object (or a descendant in its subtree) needs paint.
no setterinherited
- parent ↔ RenderObject?
-
getter/setter pairinherited
- parentData ↔ Object?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ Size
-
getter/setter pairinherited
- softWrap ↔ bool
-
getter/setter pair
- text ↔ String
-
getter/setter pair
Methods
-
attach(
RenderObject child) → void -
inherited
-
clearPaintDirty(
) → void -
Marks this render object's paint state as clean.
inherited
-
clearPaintDirtySubtree(
) → void -
Marks this render object and all descendants as paint-clean.
inherited
-
detach(
RenderObject child) → void -
inherited
-
dispose(
) → void -
inherited
-
hitTest(
HitTestResult result, {required double localX, required double localY}) → bool -
Performs hit-testing at (localX, localY) in this object's coordinate
space. Adds matching entries to
result, deepest first.inherited -
layout(
BoxConstraints constraints) → void -
override
-
markDescendantNeedsPaint(
) → void -
Called when a descendant render object's paint output has changed.
inherited
-
markNeedsPaintOnly(
) → void -
Marks this render object as needing paint without invalidating
descendant-specific paint caches.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited