ReplayEventHistoryState class final

Constructors

ReplayEventHistoryState({ReplayEventHistoryFilter filter = ReplayEventHistoryFilter.all, ReplayEventHistoryMode mode = ReplayEventHistoryMode.flat, bool expanded = false})
const

Properties

expanded bool
final
filter ReplayEventHistoryFilter
final
hashCode int
The hash code for this object.
no setterinherited
mode ReplayEventHistoryMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ReplayEventHistoryFilter? filter, ReplayEventHistoryMode? mode, bool? expanded}) ReplayEventHistoryState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withExpanded(bool expanded) ReplayEventHistoryState
withFilter(ReplayEventHistoryFilter filter) ReplayEventHistoryState
withMode(ReplayEventHistoryMode mode) ReplayEventHistoryState

Operators

operator ==(Object other) bool
The equality operator.
inherited