RibbonChart constructor

RibbonChart({
  1. required List<List<double>> series,
  2. int? width,
  3. int? height,
  4. List<UvStyle>? seriesStyles,
  5. bool normalizeTotals = true,
  6. String fillChar = '█',
  7. bool showGrid = false,
  8. int gridRows = 3,
  9. int gridCols = 0,
  10. UvStyle? gridStyle,
  11. List<ChartLegendEntry>? legendEntries,
  12. int legendColumns = 1,
  13. int legendRowGap = 0,
  14. ChartLegendPosition legendPosition = ChartLegendPosition.topRight,
  15. int legendPadding = 1,
  16. int? crosshairX,
  17. int? crosshairY,
  18. UvStyle? crosshairStyle,
  19. Key? key,
})

Creates a RibbonChart with the given series data and display options.

When width or height is null the chart fills the available constraint space (responsive mode).

Set crosshairX and crosshairY to draw a crosshair overlay at that position (e.g. from mouse hover).

Implementation

RibbonChart({
  required this.series,
  this.width,
  this.height,
  this.seriesStyles,
  this.normalizeTotals = true,
  this.fillChar = '█',
  this.showGrid = false,
  this.gridRows = 3,
  this.gridCols = 0,
  this.gridStyle,
  this.legendEntries,
  this.legendColumns = 1,
  this.legendRowGap = 0,
  this.legendPosition = ChartLegendPosition.topRight,
  this.legendPadding = 1,
  this.crosshairX,
  this.crosshairY,
  this.crosshairStyle,
  super.key,
});