RichText class

A widget that displays styled text using a TextSpan tree.

This is the lower-level API for styled text. For simple strings use Text; for rich styled text you can also use Text.rich(TextSpan(...)). This class provides a named, standalone widget for Flutter API parity.

RichText(
  text: TextSpan(
    text: 'Hello ',
    style: Style()..bold(true),
    children: [
      TextSpan(text: 'world', style: Style()..foreground(Colors.red)),
    ],
  ),
)
Inheritance

Constructors

RichText({required TextSpan text, Key? key, TextAlign textAlign = TextAlign.left, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, int? maxWidth})

Properties

children List<Widget>
Child widgets that receive forwarded messages.
no setterinherited
debugRenderObjectPassthrough bool
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
focusable bool
Whether this widget can receive keyboard focus.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this widget.
no setterinherited
key Key?
Key for preserving widget identity.
finalinherited
maxWidth int?
Maximum width in columns for text truncation.
final
overflow TextOverflow
How visual overflow should be handled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool
Whether the text should break at soft line breaks.
final
text TextSpan
The styled text span tree to render.
final
textAlign TextAlign
How the text should be aligned horizontally.
final
theme Theme
Access the current theme.
no setterinherited

Methods

buildCachedView<T>(T builder(), Object? cacheKey) → T
Returns a cached view if the cache key matches.
inherited
createRenderObject() RenderObject
override
didUnmountRenderObject(RenderObject renderObject) → void
inherited
handleInit() Cmd?
Override this instead of init for widget-specific initialization.
inherited
handleIntercept(Msg msg) → (Widget, Cmd?)
Override this to handle messages before they reach children.
inherited
handleUpdate(Msg msg) → (Widget, Cmd?)
Override this to handle messages specific to this widget.
inherited
init() Cmd?
Called once when the widget is first mounted.
inherited
invalidateCachedView() → void
Clears any cached view for this widget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Msg msg) → (Model, Cmd?)
Handles messages by forwarding to children then calling handleUpdate.
inherited
updateRenderObject(RenderObject renderObject) → void
override
view() Object
Renders the widget to a string or View.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited