createOverlayEntries abstract method
Creates the overlay entries for this route.
Subclasses must implement this to define what layers the route contributes to the overlay stack.
Implementation
Iterable<OverlayEntry> createOverlayEntries();
Creates the overlay entries for this route.
Subclasses must implement this to define what layers the route contributes to the overlay stack.
Iterable<OverlayEntry> createOverlayEntries();