RouteSettings class
Immutable route metadata.
Describes a route configuration with an optional name for named routing and optional arguments for passing data between routes.
final settings = RouteSettings(name: '/details', arguments: {'id': 42});
Constructors
- RouteSettings({String? name, Object? arguments})
-
Creates route settings with the given
nameandarguments.const
Properties
Methods
-
copyWith(
{String? name, Object? arguments}) → RouteSettings - Creates a copy of these settings with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited