autoCopySelectionOnExit property
Whether to auto-copy selected text immediately when drag leaves the scroll view's hit-test area.
Implementation
final bool autoCopySelectionOnExit;
Whether to auto-copy selected text immediately when drag leaves the scroll view's hit-test area.
final bool autoCopySelectionOnExit;