overlay property
Whether the scrollbar is drawn on top of the child.
When false, the scrollbar reserves space to the right of the child.
Implementation
final bool overlay;
Whether the scrollbar is drawn on top of the child.
When false, the scrollbar reserves space to the right of the child.
final bool overlay;