thumbUsesBackground property

bool thumbUsesBackground
final

Whether the thumb style should apply to the background.

This only affects how the scrollbar is composited when the thumb uses spaces (for example, a background-filled thumb).

Implementation

final bool thumbUsesBackground;