trackUsesBackground property

bool trackUsesBackground
final

Whether the track style should apply to the background.

This only affects how the scrollbar is composited when the track uses spaces (for example, a background-filled gutter).

Implementation

final bool trackUsesBackground;