ScrollbarGradient class

A vertical gradient for scrollbar tracks or thumbs.

Constructors

ScrollbarGradient({required Color start, required Color end, bool useBackground = false})
const
ScrollbarGradient.background({required Color start, required Color end})
Creates a gradient that applies to the background color.
const
ScrollbarGradient.foreground({required Color start, required Color end})
Creates a gradient that applies to the foreground color.
const

Properties

end Color
Ending color of the gradient.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Color
Starting color of the gradient.
final
useBackground bool
Whether the gradient applies to the background color.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited