SlotPlugin<TSlot extends Object, TData> class final

Declarative registration for one in-process widget plugin.

Constructors

SlotPlugin({required String pluginId, required Map<TSlot, SlotPluginContribution<TData>> slots})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pluginId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slots Map<TSlot, SlotPluginContribution<TData>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited