hasSlot method
Returns whether the registry has any contributions for slot.
Implementation
bool hasSlot(TSlot slot) {
return _registrations.any((registration) => registration.slot == slot);
}
Returns whether the registry has any contributions for slot.
bool hasSlot(TSlot slot) {
return _registrations.any((registration) => registration.slot == slot);
}