dispose method
Releases all listeners. After this call the notifier should not be used.
Implementation
@override
void dispose() {
stop();
super.dispose();
}
Releases all listeners. After this call the notifier should not be used.
@override
void dispose() {
stop();
super.dispose();
}