start method
void
start()
Starts or restarts the animation from the first frame.
Implementation
void start() {
_frame = 0;
value = spinner.frames.first;
_start();
}
Starts or restarts the animation from the first frame.
void start() {
_frame = 0;
value = spinner.frames.first;
_start();
}