StackParentData class

Constructors

StackParentData({num? left, num? right, num? top, num? bottom, num? width, num? height})
const

Properties

bottom num?
final
hashCode int
The hash code for this object.
no setterinherited
height num?
final
isPositioned bool
no setter
left num?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top num?
final
width num?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited