handleInit method

Cmd? handleInit()

Called once when the widget tree is first mounted.

Return a Cmd to schedule initialization work such as starting animations. This is the State-level equivalent of Widget.handleInit.

Implementation

Cmd? handleInit() => null;