mounted property
bool
get
mounted
Whether this state is currently mounted in the element tree.
Implementation
bool get mounted => _element != null;
Whether this state is currently mounted in the element tree.
bool get mounted => _element != null;