StepItem class

A single step in a StepIndicator.

Constructors

StepItem({required String label, StepStatus status = StepStatus.pending, String? description})
const
StepItem.fromMap(Map<String, dynamic> map)
Creates a StepItem from a map structure.
factory

Properties

description String?
Optional longer description.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The step label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StepStatus
Current status of the step.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited