StepTween class
A tween that floors the interpolated value to an integer.
Useful for discrete step animations (e.g., progress bar segments).
- Inheritance
-
- Object
- Animatable<
int> - Tween<
int> - StepTween
Properties
- begin ↔ int?
-
The value at the beginning of the animation (t = 0.0).
getter/setter pairinherited
- end ↔ int?
-
The value at the end of the animation (t = 1.0).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
Animation< double> parent) → Animation<int> -
Creates a new Animation by applying this animatable on top of
parent.inherited -
chain(
Animatable< double> parent) → Animatable<int> -
Chains this animatable after
parent.inherited -
evaluate(
Animation< double> animation) → int -
Evaluates this animatable at the current value of
animation.inherited -
lerp(
double t) → int -
Returns the interpolated value for the given animation parameter
t.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
double t) → int -
Returns the value of this animatable at the given
t.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited