TapUpDetails class

Details for a tap-up event.

Constructors

TapUpDetails({required Offset globalPosition, required Offset localPosition})
const

Properties

globalPosition Offset
Position in global (terminal) coordinates.
final
hashCode int
The hash code for this object.
no setterinherited
localPosition Offset
Position in the gesture detector's local coordinate space.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited