TerminalShadowStyle enum

Preset terminal-cell patterns used to paint a Shadow.

Inheritance
Available extensions

Values

block → const TerminalShadowStyle

A solid background-colored block.

const TerminalShadowStyle(' ')
light → const TerminalShadowStyle

Light shade cells.

const TerminalShadowStyle('░')
medium → const TerminalShadowStyle

Medium shade cells.

const TerminalShadowStyle('▒')
dark → const TerminalShadowStyle

Dark shade cells.

const TerminalShadowStyle('▓')

Properties

glyph String
Glyph used by this style.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TerminalShadowStyle>
A constant List of the values in this enum, in order of their declaration.