clear method
void
clear()
Replaces the text content and resets the cursor to the end.
Implementation
void clear() {
_model.reset();
notifyListeners();
}
Replaces the text content and resets the cursor to the end.
void clear() {
_model.reset();
notifyListeners();
}