moveLinesDown method
Moves the selected lines, or the current line, one row downward.
Implementation
bool moveLinesDown() {
final changed = _model.moveLinesDown();
if (changed) {
notifyListeners();
}
return changed;
}
Moves the selected lines, or the current line, one row downward.
bool moveLinesDown() {
final changed = _model.moveLinesDown();
if (changed) {
notifyListeners();
}
return changed;
}