TextDecorationLayerBinding class final

Keeps one named range-decoration layer in sync with a text controller.

Constructors

TextDecorationLayerBinding({required TextAreaController controller, required String layerKey, required TextDecorationLayerBuilder buildDecorations, int priority = textDefaultDecorationLayerPriority, bool isActive()?, bool syncImmediately = true})

Properties

controller TextAreaController
The controller currently synced by this binding.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isActive bool Function()?
Whether this binding should actively manage layerKey.
final
layerKey String
Named layer updated by this binding.
final
priority int
Priority used when applying decorations to layerKey.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears the managed range-decoration layer.
dispose() → void
Detaches the binding from its controller.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync({bool force = false}) → void
Recomputes range decorations from the controller's current text.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited