redo method
Reapplies the most recently undone edit state and notifies listeners.
Implementation
bool redo() {
final changed = _model.redo();
if (changed) {
notifyListeners();
}
return changed;
}
Reapplies the most recently undone edit state and notifies listeners.
bool redo() {
final changed = _model.redo();
if (changed) {
notifyListeners();
}
return changed;
}