dispose method
Releases all listeners. After this call the notifier should not be used.
Implementation
@override
void dispose() {
if (_disposed) return;
_disposed = true;
_text.removeListener(_handleTextChanged);
super.dispose();
}
Releases all listeners. After this call the notifier should not be used.
@override
void dispose() {
if (_disposed) return;
_disposed = true;
_text.removeListener(_handleTextChanged);
super.dispose();
}