theme property
Theme
get
theme
Returns the nearest theme from context, or the global theme.
Implementation
Theme get theme => ThemeScope.of(this);
Returns the nearest theme from context, or the global theme.
Theme get theme => ThemeScope.of(this);