maybeOf static method
Returns the nearest theme from the context, if any.
Implementation
static Theme? maybeOf(BuildContext context) {
return context.dependOnInheritedWidgetOfExactType<ThemeScope>()?.theme;
}
Returns the nearest theme from the context, if any.
static Theme? maybeOf(BuildContext context) {
return context.dependOnInheritedWidgetOfExactType<ThemeScope>()?.theme;
}