of static method
Returns the nearest theme from the context, or the global theme.
Implementation
static Theme of(BuildContext context) {
return maybeOf(context) ?? currentTheme;
}
Returns the nearest theme from the context, or the global theme.
static Theme of(BuildContext context) {
return maybeOf(context) ?? currentTheme;
}