weight property
The relative weight of this segment.
Weights do not need to sum to any particular value — they are automatically normalized.
Implementation
final double weight;
The relative weight of this segment.
Weights do not need to sum to any particular value — they are automatically normalized.
final double weight;