UniqueKey constructor
UniqueKey()
Creates a key that is equal only to itself.
Implementation
// ignore: prefer_const_constructors_in_immutables
UniqueKey();
Creates a key that is equal only to itself.
// ignore: prefer_const_constructors_in_immutables
UniqueKey();