ValueKey<T> class

A key that uses a value of a particular type to identify itself.

Inheritance

Constructors

ValueKey(T value)
Creates a key that delegates its operator== to the given value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The value to which this key delegates its operator==.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override