ValueListenable<T> class abstract

A Listenable that exposes a current value.

Inheritance

Constructors

ValueListenable()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The current value held by this object.
no setter

Methods

addListener(void listener()) → void
Register listener to be called when the object notifies.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener()) → void
Remove a previously registered listener.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited