cacheExtentItems property
Number of off-screen item elements to retain before and after the visible range when using the builder constructor.
Implementation
final int cacheExtentItems;
Number of off-screen item elements to retain before and after the visible range when using the builder constructor.
final int cacheExtentItems;