backgroundColor property

Color? backgroundColor
final

Optional terminal background color.

When set, view returns a View object with this color as the terminal-level background (OSC 11). This fills the entire terminal window — including any cells that the widget tree does not explicitly paint — eliminating edge gaps around the UI.

Implementation

final Color? backgroundColor;