thumbDragActive property
bool
get
thumbDragActive
Whether an attached scrollbar thumb drag is currently active.
Implementation
bool get thumbDragActive => _thumbDragActive;
Whether an attached scrollbar thumb drag is currently active.
bool get thumbDragActive => _thumbDragActive;