WizardFormStep class abstract

Constructors

WizardFormStep({required String key, required String prompt, String? description})
const
WizardFormStep.conditional({required WizardFormStep step, required bool condition(Map<String, dynamic>)})
factory
WizardFormStep.confirm({required String key, required String prompt, bool? defaultValue, String? description})
factory
WizardFormStep.group({required String key, required String title, required List<WizardFormStep> steps, String? description})
factory
WizardFormStep.multiSelect({required String key, required String prompt, required List<String> options, List<int>? defaultSelected, String? description})
factory
WizardFormStep.password({required String key, required String prompt, String? placeholder, String? defaultValue, WizardValidateFunc? validate, String? description})
factory
WizardFormStep.select({required String key, required String prompt, required List<String> options, int? defaultIndex, String? description})
factory
WizardFormStep.textInput({required String key, required String prompt, String? placeholder, String? defaultValue, WizardValidateFunc? validate, String? description})
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldSkip(Map<String, dynamic> answers) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited