Stable IDs for commands shared by editor hosts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- addCursorAbove → const String
- addCursorBelow → const String
- addNextOccurrence → const String
- capitalizeSelectionOrLine → const String
- capitalizeWord → const String
- cleanupWhitespace → const String
- clearSelection → const String
- cursorDocumentEnd → const String
- cursorDocumentStart → const String
- cursorDown → const String
- cursorLeft → const String
- cursorLineEnd → const String
- cursorLineStart → const String
- cursorPageDown → const String
- cursorPageUp → const String
- cursorRight → const String
- cursorUp → const String
- cursorVisualLineEnd → const String
- cursorVisualLineStart → const String
- cursorWordLeft → const String
- cursorWordRight → const String
- deleteLeft → const String
- deleteLine → const String
- deleteLineLeft → const String
- deleteLineRight → const String
- deleteRight → const String
- deleteWordLeft → const String
- deleteWordRight → const String
- duplicateLine → const String
- foldAll → const String
- goToMatchingBracket → const String
- indentLines → const String
- insertLineBreak → const String
- insertSnippet → const String
- insertText → const String
- joinLines → const String
- lowercaseSelectionOrLine → const String
- lowercaseWord → const String
- moveLineDown → const String
- moveLineUp → const String
- nextDiagnostic → const String
- nextSearchMatch → const String
- nextSnippetPlaceholder → const String
- outdentLines → const String
- previousDiagnostic → const String
- previousSearchMatch → const String
- previousSnippetPlaceholder → const String
- redo → const String
- renumberNumberedList → const String
- selectAll → const String
- selectDocumentEnd → const String
- selectDocumentStart → const String
- selectDown → const String
- selectLeft → const String
- selectLine → const String
- selectLineEnd → const String
- selectLineStart → const String
- selectPageDown → const String
- selectPageUp → const String
- selectRight → const String
- selectUp → const String
- selectVisualLineEnd → const String
- selectVisualLineStart → const String
- selectWordLeft → const String
- selectWordRight → const String
- sortSelectedLines → const String
- splitLine → const String
- toggleChecklist → const String
- toggleFold → const String
- toggleHeading → const String
- toggleLinePrefix → const String
- toggleNumberedList → const String
- transposeCharacters → const String
- undo → const String
- unfoldAll → const String
- unwrapSelection → const String
- uppercaseSelectionOrLine → const String
- uppercaseWord → const String
- wrapSelection → const String