EditorCompletionItem class final
One completion candidate and the edits needed to accept it.
Constructors
- EditorCompletionItem({required String label, required String insertText, EditorCompletionKind kind = EditorCompletionKind.text, String detail = '', String documentation = '', String? filterText, String? sortText, int? replacementStart, int? replacementEnd, WorkspaceEdit additionalEdits = const WorkspaceEdit()})
-
const
Properties
- additionalEdits → WorkspaceEdit
-
Import or cross-file edits applied with the primary insertion.
final
- detail → String
-
final
- documentation → String
-
final
- filterText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insertText → String
-
final
- kind → EditorCompletionKind
-
final
- label → String
-
final
- replacementEnd → int?
-
final
- replacementStart → int?
-
Optional replacement range. Null means insert at the request cursor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortText → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited