EditorCoreConfig class final
Constructors
- EditorCoreConfig({int tabWidth = 4, int tabWidthSingleLine = 1, int scrollMargin = 0, int decorationLayerPriorityDefault = 0, int decorationLayerPrioritySyntax = 50, int decorationLayerPriorityDiagnostics = 75, int decorationLayerPrioritySearch = 100, int decorationLayerPriorityDefaultLine = 0, int decorationLayerPriorityDiagnosticsLine = 75, int decorationLayerPriorityActiveLine = 50, int sourceBackedReplacementTextThreshold = 8192, int extmarkMaxOffset = 1073741824})
-
const
Properties
- decorationLayerPriorityActiveLine → int
-
final
- decorationLayerPriorityDefault → int
-
final
- decorationLayerPriorityDefaultLine → int
-
final
- decorationLayerPriorityDiagnostics → int
-
final
- decorationLayerPriorityDiagnosticsLine → int
-
final
- decorationLayerPrioritySearch → int
-
final
- decorationLayerPrioritySyntax → int
-
final
- extmarkMaxOffset → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollMargin → int
-
final
- sourceBackedReplacementTextThreshold → int
-
final
- tabWidth → int
-
final
- tabWidthSingleLine → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current ↔ EditorCoreConfig
-
getter/setter pair