FlickerEvent class final
One event detected while scanning terminal output.
Constructors
- FlickerEvent({required FlickerEventType type, required FlickerSeverity severity, required String message, required int byteOffset, required int frameId})
-
Creates a flicker-analysis event.
const
Properties
- byteOffset → int
-
Character offset in the analyzed string.
final
- frameId → int
-
Active synchronized-frame id when the event was detected.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable event detail.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → FlickerSeverity
-
Event severity.
final
- type → FlickerEventType
-
Event family.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this event into a serialization-friendly map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited