Box-drawing and marker characters.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- arrowRight → const String
- arrowUp → const String
- cornerBl → const String
- cornerBr → const String
- cornerTl → const String
- cornerTr → const String
- cross → const String
- diamond → const String
- dot → const String
- horizontal → const String
- smallDot → const String
- teeBottom → const String
- teeLeft → const String
- teeRight → const String
- teeTop → const String
- triangleDown → const String
- triangleUp → const String
- vertical → const String