PieChartProps class final
Props for pie / donut charts.
Constructors
-
PieChartProps({String? id, required int width, required int height, String? title, String? titleColor, String? backgroundColor, ChartMargins? margins, LegendOptions? legend, List<
String> ? colors, required List<PieSlice> slices, int? radius, bool? showPercentages, bool? showLabels, bool? donut, int? donutInnerRadius}) -
const
Properties
- backgroundColor → String?
-
final
-
colors
→ List<
String> ? -
final
- donut → bool?
-
final
- donutInnerRadius → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- id → String?
-
final
- legend → LegendOptions?
-
final
- margins → ChartMargins?
-
final
- radius → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabels → bool?
-
final
- showPercentages → bool?
-
final
-
slices
→ List<
PieSlice> -
final
- title → String?
-
final
- titleColor → String?
-
final
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited