RemotePluginFrame class final
- Inheritance
-
- Object
- RemotePluginMessage
- RemotePluginFrame
Constructors
-
RemotePluginFrame({required String surfaceId, required int width, required int height, required List<
RemotePluginFrameCell> cells, RemotePluginCursor? cursor}) -
const
- RemotePluginFrame.fromPayload(JsonObject payload)
-
factory
Properties
-
cells
→ List<
RemotePluginFrameCell> -
final
- cursor → RemotePluginCursor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- messageType → RemotePluginMessageType
-
no setteroverride
- payloadJson → JsonObject
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surfaceId → String
-
final
- width → int
-
final
Methods
-
encodeJson(
) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → JsonObject -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited