Renderer class abstract
Abstract interface for rendering styled output.
Implementations handle writing to different outputs (terminal, string buffer) and provide information about the target's color capabilities.
- Implementers
Constructors
- Renderer()
Properties
- colorProfile ↔ ColorProfile
-
The color profile of the output target.
getter/setter pair
- hasDarkBackground ↔ bool
-
Whether the output target has a dark background.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → Object?
-
Gets the underlying output sink/writer for this renderer, if available.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String text) → void - Writes text to the output without a trailing newline.
-
writeln(
[String text = '']) → void - Writes text to the output followed by a newline.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited