DataTableStyles class
Styles for the interactive data table.
Constructors
Properties
- dimmed → Style
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- noResults → Style
-
final
- prompt → Style
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableCell → Style
-
final
- tableHeader → Style
-
final
- tableSelected → Style
-
final
- title → Style
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited