DiffCommentAnchor class
A commentable position in the rendered diff.
Constructors
- DiffCommentAnchor({required String path, required int line, required DiffCommentSide side, required DiffCommentKind kind, required int renderLine, required String content, int? renderLineEnd})
-
Creates a diff comment anchor.
const
Properties
- content → String
-
Source line content without the diff marker.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → DiffCommentLineKey
-
Stable identity for this anchor.
no setter
- kind → DiffCommentKind
-
Type of source diff line.
final
- label → String
-
Compact label for UI hints.
no setter
- line → int
-
Blob line number on side.
final
- path → String
-
File path for GitHub's review-comment API.
final
- renderLine → int
-
First rendered row occupied by this source line.
final
- renderLineEnd → int
-
First rendered row after this source line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → DiffCommentSide
-
Diff side for line.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited