DiffCommentLineHighlight class
A visual highlight request for a commentable diff line.
Constructors
- DiffCommentLineHighlight({required DiffCommentLineKey key, required DiffCommentLineHighlightKind kind})
-
Creates a diff comment line highlight.
const
- DiffCommentLineHighlight.range(DiffCommentAnchor anchor)
-
Creates a selected-range highlight from
anchor.factory - DiffCommentLineHighlight.selected(DiffCommentAnchor anchor)
-
Creates a selected-line highlight from
anchor.factory - DiffCommentLineHighlight.thread(DiffCommentAnchor anchor)
-
Creates an existing-thread highlight from
anchor.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → DiffCommentLineKey
-
Comment line identity.
final
- kind → DiffCommentLineHighlightKind
-
Highlight role.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited