DiffCommentLineKey class
Stable identity for a commentable line in a pull-request diff.
Constructors
- DiffCommentLineKey({required String path, required int line, required DiffCommentSide side})
-
Creates a stable diff comment line key.
const
- DiffCommentLineKey.fromAnchor(DiffCommentAnchor anchor)
-
Creates a key from a rendered comment anchor.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- line → int
-
Blob line number on side.
final
- path → String
-
File path in the pull request diff.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → DiffCommentSide
-
Diff side for line.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override