MultiSearchKeyMap class
Key bindings for the multi-search component.
- Inheritance
-
- Object
- KeyMap
- SearchKeyMap
- MultiSearchKeyMap
Constructors
- MultiSearchKeyMap({KeyBinding? up, KeyBinding? down, KeyBinding? home, KeyBinding? end, KeyBinding? pageUp, KeyBinding? pageDown, KeyBinding? cancel, KeyBinding? toggle, KeyBinding? toggleAll, KeyBinding? confirm})
Properties
- cancel → KeyBinding
-
Cancel search.
finalinherited
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
- confirm → KeyBinding
-
Confirm multi-selection.
final
- down → KeyBinding
-
Move cursor down.
finalinherited
- end → KeyBinding
-
Jump to last item.
finalinherited
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → KeyBinding
-
Jump to first item.
finalinherited
- pageDown → KeyBinding
-
Page down.
finalinherited
- pageUp → KeyBinding
-
Page up.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select → KeyBinding
-
Confirm selection.
finalinherited
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
- toggle → KeyBinding
-
Toggle current item selection.
final
- toggleAll → KeyBinding
-
Toggle all currently filtered items.
final
- up → KeyBinding
-
Move cursor up.
finalinherited
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited