PaginatorKeyMap class
Key bindings for paginator navigation.
Constructors
- PaginatorKeyMap({KeyBinding? prevPage, KeyBinding? nextPage})
Properties
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPage → KeyBinding
-
Key binding for next page.
final
- prevPage → KeyBinding
-
Key binding for previous page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited