PasswordKeyMap class
Key bindings for the password component.
Constructors
- PasswordKeyMap({KeyBinding? submit, KeyBinding? cancel, KeyBinding? deleteBackward, KeyBinding? deleteForward, KeyBinding? deleteAll, KeyBinding? cursorLeft, KeyBinding? cursorRight, KeyBinding? cursorStart, KeyBinding? cursorEnd})
Properties
- cancel → KeyBinding
-
Cancel input.
final
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
- cursorEnd → KeyBinding
-
Move cursor to end.
final
- cursorLeft → KeyBinding
-
Move cursor left.
final
- cursorRight → KeyBinding
-
Move cursor right.
final
- cursorStart → KeyBinding
-
Move cursor to start.
final
- deleteAll → KeyBinding
-
Delete all characters.
final
- deleteBackward → KeyBinding
-
Delete character before cursor.
final
- deleteForward → KeyBinding
-
Delete character after cursor.
final
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
- submit → KeyBinding
-
Submit the password.
final
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited