SearchKeyMap class
Key bindings for the search component.
- Inheritance
- Implementers
Constructors
- SearchKeyMap({KeyBinding? up, KeyBinding? down, KeyBinding? home, KeyBinding? end, KeyBinding? pageUp, KeyBinding? pageDown, KeyBinding? select, KeyBinding? cancel})
Properties
- cancel → KeyBinding
-
Cancel search.
final
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
- down → KeyBinding
-
Move cursor down.
final
- end → KeyBinding
-
Jump to last item.
final
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → KeyBinding
-
Jump to first item.
final
- pageDown → KeyBinding
-
Page down.
final
- pageUp → KeyBinding
-
Page up.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select → KeyBinding
-
Confirm selection.
final
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
- up → KeyBinding
-
Move cursor up.
final
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited