TableKeyMap class
Key map for table navigation.
Constructors
- TableKeyMap({KeyBinding? lineUp, KeyBinding? lineDown, KeyBinding? pageUp, KeyBinding? pageDown, KeyBinding? halfPageUp, KeyBinding? halfPageDown, KeyBinding? gotoTop, KeyBinding? gotoBottom})
- Creates a table key map with default bindings.
Properties
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- gotoBottom → KeyBinding
-
Move selection to last row.
final
- gotoTop → KeyBinding
-
Move selection to first row.
final
- halfPageDown → KeyBinding
-
Move selection down half a page.
final
- halfPageUp → KeyBinding
-
Move selection up half a page.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineDown → KeyBinding
-
Move selection down one row.
final
- lineUp → KeyBinding
-
Move selection up one row.
final
- pageDown → KeyBinding
-
Move selection down one page.
final
- pageUp → KeyBinding
-
Move selection up one page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited