ViewportKeyMap class
Key bindings for viewport navigation.
Constructors
- ViewportKeyMap({KeyBinding? pageDown, KeyBinding? pageUp, KeyBinding? halfPageUp, KeyBinding? halfPageDown, KeyBinding? down, KeyBinding? up, KeyBinding? left, KeyBinding? right, KeyBinding? copy})
- Creates a key mapping configuration for viewport navigation.
Properties
-
chords
↔ List<
({String id, KeyBinding key, KeyBinding prefix})> ? -
Optional multi-key chord bindings.
getter/setter pairinherited
- copy → KeyBinding
-
Key binding for copying selected text.
final
- down → KeyBinding
-
Key binding for scrolling one line down.
final
-
fullHelp
↔ List<
List< KeyBinding> > -
Bindings for the full help view, grouped by columns.
getter/setter pairinherited
- halfPageDown → KeyBinding
-
Key binding for scrolling half a page down.
final
- halfPageUp → KeyBinding
-
Key binding for scrolling half a page up.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → KeyBinding
-
Key binding for scrolling left.
final
- pageDown → KeyBinding
-
Key binding for scrolling one page down.
final
- pageUp → KeyBinding
-
Key binding for scrolling one page up.
final
- right → KeyBinding
-
Key binding for scrolling right.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortHelp
↔ List<
KeyBinding> -
Bindings for the short help view.
getter/setter pairinherited
- up → KeyBinding
-
Key binding for scrolling one line up.
final
Methods
-
firstMatch(
KeyMsg msg) → KeyBinding? -
Returns the first enabled KeyBinding that matches
msg, ornull.inherited -
handle(
KeyMsg msg) → Cmd? -
Returns the command from the first matching handler, or
null.inherited -
intercept(
KeyMsg msg) → bool -
Returns
trueif a matching binding's KeyBinding.action was called.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited