WizardStepCompletedMsg class
Message sent when a wizard step is completed.
Constructors
- WizardStepCompletedMsg(int stepIndex, dynamic answer)
-
const
Properties
- answer → dynamic
-
The answer provided for this step.
final
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepIndex → int
-
The index of the completed step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited