GlamourBlockContext class
Tracks rendering state for a block-level markdown element.
Context for a nested block rendering context.
Constructors
- GlamourBlockContext({required GlamourBlockStyle style, required int maxWidth})
- Creates a block context with style, width, and buffer.
Properties
- buffer → StringBuffer
-
The string buffer accumulating this block's output.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWidth → int
-
The maximum width available for this block.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GlamourBlockStyle
-
The Style applied to this block.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited