EvidenceEntry class

A single piece of evidence contributing to the match score.

Constructors

EvidenceEntry({required EvidenceKind kind, required double bayesFactor, required String description})
const

Properties

bayesFactor double
Bayes factor: values > 1.0 support relevance, < 1.0 oppose it.
final
description String
Human-readable explanation.
final
hashCode int
The hash code for this object.
no setterinherited
kind EvidenceKind
Type of evidence.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited