RankedItem class
A single item in the ranked results.
Constructors
- RankedItem({required int originalIndex, required MatchResult result, required RankConfidence rankConfidence})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalIndex → int
-
Index into the original (pre-sort) input list.
final
- rankConfidence → RankConfidence
-
Conformal confidence for this rank position.
final
- result → MatchResult
-
The match result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited