BlockQuadrants class
Quadrant block glyphs for sub-pixel rendering (U+2596–U+259F).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- allButLowerLeft → const String
- All but lower-left ▜.
- allButLowerRight → const String
- All but lower-right ▛.
- allButUpperLeft → const String
- All but upper-left ▟.
- allButUpperRight → const String
- All but upper-right ▙.
- leftHalves → const String
- Left halves ▚ — upper-left + lower-right.
- lowerLeft → const String
- Lower-left quadrant ▖.
- lowerRight → const String
- Lower-right quadrant ▗.
- rightHalves → const String
- Right halves ▞ — upper-right + lower-left.
- upperLeft → const String
- Upper-left quadrant ▘.
- upperRight → const String
- Upper-right quadrant ▝.