BlockShades class
Block shade characters (U+2580–U+259F).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dark → const String
- Dark shade ▓ (U+2593).
- full → const String
- Full block █ (U+2588).
- left → const String
- Left half block ▌ (U+258C).
- light → const String
- Light shade ░ (U+2591).
- lower → const String
- Lower half block ▄ (U+2584).
- medium → const String
- Medium shade ▒ (U+2592).
- right → const String
- Right half block ▐ (U+2590).
- upper → const String
- Upper half block ▀ (U+2580).