BoxMetrics class final

Constructors

BoxMetrics({required int contentWidth, required int contentHeight, required Padding padding, required Margin margin, required BorderMetrics border, BoxSizing sizing = BoxSizing.contentBox})
const

Properties

border → BorderMetrics
final
borderBoxHeight int
no setter
borderBoxWidth int
no setter
contentHeight int
final
contentWidth int
final
hashCode int
The hash code for this object.
no setterinherited
innerHeight int
no setter
innerWidth int
no setter
margin Margin
final
outerHeight int
no setter
outerWidth int
no setter
padding Padding
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizing BoxSizing
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited