ScannerCharSet class
Character pair for a scanner (Knight Rider) animation style.
Use with Spinners.scanner or ScannerChars presets.
Constructors
-
ScannerCharSet({required List<
String> active, String inactive = '⬝'}) -
Creates a scanner character set.
const
Properties
-
active
→ List<
String> -
Characters used for active (head/trail) positions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactive → String
-
Character used for inactive (background) positions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited