Sprintln function
Returns concatenated values as a string with trailing newline.
Like Println but returns the string instead of printing.
final s = Sprintln('Hello,', 'world'); // 'Hello, world\n'
Implementation
String Sprintln([
Object? v1,
Object? v2,
Object? v3,
Object? v4,
Object? v5,
Object? v6,
]) => SprintlnAll([v1, v2, v3, v4, v5, v6].where((it) => it != null));