StyledSegment class
A styled segment containing child segments.
- Inheritance
-
- Object
- TagSegment
- StyledSegment
Constructors
-
StyledSegment({required List<
TagSegment> children, String? foreground, String? background, List<String> options = const [], String? href, String? namedStyle}) -
const
Properties
- background → String?
-
final
-
children
→ List<
TagSegment> -
final
- foreground → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
final
- namedStyle → String?
-
final
-
options
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited