AnsiRenderer class
Renders markdown AST nodes to ANSI-styled terminal output.
Implements the NodeVisitor interface from the markdown package to
traverse the AST and produce styled output.
Constructors
- AnsiRenderer({AnsiRendererOptions? options})
- Creates an ANSI renderer with the given options.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → AnsiRendererOptions
-
The rendering options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
List< Node> nodes) → String - Renders a list of markdown nodes to ANSI-styled text.
-
toString(
) → String -
A string representation of this object.
inherited
-
visitElementAfter(
Element element) → void - Called when an Element has been reached, after its children have been visited.
-
visitElementBefore(
Element element) → bool - Called when an Element has been reached, before its children have been visited.
-
visitText(
Text text) → void - Called when a Text node has been reached.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited