withOutputLog abstract method
Returns a new model with the given log replacing outputLog.
This is called by the runtime when a CapturedOutputMsg is
received. Implementations should return a copy of this with
only the outputLog field replaced.
Implementation
Model withOutputLog(OutputLog log);