CellSizeMsg class

Message sent when the terminal reports its cell size in pixels.

This comes from xterm-style CSI 6 ; height ; width t replies when UV input decoding is enabled.

Inheritance

Constructors

CellSizeMsg(int width, int height)
Creates a cell-size message.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
The cell height in pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The cell width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override