CellSizeMsg class
Message sent when the terminal reports its cell size in pixels.
This comes from xterm-style CSI 6 ; height ; width t replies when UV
input decoding is enabled.
Constructors
- CellSizeMsg(int width, int height)
-
Creates a cell-size message.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override