ClipboardSetMsg class

Message emitted after a best-effort clipboard write is attempted.

Inheritance

Constructors

ClipboardSetMsg({required ClipboardSetMethod method, required int textLength})
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
method ClipboardSetMethod
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textLength int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited