requestCellSizeReport static method
Request the terminal to report its cell size in pixels.
Terminals that support xterm window ops respond to CSI 16 t with
CSI 6 ; <height> ; <width> t, which UV decoding maps to CellSizeMsg.
Implementation
static Cmd requestCellSizeReport() => writeRaw('\x1b[16t');