DiffFile class
A file entry in a parsed diff.
Constructors
Properties
- additions → int
-
Number of added lines.
latefinal
- deletions → int
-
Number of removed lines.
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
DiffLine> -
All parsed diff lines for this file.
final
- newPath → String
-
Path of the new file (after changes).
final
- oldPath → String
-
Path of the old file (before changes).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited