FixedViewport class final
A fixed terminal rectangle, using zero-based cell coordinates.
Constructors
- FixedViewport({required int x, required int y, required int width, required int height})
-
Creates a viewport at (
x,y) with the requestedwidthandheight.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Requested height in terminal cells.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Requested width in terminal cells.
final
- x → int
-
Zero-based left column.
final
- y → int
-
Zero-based top row.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited