FocusMsg class

Message sent when focus is gained or lost.

Only available when focus reporting is enabled.

Inheritance

Constructors

FocusMsg(bool focused)
Creates a focus message.
const

Properties

dropWhenInputQueued bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
focused bool
Whether the terminal gained focus (true) or lost focus (false).
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override