ForegroundColorMsg class final
Message containing the terminal's foreground color.
Only emitted when UV input decoding is enabled and the terminal reports a foreground color (OSC 10).
Constructors
- ForegroundColorMsg({required String hex})
-
Creates a foreground color detection message from a hex color string.
const
Properties
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hex → String
-
The foreground color reported by the terminal (hex string).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited