FrameTickModel class abstract
Optional interface for models that want to control frame ticks.
When implemented, the runtime will only start the frame tick timer if wantsFrameTicks is true.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wantsFrameTicks → bool
-
Whether the model wants to receive frame tick messages.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited