GitDiffKeyMap class
Key bindings for the git diff viewer.
Provides a cycleViewMode binding (default: v) to cycle between
DiffViewMode values (unified → sideBySide → pretty → unified…).
- Implemented types
Constructors
- GitDiffKeyMap({KeyBinding? cycleViewMode})
- Creates a git diff key map with optional overrides.
Properties
- cycleViewMode → KeyBinding
-
Key to cycle through view modes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fullHelp(
) → List< List< KeyBinding> > -
Returns bindings for the full help view, grouped by columns.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortHelp(
) → List< KeyBinding> -
Returns bindings for the short help view.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited