HighlightInfo class
Describes a text highlight region within the viewport.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineEnd → int
-
The ending line index of the highlight.
final
-
lines
→ Map<
int, (int, int)> -
The highlighted content lines.
the grapheme highlight ranges for each of these lines
final
- lineStart → int
-
The starting line index of the highlight.
in which line this highlight starts and ends
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
coords(
) → (int, int, int) - Returns the character coordinates of the highlight region.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited