HitTestMouseMsg class
Message dispatched to an element when render-tree hit-testing determines that a MouseMsg landed within its render object's bounds.
This replaces zone-based dispatch for widget apps. The localX and localY fields contain the mouse position in the hit element's local coordinate space.
Constructors
- HitTestMouseMsg({required MouseMsg event, required double localX, required double localY})
-
Creates a mouse message that has passed hit-testing against a render object.
const
Properties
- event → MouseMsg
-
The original mouse event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localX → double
-
X coordinate in the hit element's local coordinate space.
final
- localY → double
-
Y coordinate in the hit element's local coordinate space.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited