HotReloadMixin mixin
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initializeHotReload(
{Duration debounceInterval = const Duration(milliseconds: 500)}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onHotReloadStatus(
HotReloadStatus status, {String? detail}) → void -
performReassemble(
) → Future< void> -
stopHotReload(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited