HotReloadMixin mixin

Integrates the Dart VM hot-reload lifecycle with a running TUI host.

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canInitializeHotReload() → Future<bool>
Whether this process has a VM service that can support hot reload.
initializeHotReload({Duration debounceInterval = const Duration(milliseconds: 500)}) → Future<void>
Starts automatic hot reload once.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHotReloadStatus(HotReloadStatus status, {String? detail}) → void
performReassemble() → Future<void>
stopHotReload() → Future<void>
Stops file watching and closes the VM service connection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited