HotReloadStatus enum
Status of the hot reload system.
These values are emitted as HotReloadStatusMsg messages so the model can optionally display reload feedback in the TUI view.
Values
- initializing → const HotReloadStatus
-
The hot reload watcher is being set up.
- ready → const HotReloadStatus
-
The hot reload watcher is active and monitoring for file changes.
- changeDetected → const HotReloadStatus
-
A file change was detected and a reload is about to start.
- reassembling → const HotReloadStatus
-
The reload succeeded and the application is being reassembled.
- succeeded → const HotReloadStatus
-
The reassembly completed successfully.
- failed → const HotReloadStatus
-
The reload or reassembly failed.
-
The VM service is not available (hot reload cannot work).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HotReloadStatus> - A constant List of the values in this enum, in order of their declaration.