Optional handler invoked when this binding is activated.
Used by activate to produce a Cmd when the binding matches a key. When null, activate returns null even if the key matches.
null
final Cmd? Function()? handler;