KeyChordBinding class final

A declarative chord binding made of a prefix key and a continuation key.

Constructors

KeyChordBinding({required String id, required KeyBinding prefix, required KeyBinding key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier for the chord.
final
key KeyBinding
The continuation key that resolves the chord.
final
prefix KeyBinding
The prefix key that starts the chord.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited