KeyChordCancelledMsg class final

Message emitted when a pending chord is cancelled or times out.

Inheritance

Constructors

KeyChordCancelledMsg({required Key prefix, Key? key, bool timedOut = false})
const

Properties

dropWhenInputQueued → bool
Whether this message can be dropped when fresher user input is queued.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
The key that cancelled the chord, if cancellation came from a key.
final
prefix → Key
The prefix key that started the chord.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timedOut → bool
Whether the cancellation was caused by a timeout.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited