The bytes to write at column. Always begins with a full attribute reset followed by the ANSI state active at that point of the line, so the write is correct regardless of the terminal's current pen.
final String text;