PaneLayout class final
A complete computed layout for all leaf panes and split handles.
Constructors
-
PaneLayout({required Map<
String, PaneRect> panes, required Map<String, SplitHandle> splits}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited