PaneLeaf class final

Inheritance

Constructors

PaneLeaf(String paneId)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
paneId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

minHeight(int paneMinWidth, int paneMinHeight) int
Minimum heights needed for this node.
override
minWidth(int paneMinWidth, int paneMinHeight) int
Minimum widths needed for this node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paneIds() Set<String>
Collects all pane IDs reachable from this node.
override
splitIds() Set<String>
Collects all split IDs reachable from this node.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited