PreparedReplay class final
Prepared replay data including session selection and scenario.
Constructors
- PreparedReplay({required TraceSessionSelection selection, required ReplayScenario scenario, required int actionCount})
-
const
Properties
- actionCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenario → ReplayScenario
-
final
- scenarioPath → String
-
no setter
- selection → TraceSessionSelection
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited