PrimaryDeviceAttributesMsg class
Message sent when the terminal replies with primary device attributes.
Constructors
-
PrimaryDeviceAttributesMsg(List<
int> attrs) -
Creates a primary device attributes message.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override