ProfileHarnessConfig class final
Configuration for profile harness commands.
Constructors
- ProfileHarnessConfig({required ReplayHarnessConfig replay, required String profilerCommand, required String artifactDir, required bool cleanArtifactDir, required int timeoutSeconds, required bool profileRegion, required String regionName, String? error})
-
const
Properties
- artifactDir → String
-
final
- cleanArtifactDir → bool
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profilerCommand → String
-
final
- profileRegion → bool
-
final
- regionName → String
-
final
- replay → ReplayHarnessConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutSeconds → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromArgResults(
ReplayHarnessConfig replay, ArgResults parsed) → ProfileHarnessConfig