cleanupErrors property
Returns any errors that occurred during cleanup.
This is useful for debugging cleanup issues. Cleanup errors are normally swallowed to ensure terminal restoration always completes, but they are collected here for inspection.
Implementation
List<Object> get cleanupErrors => List.unmodifiable(_cleanupErrors);