onHotReloadStatus method
Dispatches a HotReloadStatusMsg through the normal message queue so that the model can react to hot reload state changes.
Implementation
@override
void onHotReloadStatus(HotReloadStatus status, {String? detail}) {
if (_running) {
send(HotReloadStatusMsg(status, detail: detail));
}
}