ProgramInterceptor class abstract

Intercepts program messages and lifecycle events.

Use this to observe/transform queued messages, inject automation events, and collect timing metrics for test harnesses.

Implementers

Constructors

ProgramInterceptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProcessed(Msg msg, Duration elapsed) → void
Called after a message has been processed.
onSend(Msg msg) Msg?
Called for each message before it is queued.
onStart(void send(Msg msg)) → void
Called once after program initialization.
onStop() → void
Called during program cleanup.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited