ProgramMacro class final
Recorded user-input macro that can be replayed later.
Constructors
-
ProgramMacro(List<
ProgramReplayStep> steps) -
Creates a macro from timed replay steps.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
ProgramReplayStep> -
The recorded timed steps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toReplay(
{bool loop = false}) → ProgramReplay - Converts this macro into a ProgramReplay.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited