startupProbes property
Whether to run UV startup probes before and after the first render.
When true, probes always run when the active terminal supports them.
When false, probes are skipped entirely.
When null (default), the runtime only auto-runs startup probes for the
built-in terminal implementations that it knows how to interrogate
safely. Arbitrary injected terminals are skipped unless they opt in.
Inline modes skip auto-probing unless this is explicitly set to true
because cursor-report and emoji-width probes can visibly disturb the
primary screen.
Implementation
final bool? startupProbes;