ProgramRenderCapturePayload class final
Structured export payload for one ProgramRenderCapture state snapshot.
Constructors
- ProgramRenderCapturePayload({required ProgramRenderStats stats, required ProgramRenderCaptureReport report, required ProgramRenderSnapshot? lastSnapshot, required ProgramRenderSnapshotSummary? lastSnapshotSummary})
-
Creates a capture payload.
const
-
ProgramRenderCapturePayload.fromJson(Map<
Object?, Object?> json) -
Rebuilds a capture payload from serialized JSON data.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastSnapshot → ProgramRenderSnapshot?
-
Latest full snapshot, if any.
final
- lastSnapshotSummary → ProgramRenderSnapshotSummary?
-
Latest compact snapshot summary, if any.
final
- report → ProgramRenderCaptureReport
-
Formatted capture report.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stats → ProgramRenderStats
-
Aggregate render statistics.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this payload into a serialization-friendly map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited