ProgramRenderSnapshotSummary class final
Compact summary of the most recent captured render snapshot.
Constructors
-
ProgramRenderSnapshotSummary({required int sequence, required int renderGeneration, required DegradationLevel degradationLevel, required Duration renderDuration, required int? width, required int? height, required List<
String> frameLines, required ProgramRenderChangeSummary changeSummary}) -
Creates a snapshot summary.
const
-
ProgramRenderSnapshotSummary.fromJson(Map<
Object?, Object?> json) -
Rebuilds a snapshot summary from serialized JSON data.
factory
- ProgramRenderSnapshotSummary.fromSnapshot(ProgramRenderSnapshot snapshot, {int maxFrameLines = 3})
-
Builds a summary from a full ProgramRenderSnapshot.
factory
Properties
- changeSummary → ProgramRenderChangeSummary
-
Native change summary for this render.
final
- degradationLevel → DegradationLevel
-
Degradation level used for this render.
final
-
frameLines
→ List<
String> -
Plain-text frame lines selected for summary output.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Terminal height, when known.
final
- renderDuration → Duration
-
Runtime render duration.
final
- renderGeneration → int
-
Monotonic render generation from the runtime.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
Local capture sequence.
final
- width → int?
-
Terminal width, when known.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this summary into a serialization-friendly map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited