ProgramReplay class final
Message replay source for ProgramOptions.replay.
Use ProgramReplay.stream to reuse an existing stream or ProgramReplay.script to define timed steps.
Constructors
-
ProgramReplay.script(List<
ProgramReplayStep> steps, {bool loop = false}) -
ProgramReplay.stream(Stream<
Msg> messages)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toStream(
) → Stream< Msg> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited