RenderBudgetMsg class
Message sent when the runtime changes render-budget degradation state.
This is emitted when budget-aware degradation is enabled and the controller transitions to a different degradation level.
Constructors
- RenderBudgetMsg(RenderBudgetState state)
-
Creates a render-budget message.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RenderBudgetState
-
The current render-budget controller state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited