ReplayCustomEvent class final

Structured custom event embedded in replay actions.

Constructors

ReplayCustomEvent({required String type, Map<String, Object?> fields = const <String, Object?>{}})
const

Properties

fields Map<String, Object?>
Event payload fields.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Event type, usually copied from TuiTrace.event(type: ...).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited