ReplayScenario class final

Replay scenario document.

Constructors

ReplayScenario({required String name, required List<ReplayAction> actions, String description = '', ReplayScreen screen = const ReplayScreen()})
const
ReplayScenario.fromJson(Map<String, dynamic> json, {String fallbackName = 'replay'})
factory

Properties

actions List<ReplayAction>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen ReplayScreen
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String path) Future<void>
toJson() Map<String, Object?>
toProgramReplay({bool loop = false, bool keepOpen = false, double speed = 1.0, ReplayEventHook? eventHook}) ProgramReplay
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(String path) Future<ReplayScenario>