ReplayTraceSummary class final

Summarizes the slowest spans in a trace file.

Constructors

ReplayTraceSummary({required String path, required int spanCount, required int maxDurationUs, required List<ReplayTraceSummarySpan> spans})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDurationUs → int
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spanCount → int
final
spans → List<ReplayTraceSummarySpan>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited