ReplayTraceSummarySpan class final

One timed span in a trace summary.

Constructors

ReplayTraceSummarySpan({required String path, required int lineNumber, required String tag, required String message, required int durationUs})
const

Properties

durationUs → int
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
final
message → String
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited