ResizeCoalescerState class

One decision produced by ResizeCoalescer.next.

Constructors

ResizeCoalescerState({DateTime? lastEventAt, int burstCount = 0, Duration delay = Duration.zero})
Creates coalescer state.
const

Properties

burstCount → int
The current burst count.
final
delay → Duration
The coalescing delay to apply for the current event.
final
hashCode → int
The hash code for this object.
no setterinherited
lastEventAt → DateTime?
The timestamp of the last resize event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited