ResolvedReplay class final
Resolved replay plan ready for inline use in a Program command.
Constructors
- ResolvedReplay({required String path, required String name, required int actionCount, required bool loop, required bool keepOpen, required bool blockInput, required double speed, required ProgramReplay replay, required ProgramInterceptor interceptor, required bool convertOnly, ReplayTraceConversionResult? traceConversion})
-
const
Properties
- actionCount → int
-
final
- blockInput → bool
-
final
- convertOnly → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interceptor → ProgramInterceptor
-
final
- keepOpen → bool
-
final
- loop → bool
-
final
- name → String
-
final
- path → String
-
final
- replay → ProgramReplay
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenarioPath → String
-
no setter
- speed → double
-
final
- traceConversion → ReplayTraceConversionResult?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited