SimpleTuiRenderer class

TuiRenderer that writes output without diffing or clearing (nil renderer mode).

Implemented types

Constructors

SimpleTuiRenderer({required TuiTerminal terminal, TuiRendererOptions options = const TuiRendererOptions()})
Creates a simple renderer targeting the given terminal.

Properties

hashCode int
The hash code for this object.
no setterinherited
metrics RenderMetrics?
Returns render performance metrics, or null if not supported.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal TuiTerminal
The terminal to render to.
final

Methods

clear() → void
Clears the rendered content.
override
dispose() → void
Disposes of renderer resources.
override
flush() Future<void>
Flushes any buffered output.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Object view) → void
Renders the view to the terminal.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited