SuggestKeyMap class
Key bindings for SuggestModel.
- Implemented types
Constructors
- SuggestKeyMap({KeyBinding? moveUp, KeyBinding? moveDown, KeyBinding? moveFirst, KeyBinding? moveLast, KeyBinding? accept, KeyBinding? deleteBackward, KeyBinding? moveCursorLeft, KeyBinding? moveCursorRight, KeyBinding? cancel})
- Creates a key map with default bindings.
Properties
- accept → KeyBinding
-
Accept the current input or highlighted suggestion.
final
- cancel → KeyBinding
-
Cancel the prompt.
final
- deleteBackward → KeyBinding
-
Delete the character before the cursor.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- moveCursorLeft → KeyBinding
-
Move text cursor left (clears dropdown selection).
final
- moveCursorRight → KeyBinding
-
Move text cursor right (clears dropdown selection).
final
- moveDown → KeyBinding
-
Move selection down in the dropdown.
final
- moveFirst → KeyBinding
-
Jump to first suggestion.
final
- moveLast → KeyBinding
-
Jump to last suggestion.
final
- moveUp → KeyBinding
-
Move selection up in the dropdown.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fullHelp(
) → List< List< KeyBinding> > -
Returns bindings for the full help view, grouped by columns.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortHelp(
) → List< KeyBinding> -
Returns bindings for the short help view.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited