TableThemeEffect class
A composable style rule for table cells.
Rules can target all cells, only headers, only body rows, a specific row, or a specific column.
Constructors
-
TableThemeEffect({Style? style, TableThemeSection section = TableThemeSection.all, int? row, int? column, List<
Color> gradient = const [], TableBlendMode blendMode = TableBlendMode.normal, TableThemeGradientAxis gradientAxis = TableThemeGradientAxis.horizontal}) - Creates a new table theme effect.
Properties
- blendMode → TableBlendMode
-
Blend mode used when the gradient is combined with theme colors.
final
- column → int?
-
Target column for this effect.
final
-
gradient
→ List<
Color> -
Optional gradient to generate foreground color for matched cells.
final
- gradientAxis → TableThemeGradientAxis
-
Axis used when sampling the gradient.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- row → int?
-
Target row for this effect (
Table.headerRowallowed).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section → TableThemeSection
-
Target section for this effect.
final
- style → Style?
-
Optional style to apply when this effect matches a cell.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
styleForCell(
{required int row, required int column, required TableThemeSection section, required int rowCount, required int columnCount, required bool hasHeader, required bool hasDarkBackground}) → Style? - Returns a style when the effect applies to the target cell.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited