TerminalNativeCellDelta class
One changed cell between two native frames.
Constructors
- TerminalNativeCellDelta({required int column, TerminalNativeCell? previous, TerminalNativeCell? current})
-
Creates a cell-delta record.
const
Properties
- column → int
-
Zero-based column index.
final
- current → TerminalNativeCell?
-
Current cell snapshot, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previous → TerminalNativeCell?
-
Previously committed cell snapshot, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited