TerminalNativeColor class
Snapshot of a UV color.
Properties
- a → int?
-
Alpha channel for RGB colors.
final
- b → int?
-
Blue channel for RGB colors.
final
- bright → bool?
-
Bright flag for basic ANSI colors.
final
- g → int?
-
Green channel for RGB colors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int?
-
Palette index when present.
final
- kind → String
-
Color representation kind:
basic16,indexed256, orrgb.final - r → int?
-
Red channel for RGB colors.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromUv(
UvColor? color) → TerminalNativeColor? - Converts a UV color to a native snapshot.