TerminalNativeDeltaFrame class
Delta snapshot containing only dirty lines from a native frame.
Constructors
-
TerminalNativeDeltaFrame({required int width, required int height, required List<
TerminalNativeLine> lines}) -
Creates a native delta snapshot.
const
- TerminalNativeDeltaFrame.fromBuffer(Buffer buffer)
-
Captures only dirty lines from a UV
buffer.factory - TerminalNativeDeltaFrame.fromFrame(TerminalNativeFrame frame)
-
Captures only dirty lines from an existing native
frame.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Height of the backing buffer.
final
- isEmpty → bool
-
Whether this delta contains any changed lines.
no setter
-
lines
→ List<
TerminalNativeLine> -
Dirty lines captured from the backing buffer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Width of the backing buffer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited