TerminalNativeSpan class
One grouped semantic span from a native line.
Constructors
- TerminalNativeSpan({required int lineIndex, required int startColumn, required int endColumn, required String text, required TerminalNativeStyle style, required TerminalNativeLink link, required bool hasDrawable})
-
Creates a native span.
const
Properties
- endColumn → int
-
Exclusive end column.
final
- hasDrawable → bool
-
Whether any cell in the span had a drawable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineIndex → int
-
Zero-based line index.
final
- link → TerminalNativeLink
-
Shared hyperlink metadata for the span.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startColumn → int
-
Inclusive start column.
final
- style → TerminalNativeStyle
-
Shared style metadata for the span.
final
- text → String
-
Text content represented by this span.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited