TerminalPaletteSnapshot class final

Immutable snapshot of terminal-reported colors.

Constructors

TerminalPaletteSnapshot({String? foregroundHex, String? backgroundHex, String? cursorHex, required Map<int, String> palette})

Properties

backgroundHex → String?
final
cursorHex → String?
final
foregroundHex → String?
final
hasBackground → bool
no setter
hasCoreColors → bool
no setter
hasCursor → bool
no setter
hasForeground → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isBackgroundDark → bool
no setter
palette → UnmodifiableMapView<int, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? foregroundHex, String? backgroundHex, String? cursorHex, Map<int, String>? palette}) → TerminalPaletteSnapshot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paletteHex(int index) → String?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited