TerminalRenderFrame class
Parsed representation of rendered terminal output.
Constructors
-
TerminalRenderFrame(List<
TerminalRenderLine> lines) -
Creates a parsed render frame.
const
Properties
- content → String
-
The rendered frame reassembled line-by-line.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
TerminalRenderLine> -
ANSI-aware lines in the rendered frame.
final
- plainText → String
-
The ANSI-stripped frame content.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
inspect(
Object view) → TerminalRenderFrame -
Parses a rendered
viewstring or View. -
parse(
String content) → TerminalRenderFrame -
Parses rendered
contentinto an ANSI-aware frame model.