TextDocumentChange class final
Constructors
- TextDocumentChange({required int startOffset, required int oldEndOffset, required int newEndOffset, required TextPosition startPosition, required TextPosition oldEndPosition, required TextPosition newEndPosition})
-
const
Properties
- deletedLength → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- insertedLength → int
-
no setter
- isNoop → bool
-
no setter
- newEndOffset → int
-
final
- newEndPosition → TextPosition
-
final
- oldEndOffset → int
-
final
- oldEndPosition → TextPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startOffset → int
-
final
- startPosition → TextPosition
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited