TextInputStyleState class
Style state for focused and blurred states.
Contains Style configurations for each visual element of a TextInputModel. Separate style states allow different appearances when the input is focused vs. blurred.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeholder ↔ Style
-
Style for placeholder text shown when input is empty.
getter/setter pair
- prompt ↔ Style
-
Style for the prompt prefix.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection ↔ Style
-
Style for selected text.
getter/setter pair
- suggestion ↔ Style
-
Style for autocomplete suggestion text.
getter/setter pair
- text ↔ Style
-
Style for the entered text.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited