TextInputStyleState constructor
TextInputStyleState({})
Creates a style state with optional styles for each element.
All styles default to an empty Style if not provided.
Implementation
TextInputStyleState({
Style? text,
Style? placeholder,
Style? suggestion,
Style? prompt,
Style? selection,
}) : text = text ?? Style(),
placeholder = placeholder ?? Style(),
suggestion = suggestion ?? Style(),
prompt = prompt ?? Style(),
selection =
selection ??
Style().background(AnsiColor(7)).foreground(AnsiColor(0));