TextPasteSession class final
Constructors
- TextPasteSession.fromText(String content)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
no setter
- offset → int
-
final
-
runes
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalRunes → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
takeChunk(
int chunkSize) → TextPasteChunkStep? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited