TextSyntaxSession<State> class
final
Constructors
-
TextSyntaxSession({required TextSyntaxProvider<
State> provider, String? language})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ String?
-
getter/setter pair
-
provider
→ TextSyntaxProvider<
State> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
snapshot
→ TextSyntaxSnapshot<
State> ? -
no setter
Methods
-
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
String text, {String? language, bool force = false, TextDocumentChange? change}) → TextSyntaxSnapshot< State> -
syncDocument(
TextDocument document, {String? language, bool force = false, TextDocumentChange? change}) → TextSyntaxSnapshot< State> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited