TraceEventRecord class final

A structured event decoded from one trace log line.

Constructors

TraceEventRecord({required int timestampUs, required TraceTag tag, required String type, required Map<String, Object?> fields})
const

Properties

fields Map<String, Object?>
Event payload fields excluding protocol metadata.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag TraceTag
Log tag for this event line.
final
timestampUs int
Monotonic timestamp from trace start.
final
type String
Event type string (for example TraceEventType.inputBatch).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited