TraceSpan class final
A timing span for hierarchical tracing.
Created via TuiTrace.begin. Call end to log the elapsed duration. Spans are lightweight and allocation-free when tracing is disabled (returns TraceSpan.noop).
Properties
- elapsedMicroseconds → int
-
The elapsed microseconds since the span was created.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
end(
{String? extra}) → void - Ends the span and logs the elapsed duration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited