TuiEvidence class final
Structured runtime evidence logging for diagnostic replayability.
Logs are opt-in JSONL entries emitted for runtime decisions (for example, render-budget transitions).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- captureFramesEnabled → bool
-
no setter
- enabled → bool
-
no setter
Static Methods
-
clearTestOverrides(
) → void -
close(
) → void -
configureForTest(
{bool? enabled, bool captureFrames = false, String? path, String? runId, String? baseDirectory, DateTime nowProvider()?, bool clear = false}) → void -
logDecision(
{required String decisionType, required String result, required Map< String, Object?> factors, String type = 'runtime.decision'}) → void -
logRenderCapture(
{required ProgramRenderCapture capture, String prefix = 'Render', int maxFrameLines = 3}) → void -
logRenderCapturePayload(
{required ProgramRenderCapturePayload payload}) → void -
logRenderFrame(
{required Object view, int? renderGeneration, String? degradationLevel, int? renderDurationUs, int? width, int? height, List< TerminalNativeSpanDelta> ? nativeSpanDelta}) → void -
tryParseLine(
String line) → TuiEvidenceRecord?