TuiEvidenceRecord class final

A decoded evidence event line.

Constructors

TuiEvidenceRecord({required int version, required String type, required int timestampUs, required String decisionType, required String result, required Map<String, Object?> factors, String? runId})
const

Properties

decisionType String
final
factors Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
result String
final
runId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampUs int
final
type String
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited