TuiTrace class final
Lightweight debug tracer for TUI frame rendering and message dispatch.
Constructors
- TuiTrace()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- captureDispatchEnabled → bool
-
no setter
- captureEnabled → bool
-
no setter
- enabled → bool
-
no setter
Static Methods
-
begin(
String label, {TraceTag tag = TraceTag.general, String? extra}) → TraceSpan -
clearTestOverrides(
) → void -
close(
) → void -
configureForTest(
{bool? enabled, String? path, String? baseDirectory, bool captureEnabled = false, String? tagsRaw, DateTime nowProvider()?, bool clear = false}) → void -
event(
String type, {TraceTag tag = TraceTag.general, Map< String, Object?> fields = const {}}) → void -
isTagEnabled(
TraceTag tag) → bool -
log(
String message, {TraceTag tag = TraceTag.general, Object? extra}) → void -
logTrace(
String line) → void -
parseEventLine(
String line) → TraceEventRecord? -
tryParseEventLine(
String line) → TraceEventRecord?