UvEventMsg class final
Raw Ultraviolet event message (only emitted when UV input decoding is enabled).
This enables feature parity for terminals that send non-key events like OSC/CSI/DCS reports (device attributes, color reports, XTGETTCAP, etc.).
The payload is intentionally typed as Object to avoid hard-coupling the core TUI message module to the UV event types.
Constructors
- UvEventMsg(Object event)
-
Creates a UV event message wrapping a raw terminal event.
const
Properties
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- event → Object
-
The raw terminal event object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited