ViewDegradation class
Opt-in degraded content stages for a View.
Constructors
- ViewDegradation({String? simpleBordersContent, String? noStylingContent, String? essentialContent, String? skeletonContent})
-
Creates degraded view content stages.
const
Properties
- essentialContent → String?
-
The content to use at DegradationLevel.essentialOnly.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- noStylingContent → String?
-
The content to use at DegradationLevel.noStyling.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simpleBordersContent → String?
-
The content to use at DegradationLevel.simpleBorders.
final
- skeletonContent → String?
-
The content to use at DegradationLevel.skeleton.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String fullContent, DegradationLevel level) → String -
Resolves content for
level, falling back toward fuller stages when a more degraded stage is not provided. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited