WindowPixelSizeMsg class
Message sent when the terminal window reports its pixel dimensions.
This comes from xterm-style window operation replies such as CSI 4 ; h ; w t
or the pixel-size half of in-band CSI 48 ; rows ; cols ; height ; width t
reports when UV input decoding is enabled.
Constructors
- WindowPixelSizeMsg(int width, int height)
-
Creates a window pixel-size message.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override