anyInBounds method
Sends a ZoneInBoundsMsg to the model for each zone that contains the mouse position, discarding the results.
Use anyInBoundsAndUpdate if you need the updated model and commands.
Implementation
void anyInBounds(Model model, MouseMsg mouse) {
final zones = findInBounds(mouse);
for (final zone in zones) {
model.update(ZoneInBoundsMsg(zone: zone, event: mouse));
}
}