styleId property
int
get
styleId
The pre-computed style identifier for this cell, used by the renderer for fast style comparison without going through UvStyle.==.
Implementation
int get styleId => _styleId;