CrtTrailFilter class final
CRT-style preset with a short temporal persistence trail.
- Inheritance
-
- Object
- BufferFilter
- CompositeFilter
- CrtTrailFilter
Constructors
Properties
-
filters
→ List<
BufferFilter> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Buffer source, Buffer target, double dt) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited