CursorShape enum

Cursor shape primitives.

Upstream: third_party/ultraviolet/cursor.go.

Inheritance
Available extensions

Values

block → const CursorShape

A block cursor (█).

underline → const CursorShape

An underline cursor (_).

bar → const CursorShape

A bar (I-beam) cursor (|).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode({required bool blink}) int

Available on CursorShape, provided by the CursorShapeEncode extension

Returns the ANSI-encoded cursor shape code.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CursorShape>
A constant List of the values in this enum, in order of their declaration.