Environ class final
An environment snapshot represented as KEY=value strings.
Like the Go implementation, lookups walk backwards so the last entry wins if there are duplicates.
Properties
Methods
-
getenv(
String key) → String -
Returns the value of
key, or''if missing. -
lookupEnv(
String key) → ({bool found, String? value}) -
Looks up
keyand returns(value, found). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited