HalfBlockImageDrawable class final
A Drawable that renders an image using half-block characters.
This is a fallback for terminals that do not support any graphics protocol. It uses the upper and lower half-block characters (▀, ▄) to simulate pixels, effectively doubling the vertical resolution of the terminal.
- Implemented types
Constructors
- HalfBlockImageDrawable(Image image, {int? columns, int? rows})
Properties
Methods
-
bounds(
) → Rectangle -
Returns the bounds required to draw this drawable.
override
-
draw(
Screen screen, Rectangle area) → void -
Draws this drawable into
screenwithinarea.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited