ITerm2ImageDrawable class final
A Drawable that renders an image using the iTerm2 Image Protocol.
This drawable uses the iTerm2 inline image protocol to display high-resolution images in compatible terminals. It supports scaling to a specific number of columns and rows.
- Implemented types
Constructors
- ITerm2ImageDrawable(Image image, {String? name, int? columns, int? rows})
Properties
Methods
-
bounds(
) → Rectangle -
Returns the bounds required to draw this drawable.
override
-
draw(
Screen screen, Rectangle area) → void -
Draws this drawable into
screenwithinarea.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited