KittyGraphicsEvent class final
Kitty graphics payload (APC G ... ST).
Constructors
-
KittyGraphicsEvent({required KittyOptions options, required List<
int> payload}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- options → KittyOptions
-
final
-
payload
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override