deleteSequence method
Returns an escape sequence that deletes this image from the terminal.
Call this when the drawable is no longer needed to free terminal resources.
Implementation
String deleteSequence() => KittyImage.delete(imageId: id, quiet: quiet);