setOwned method

void setOwned(
  1. int x,
  2. Cell? cell
)

Sets the cell at x, taking ownership of cell if provided.

Callers should use this only when they know cell is a freshly created instance that will not be reused elsewhere.

Implementation

void setOwned(int x, Cell? cell) =>
    _setInternal(x, cell, takeOwnership: true);