setOwned method
Sets the cell at x, taking ownership of cell if provided.
Callers should use this only when they know cell is a freshly created
instance that will not be reused elsewhere.
Implementation
void setOwned(int x, Cell? cell) =>
_setInternal(x, cell, takeOwnership: true);