LiquifyFilter class final
A simple velocity-field liquify filter.
This is intentionally lightweight: it displaces cells based on a damped noise field. Use strength to increase distortion.
- Inheritance
-
- Object
- BufferFilter
- LiquifyFilter
Constructors
Properties
Methods
-
apply(
Buffer source, Buffer target, double dt) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited