LiquifyFilter class final

A simple velocity-field liquify filter.

This is intentionally lightweight: it displaces cells based on a damped noise field. Use strength to increase distortion.

Inheritance

Constructors

LiquifyFilter({double strength = 1.0, double damping = 0.9, double noise = 0.35, double flow = 0.8, int? seed})

Properties

damping → double
final
flow → double
final
hashCode → int
The hash code for this object.
no setterinherited
noise → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strength → double
final

Methods

apply(Buffer source, Buffer target, double dt) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited