Mouse class final

Mouse event payload.

Upstream: third_party/ultraviolet/mouse.go (Mouse).

Constructors

Mouse({required int x, required int y, required int button, int mod = 0})
const

Properties

button int
final
hashCode int
The hash code for this object.
no setteroverride
mod int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
final
y int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override