PhosphorTrailFilter class final
Green phosphor preset with a temporal afterimage trail.
This layers GhostingFilter onto the existing phosphor look so moving text or rapidly changing scenes keep a short-lived persistence trail.
- Inheritance
-
- Object
- BufferFilter
- CompositeFilter
- PhosphorTrailFilter
Constructors
- PhosphorTrailFilter({double tint = 0.58, double distortion = 0.08, double persistence = 0.42})
Properties
-
filters
→ List<
BufferFilter> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Buffer source, Buffer target, double dt) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited