metricsOnlyFrame property
When true, the next beginFrame/endFrame cycle is treated as a bookkeeping render (e.g. triggered by the metrics timer) and will not record inter-frame timing or increment the frame count. The flag is automatically reset at the end of endFrame.
Implementation
bool metricsOnlyFrame = false;