ScreenBuffer class final
A screen buffer that implements Screen operations and carries a width
method for calculating cell widths.
Upstream: third_party/ultraviolet/screen + NewScreenBuffer.
Constructors
- ScreenBuffer(int width, int height)
Properties
- buffer → Buffer
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method ↔ WidthMethod
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bounds(
) → Rectangle -
Returns the screen bounds as a Rectangle.
override
-
cellAt(
int x, int y) → Cell? -
Returns the cell at (
x,y) or null if out of bounds.override -
clear(
) → void -
Clears the entire screen to empty cells.
override
-
clearArea(
Rectangle area) → void -
Clears
areaof the screen to empty cells.override -
clone(
) → Buffer -
Returns a copy of the screen's backing buffer.
override
-
cloneArea(
Rectangle area) → Buffer? -
Returns a copy of
areafrom the screen's backing buffer, or null.override -
draw(
Screen screen, Rectangle area) → void -
Draws this drawable into
screenwithinarea.override -
fill(
Cell? cell) → void -
Fills the entire screen with
cell.override -
fillArea(
Cell? cell, Rectangle area) → void -
Fills
areaof the screen withcell.override -
height(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resize(
int width, int height) → void -
setCell(
int x, int y, Cell? cell) → void -
Sets the cell at (
x,y) tocell.override -
toString(
) → String -
A string representation of this object.
inherited
-
width(
) → int -
widthMethod(
) → WidthMethod -
Returns the active grapheme width measurement method.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited