SgrParam class final
Represents a parsed SGR (Select Graphic Rendition) parameter.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSub → bool
-
Whether this parameter has a sub-parameter.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sub
→ List<
int> -
The sub-parameter values, or empty if none.
final
- value → int
-
The main parameter value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited