Side class final
UvBorder primitives.
Upstream: third_party/ultraviolet/border.go.
Constructors
Properties
Methods
-
copyWith(
{String? content, UvStyle? style, Link? link}) → Side - Returns a copy of this side with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited