SizeNotifier class
Stub SizeNotifier for platforms without SIGWINCH.
Constructors
Properties
Methods
-
getSize(
) → (int, int) - Returns the current cell size of the terminal window.
-
getWindowSize(
) → ({({int height, int width}) cells, ({int height, int width}) pixels}) - Returns the current size of the terminal window in cells and pixels.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void - Starts listening for window size changes.
-
stop(
) → Future< void> - Stops the notifier and cleans up resources.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited