TerminalCapabilities class final

Terminal capabilities discovered via ANSI queries.

Constructors

TerminalCapabilities({List<String>? env})
Creates a new terminal capabilities instance.

Properties

backgroundColor ↔ UvRgb?
The terminal background color.
getter/setter pair
cursorColor ↔ UvRgb?
The terminal cursor color.
getter/setter pair
darkColorScheme ↔ bool?
The terminal's reported dark/light scheme preference, if known.
getter/setter pair
foregroundColor ↔ UvRgb?
The terminal foreground color.
getter/setter pair
hasBackgroundColor → bool
Whether the terminal has reported its background color.
no setter
hasColorPalette → bool
Whether the terminal has reported any color palette entries.
no setter
hasCursorColor → bool
Whether the terminal has reported its cursor color.
no setter
hasForegroundColor → bool
Whether the terminal has reported its foreground color.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasITerm2 ↔ bool
Whether the terminal supports iTerm2 Image Protocol.
getter/setter pair
hasKeyboardEnhancements → bool
Whether the terminal supports Kitty Keyboard Protocol enhancements.
no setter
hasKittyGraphics ↔ bool
Whether the terminal supports Kitty Graphics Protocol.
getter/setter pair
hasSixel ↔ bool
Whether the terminal supports Sixel Graphics.
getter/setter pair
keyboardEnhancementFlags ↔ int
Kitty Keyboard Protocol enhancement flags reported by the terminal.
getter/setter pair
modifyOtherKeysMode ↔ int?
The terminal's reported ModifyOtherKeys mode, if known.
getter/setter pair
palette → Map<int, UvRgb>
The terminal color palette.
final
primaryAttributes ↔ List<int>
The primary device attributes reported by the terminal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAttributes ↔ List<int>
The secondary device attributes reported by the terminal.
getter/setter pair
terminalVersion ↔ String?
The terminal version string reported by the terminal.
getter/setter pair
tertiaryAttributes ↔ String?
The tertiary device attributes reported by the terminal.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
updateFromEvent(Event event) → bool
Updates capabilities based on an event.

Operators

operator ==(Object other) → bool
The equality operator.
inherited