TerminalReader class
TerminalReader represents an input event loop that reads input events from a reader and parses them into human-readable events.
Constructors
- TerminalReader(CancelReader _reader, {String term = '', Duration escTimeout = defaultEscTimeout, bool useTerminfo = false, LegacyKeyEncoding? legacy})
Properties
- escTimeout ↔ Duration
-
getter/setter pair
-
events
→ Stream<
Event> -
Returns a stream of events from the terminal.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- term → String
-
final
- useTerminfo → bool
-
final
Methods
-
close(
) → Future< void> - Closes the reader and cleans up resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited