Animatable<T> class
abstract
Transforms a double (typically from an Animation<double>) into a value
of type T.
This is the base class for Tween, CurveTween, and similar interpolation/mapping objects.
Constructors
- Animatable()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
Animation< double> parent) → Animation<T> -
Creates a new Animation by applying this animatable on top of
parent. -
chain(
Animatable< double> parent) → Animatable<T> -
Chains this animatable after
parent. -
evaluate(
Animation< double> animation) → T -
Evaluates this animatable at the current value of
animation. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
double t) → T -
Returns the value of this animatable at the given
t.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited