builder property
Called every time the animation notifies.
The child argument is the same widget passed to this AnimatedBuilder's constructor, allowing you to cache subtrees that do not depend on the animation value.
Implementation
final Widget Function(BuildContext context, Widget? child) builder;