AnimationController constructor
AnimationController({})
Creates an animation controller.
value: initial value. Defaults tolowerBound.duration: the length of this animation when going forward.reverseDuration: the length of this animation when going in reverse. Defaults todurationwhen null.lowerBound/upperBound: the range of values this animation spans.fps: target frame rate for animation ticks. Higher values produce smoother animation at the cost of more TEA messages.id: an identity object used to match AnimationTickMsgs to this controller. Auto-generated if not provided.
Implementation
AnimationController({
double? value,
this.duration,
this.reverseDuration,
this.lowerBound = 0.0,
this.upperBound = 1.0,
this.fps = 30,
Object? id,
}) : _id = id ?? Object() {
_value = value ?? lowerBound;
_status = AnimationStatus.dismissed;
}