time property

DateTime time
final

The wall-clock time when this tick was generated.

Used by AnimationController.processTick to compute the elapsed duration since the animation started, which in turn determines the current animation value.

Implementation

final DateTime time;