AnimationTimelineStep.reverse constructor
AnimationTimelineStep.reverse(})
Runs an AnimationController toward its lower bound.
When the timeline is playing in reverse, this step automatically runs the same controller forward toward its upper bound.
Implementation
factory AnimationTimelineStep.reverse(
AnimationController controller, {
String? label,
double? from,
double? reverseFrom,
Curve curve,
Curve? reverseCurve,
}) = _ControllerReverseStep;