ChartSeries class
A named data series for use in charts that support multiple series.
final series = ChartSeries('Revenue', [10, 20, 30, 25],
style: UvStyle(fg: UvColor.rgb(0, 200, 100)));
Constructors
-
ChartSeries(String label, List<
double> values, {UvStyle? style}) -
Creates a ChartSeries with the given
label,values, and optionalstyle.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
A human-readable label for the series (used in legends).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → UvStyle?
-
Optional rendering style override for this series.
final
-
values
→ List<
double> -
The data values for this series.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited