CommandPaletteMatch class
A scored command palette match with explainable evidence.
Constructors
-
CommandPaletteMatch({required CommandPaletteItem item, required double score, required Map<
String, double> evidence, required int originalIndex}) -
Creates a scored match for
item.const
Properties
-
evidence
→ Map<
String, double> -
Evidence ledger keyed by named feature.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → CommandPaletteItem
-
Matched item.
final
- originalIndex → int
-
Original index in the source list.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
Total score for ranking.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited