ConstantTween<T> class

A tween that always returns the same constant value.

Inheritance

Constructors

ConstantTween(T value)
Creates a constant tween that always evaluates to value.

Properties

begin ↔ T?
The value at the beginning of the animation (t = 0.0).
getter/setter pairinherited
end ↔ T?
The value at the end of the animation (t = 1.0).
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(Animation<double> parent) Animation<T>
Creates a new Animation by applying this animatable on top of parent.
inherited
chain(Animatable<double> parent) Animatable<T>
Chains this animatable after parent.
inherited
evaluate(Animation<double> animation) → T
Evaluates this animatable at the current value of animation.
inherited
lerp(double t) → T
Returns the interpolated value for the given animation parameter t.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(double t) → T
Returns the value of this animatable at the given t.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited