A collection of common animation curves.
These are the standard curves used in material design and general UI
animation. Each curve maps the unit interval 0, 1 to the unit interval.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bounceIn → const Curve
- A bounce-in curve.
- bounceInOut → const Curve
- A bounce-in-out curve.
- bounceOut → const Curve
- A bounce-out curve.
- decelerate → const Curve
- A curve where the rate of change starts out quickly and then decelerates.
- ease → const Curve
- The standard easing curve.
- easeIn → const Curve
- A cubic animation curve that starts slowly and ends quickly.
- easeInBack → const Curve
- An ease-in curve that overshoots then returns.
- easeInCirc → const Curve
- A circular ease-in curve.
- easeInCubic → const Curve
- A cubic ease-in curve.
- easeInExpo → const Curve
- An exponential ease-in curve.
- easeInOut → const Curve
- A cubic animation curve that starts slowly, speeds up, then ends slowly.
- easeInOutBack → const Curve
- An ease-in-out curve that overshoots at both ends.
- easeInOutCirc → const Curve
- A circular ease-in-out curve.
- easeInOutCubic → const Curve
- A cubic ease-in-out curve.
- easeInOutExpo → const Curve
- An exponential ease-in-out curve.
- easeInOutQuad → const Curve
- A quadratic ease-in-out curve.
- easeInOutQuart → const Curve
- A quartic ease-in-out curve.
- easeInOutQuint → const Curve
- A quintic ease-in-out curve.
- easeInOutSine → const Curve
- A sine-based ease-in-out curve.
- easeInQuad → const Curve
- A quadratic ease-in curve.
- easeInQuart → const Curve
- A quartic ease-in curve.
- easeInQuint → const Curve
- A quintic ease-in curve.
- easeInSine → const Curve
- A sine-based ease-in curve.
- easeOut → const Curve
- A cubic animation curve that starts quickly and ends slowly.
- easeOutBack → const Curve
- An ease-out curve that overshoots then returns.
- easeOutCirc → const Curve
- A circular ease-out curve.
- easeOutCubic → const Curve
- A cubic ease-out curve.
- easeOutExpo → const Curve
- An exponential ease-out curve.
- easeOutQuad → const Curve
- A quadratic ease-out curve.
- easeOutQuart → const Curve
- A quartic ease-out curve.
- easeOutQuint → const Curve
- A quintic ease-out curve.
- easeOutSine → const Curve
- A sine-based ease-out curve.
- elasticIn → const Curve
- An elastic-in curve with the default period of 0.4.
- elasticInOut → const Curve
- An elastic-in-out curve with the default period of 0.4.
- elasticOut → const Curve
- An elastic-out curve with the default period of 0.4.
- fastLinearToSlowEaseIn → const Curve
- A curve used by material design for standard transitions.
- fastOutSlowIn → const Curve
- Material Design's standard easing curve.
- linear → const Curve
- A linear animation curve.
- slowMiddle → const Curve
- Material Design's accelerate easing curve.