DataTableCell class final
Structured content for a DataTable.cells table.
Constructors
- DataTableCell(String value, {int columnSpan = 1, TextAlign textAlign = TextAlign.left, Style? style})
-
Creates a table cell.
const
Properties
- columnSpan → int
-
Number of logical columns consumed by this cell.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → Style?
-
Optional style overriding the table's header or body style.
final
- textAlign → TextAlign
-
Horizontal alignment inside the combined cell width.
final
- value → String
-
Cell text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited