DecisionData class
Data for a DecisionCard.
Constructors
-
DecisionData({required DecisionSignal signal, required String actionLabel, DisclosureLevel level = DisclosureLevel.trafficLight, String? explanation, List<
EvidenceTerm> ? evidence, DecisionDetails? details}) -
const
Properties
- actionLabel → String
-
Short label for the chosen action (e.g., "full_redraw").
final
- details → DecisionDetails?
-
Quantitative details (shown at level >= fullDetails).
final
-
evidence
→ List<
EvidenceTerm> ? -
Evidence terms (shown at level >= evidenceTerms).
final
- explanation → String?
-
Plain-English explanation (shown at level >= plainEnglish).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → DisclosureLevel
-
Disclosure level (controls which sections are visible).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signal → DecisionSignal
-
Traffic-light signal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited