DecisionDetails class
Quantitative details for level-3 disclosure.
Constructors
Properties
- confidenceHigh → double
-
Upper bound of confidence interval.
final
- confidenceLow → double
-
Lower bound of confidence interval.
final
- expectedLoss → double
-
Expected loss of the chosen decision.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logPosterior → double
-
Log-posterior probability.
final
- lossAvoided → double?
-
Loss avoided by choosing this over the next-best option.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited