handlePointerDown method
Called when a pointer-down event occurs.
Implementation
@override
void handlePointerDown(MouseMsg event, Offset localPosition) {
super.handlePointerDown(event, localPosition);
if (_waitingForSecondTap) {
// Check if this is within slop of the first tap.
final delta = localPosition - _firstTapPosition!;
if (_magnitude(delta) <= kDoubleTapSlop) {
// This could be the second tap of a double-tap.
// We'll confirm on pointer-up.
} else {
// Too far from first tap — reset and treat as new first tap.
_resetDoubleTap();
_firstTapPosition = localPosition;
}
} else {
_firstTapPosition = localPosition;
}
}