DragUpdateDetails class
Details for a drag update event.
Constructors
- DragUpdateDetails({required Offset globalPosition, required Offset localPosition, required Offset delta})
-
const
Properties
- delta → Offset
-
Change in position since the last drag event.
final
- globalPosition → Offset
-
Current position in global (terminal) coordinates.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localPosition → Offset
-
Current position in local coordinate space.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited