ElasticInOutCurve class
An elastic curve that overshoots and oscillates at both ends.
The period parameter controls the duration of the oscillation.
Constructors
- ElasticInOutCurve([double period = 0.4])
-
Creates an elastic-in-out curve with the given
period.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transform(
double t) → double -
Returns the value of the curve at point
t.inherited -
transformInternal(
double t) → double -
Override this method to define the curve's behavior.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited