hadBuildThisFrame property
bool
get
hadBuildThisFrame
Whether the BuildOwner managing this element had dirty elements during the current frame's build phase.
This is useful for render objects to determine if cached paint output might be stale because a descendant was rebuilt.
Implementation
bool get hadBuildThisFrame => _owner?.hadBuildThisFrame ?? false;