FileImage class
An ImageProvider that loads an image from a file path.
Image(image: FileImage('/path/to/photo.png'))
- Inheritance
-
- Object
- ImageProvider
- FileImage
Properties
- decodeFrame → int?
-
Optional frame index to decode for animated image formats.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- path → String
-
The file system path to the image.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
) → Future< ImageData> -
Resolves and returns the image data.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override