FileImage class

An ImageProvider that loads an image from a file path.

Image(image: FileImage('/path/to/photo.png'))
Inheritance

Constructors

FileImage(String path)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
The file system path to the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Future<ImageData>
Resolves and returns the image data.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited