FlexParentData class
Parent-data used by flex containers for each child render object.
Constructors
- FlexParentData({required int flex, required RenderFlexFit fit})
-
Creates flex parent data.
const
Properties
- fit → RenderFlexFit
-
Fit behavior when a positive flex is provided.
final
- flex → int
-
Flex factor used to divide remaining main-axis space.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited