handleUpdate method
Override this to handle messages specific to this widget.
Children have already received the message before this is called.
@override
(Widget, Cmd?) handleUpdate(Msg msg) {
return switch (msg) {
KeyMsg(key: Key(type: KeyType.enter)) => _submit(),
_ => (this, null),
};
}
Implementation
(Widget, Cmd?) handleUpdate(Msg msg) => (this, null);