GestureRecognizerState enum
The lifecycle state of a gesture recognizer.
Values
- ready → const GestureRecognizerState
-
Ready to accept a new pointer sequence.
- possible → const GestureRecognizerState
-
A pointer sequence is in progress; the recognizer hasn't decided yet.
- accepted → const GestureRecognizerState
-
The recognizer has been accepted and is actively tracking.
- defunct → const GestureRecognizerState
-
The recognizer has finished (accepted or rejected) and needs reset.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GestureRecognizerState> - A constant List of the values in this enum, in order of their declaration.