scrollable property
Whether this viewer should process scrolling input.
When false, keyboard and mouse scroll messages are ignored so the
parent scroll container handles scrolling instead.
Implementation
final bool scrollable;
Whether this viewer should process scrolling input.
When false, keyboard and mouse scroll messages are ignored so the
parent scroll container handles scrolling instead.
final bool scrollable;