Interval class
An interval that starts and/or ends at a fractional point along the curve.
Maps the input t to a sub-range begin..end, then applies curve.
Properties
- begin → double
-
The start of the interval.
final
- curve → Curve
-
The curve to apply within the interval.
final
- end → double
-
The end of the interval.
final
- flipped → Curve
-
Returns a new curve that is the reverse of this one.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transform(
double t) → double -
Returns the value of the curve at point
t.inherited -
transformInternal(
double t) → double -
Override this method to define the curve's behavior.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited