ListTile class
- Inheritance
-
- Object
- Widget
- StatelessWidget
- ListTile
Constructors
- ListTile({required Object title, Object? subtitle, Widget? leading, Widget? trailing, CmdCallback? onTap, bool enabled = true, bool selected = false, bool dense = false, EdgeInsets? padding, Color? background, Color? selectedBackground, Color? foreground, Color? selectedForeground, Style? titleStyle, Style? subtitleStyle, int gap = 1, int minLeadingWidth = 0, Key? key})
- Creates a Material-style list tile.
Properties
- background → Color?
-
Base background color when not selected.
final
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- dense → bool
-
final
- enabled → bool
-
Whether the tile is interactive.
final
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- foreground → Color?
-
Foreground color for title/content when not selected.
final
- gap → int
-
Horizontal gap between leading/content/trailing.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- leading → Widget?
-
final
- minLeadingWidth → int
-
Reserved width for the leading slot.
final
- onTap → CmdCallback?
-
Called when the tile is tapped.
final
- padding → EdgeInsets?
-
Padding inside the tile.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- selectedBackground → Color?
-
Background color when selected is true.
final
- selectedForeground → Color?
-
Foreground color for title/content when selected is true.
final
- subtitle → Object?
-
Secondary content below title.
final
- subtitleStyle → Style?
-
Optional subtitle text style override.
final
- theme → Theme
-
Access the current theme.
no setterinherited
- title → Object
-
Primary content.
final
- titleStyle → Style?
-
Optional title text style override.
final
- trailing → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the UI represented by this widget.
override
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
view(
) → Object -
Renders the widget to a string or View.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited