options property
Optional rendering options for the ANSI renderer.
If null, default options are used with the width set to maxWidth and dark background detection from the current theme.
Implementation
final AnsiRendererOptions? options;
Optional rendering options for the ANSI renderer.
If null, default options are used with the width set to maxWidth and dark background detection from the current theme.
final AnsiRendererOptions? options;