OpenCodeThemes class
All 33 OpenCode themes, ported from the official JSON definitions.
Each factory method returns a Theme with AdaptiveColor values that automatically adjust for light/dark terminal backgrounds.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
aura(
) → Theme - aura theme.
-
ayu(
) → Theme - ayu theme.
-
byName(
String name) → Theme - Get a theme by name (case-insensitive).
-
carbonfox(
) → Theme - carbonfox theme.
-
catppuccin(
) → Theme - catppuccin theme.
-
catppuccinFrappe(
) → Theme - catppuccinFrappe theme.
-
catppuccinMacchiato(
) → Theme - catppuccinMacchiato theme.
-
cobalt2(
) → Theme - cobalt2 theme.
-
cursor(
) → Theme - cursor theme.
-
dracula(
) → Theme - dracula theme.
-
everforest(
) → Theme - everforest theme.
-
flexoki(
) → Theme - flexoki theme.
-
github(
) → Theme - github theme.
-
gruvbox(
) → Theme - gruvbox theme.
-
kanagawa(
) → Theme - kanagawa theme.
-
lucentOrng(
) → Theme - lucentOrng theme.
-
material(
) → Theme - material theme.
-
matrix(
) → Theme - matrix theme.
-
mercury(
) → Theme - mercury theme.
-
monokai(
) → Theme - monokai theme.
-
nightowl(
) → Theme - nightowl theme.
-
nord(
) → Theme - nord theme.
-
oneDark(
) → Theme - oneDark theme.
-
opencode(
) → Theme - opencode theme.
-
orng(
) → Theme - orng theme.
-
osakaJade(
) → Theme - osakaJade theme.
-
palenight(
) → Theme - palenight theme.
-
rosepine(
) → Theme - rosepine theme.
-
solarized(
) → Theme - solarized theme.
-
synthwave84(
) → Theme - synthwave84 theme.
-
tokyonight(
) → Theme - tokyonight theme.
-
vercel(
) → Theme - vercel theme.
-
vesper(
) → Theme - vesper theme.
-
zenburn(
) → Theme - zenburn theme.