OverflowBox class
A widget that imposes different constraints on its child than it gets from its parent, possibly allowing the child to overflow the parent.
This is useful when you want the child to be laid out as if it had more (or less) space than the parent provides. The OverflowBox itself reports its own size based on the parent constraints, but the child may be larger or smaller.
OverflowBox(
minWidth: 0,
maxWidth: 100,
child: Text('This text can be up to 100 columns wide'),
)
- Inheritance
-
- Object
- Widget
- RenderObjectWidget
- SingleChildRenderObjectWidget
- OverflowBox
Constructors
Properties
- alignment → Alignment
-
How to align the child within this widget's bounds.
final
- child → Widget?
-
finalinherited
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- maxHeight → double?
-
The maximum height constraint to impose on the child.
If null, the parent's max height constraint is used.
final
- maxWidth → double?
-
The maximum width constraint to impose on the child.
If null, the parent's max width constraint is used.
final
- minHeight → double?
-
The minimum height constraint to impose on the child.
If null, the parent's min height constraint is used.
final
- minWidth → double?
-
The minimum width constraint to impose on the child.
If null, the parent's min width constraint is used.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → Theme
-
Access the current theme.
no setterinherited
Methods
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
createRenderObject(
) → RenderObject -
override
-
didUnmountRenderObject(
RenderObject renderObject) → void -
inherited
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
updateRenderObject(
RenderObject renderObject) → void -
override
-
view(
) → Object -
Renders the widget to a string or View.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited