RangeSlider class
Flutter-style range slider for selecting a start/end interval.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- RangeSlider
Constructors
-
RangeSlider({required RangeValues values, ValueCmdCallback<
RangeValues> ? onChanged, double min = 0.0, double max = 1.0, int? divisions, int width = 28, bool enabled = true, Color? activeColor, Color? inactiveColor, Color? thumbColor, String rangeTrackChar = '=', String inactiveTrackChar = '-', String thumbChar = 'o', String? label, bool autofocus = false, String? focusId, FocusController? focusController, Key? key})
Properties
- activeColor → Color?
-
final
- autofocus → bool
-
final
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- divisions → int?
-
final
- enabled → bool
-
final
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- focusController → FocusController?
-
final
- focusId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- inactiveColor → Color?
-
final
- inactiveTrackChar → String
-
final
- key → Key?
-
Key for preserving widget identity.
finalinherited
- label → String?
-
final
- max → double
-
final
- min → double
-
final
-
onChanged
→ ValueCmdCallback<
RangeValues> ? -
final
- rangeTrackChar → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → Theme
-
Access the current theme.
no setterinherited
- thumbChar → String
-
final
- thumbColor → Color?
-
final
- values → RangeValues
-
final
- width → int
-
final
Methods
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable State associated with this widget.
override
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
view(
) → Object -
Renders the widget to a string or View.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited