ReloadSignal class final
One reload signal emitted by ReloadController.
Constructors
- ReloadSignal.reload(int revision)
-
Creates a rebuild-preserving reload signal.
const
- ReloadSignal.restart(int revision)
-
Creates a full restart signal.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → ReloadMode
-
Requested reload behavior.
final
- revision → int
-
Monotonic revision counter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited