RenderMetricsInjection class
A portable render-metrics update payload.
Use this to inject runtime metrics and/or custom key-value lines that should appear in debug overlays.
Constructors
-
RenderMetricsInjection({RenderMetrics? metrics, Map<
String, String> upsertEntries = const <String, String>{}, Set<String> removeKeys = const <String>{}, bool clearEntries = false}) -
const
Properties
- clearEntries → bool
-
Whether to clear all custom entries before applying updates.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Returns
truewhen this update carries no changes.no setter - metrics → RenderMetrics?
-
Optional runtime metrics snapshot to publish.
final
-
removeKeys
→ Set<
String> -
Custom entry keys to remove.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
upsertEntries
→ Map<
String, String> -
Custom entries to add/update in overlays.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited