invalidateChildPaintCache method
void
invalidateChildPaintCache()
Marks the cached child paint output as stale so it will be recomputed on the next paint call.
Implementation
void invalidateChildPaintCache() {
_cachedChildPaintLines = null;
}