ReverseTween<T> class
A tween that evaluates another tween in reverse.
The value at t=0.0 is parent.end and the value at t=1.0 is
parent.begin.
- Inheritance
-
- Object
- Animatable<
T> - Tween<
T> - ReverseTween
Constructors
-
ReverseTween(Tween<
T> parent) - Creates a reverse tween.
Properties
- begin ↔ T?
-
The value at the beginning of the animation (t = 0.0).
getter/setter pairinherited
- end ↔ T?
-
The value at the end of the animation (t = 1.0).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parent
→ Tween<
T> -
The tween being reversed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
Animation< double> parent) → Animation<T> -
Creates a new Animation by applying this animatable on top of
parent.inherited -
chain(
Animatable< double> parent) → Animatable<T> -
Chains this animatable after
parent.inherited -
evaluate(
Animation< double> animation) → T -
Evaluates this animatable at the current value of
animation.inherited -
lerp(
double t) → T -
Returns the interpolated value for the given animation parameter
t.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
double t) → T -
Returns the value of this animatable at the given
t.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited