RibbonChart class
A stacked area (ribbon) chart widget for visualising multiple data series.
Each series is rendered as a stacked band within the width×height area. When normalizeTotals is true each column fills 100% of the chart height.
RibbonChart(
series: [
[10, 20, 30, 25],
[15, 10, 20, 30],
],
width: 60,
height: 12,
seriesStyles: [
UvStyle(fg: UvColor.rgb(80, 180, 255)),
UvStyle(fg: UvColor.rgb(255, 120, 80)),
],
)
- Inheritance
-
- Object
- Widget
- RenderObjectWidget
- LeafRenderObjectWidget
- RibbonChart
Constructors
-
RibbonChart({required List<
List< series, int? width, int? height, List<double> >UvStyle> ? seriesStyles, bool normalizeTotals = true, String fillChar = '█', bool showGrid = false, int gridRows = 3, int gridCols = 0, UvStyle? gridStyle, List<ChartLegendEntry> ? legendEntries, int legendColumns = 1, int legendRowGap = 0, ChartLegendPosition legendPosition = ChartLegendPosition.topRight, int legendPadding = 1, int? crosshairX, int? crosshairY, UvStyle? crosshairStyle, Key? key}) - Creates a RibbonChart with the given series data and display options.
Properties
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- crosshairStyle → UvStyle?
-
Style for the crosshair lines.
final
- crosshairX → int?
-
X coordinate for crosshair overlay, or null to hide.
final
- crosshairY → int?
-
Y coordinate for crosshair overlay, or null to hide.
final
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- fillChar → String
-
Character used to fill stacked bands.
final
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- gridCols → int
-
Number of vertical grid lines.
final
- gridRows → int
-
Number of horizontal grid lines.
final
- gridStyle → UvStyle?
-
Style for grid lines.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
The chart height in terminal rows, or null to fill available space.
final
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- legendColumns → int
-
Number of legend columns.
final
-
legendEntries
→ List<
ChartLegendEntry> ? -
Optional legend entries rendered inside chart bounds.
final
- legendPadding → int
-
Inner padding from chart edges to legend area.
final
- legendPosition → ChartLegendPosition
-
Legend placement within chart bounds.
final
- legendRowGap → int
-
Empty rows inserted between legend rows.
final
- normalizeTotals → bool
-
Whether each column is normalised to fill the full height.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
List< double> > -
The list of data series (each is a list of values).
final
-
seriesStyles
→ List<
UvStyle> ? -
Per-series styles. If null, default empty styles are used.
final
- showGrid → bool
-
Whether to draw background grid lines.
final
- theme → Theme
-
Access the current theme.
no setterinherited
- width → int?
-
The chart width in terminal columns, or null to fill available space.
final
Methods
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
createRenderObject(
) → RenderObject -
override
-
didUnmountRenderObject(
RenderObject renderObject) → void -
inherited
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
updateRenderObject(
RenderObject renderObject) → void -
override
-
view(
) → Object -
Renders the widget to a string or View.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited