RibbonChart constructor
RibbonChart({
- required List<
List< series,double> > - int? width,
- int? height,
- List<
UvStyle> ? seriesStyles, - bool normalizeTotals = true,
- String fillChar = '█',
- bool showGrid = false,
- int gridRows = 3,
- int gridCols = 0,
- UvStyle? gridStyle,
- List<
ChartLegendEntry> ? legendEntries, - int legendColumns = 1,
- int legendRowGap = 0,
- ChartLegendPosition legendPosition = ChartLegendPosition.topRight,
- int legendPadding = 1,
- int? crosshairX,
- int? crosshairY,
- UvStyle? crosshairStyle,
- Key? key,
Creates a RibbonChart with the given series data and display options.
When width or height is null the chart fills the available
constraint space (responsive mode).
Set crosshairX and crosshairY to draw a crosshair overlay at
that position (e.g. from mouse hover).
Implementation
RibbonChart({
required this.series,
this.width,
this.height,
this.seriesStyles,
this.normalizeTotals = true,
this.fillChar = '█',
this.showGrid = false,
this.gridRows = 3,
this.gridCols = 0,
this.gridStyle,
this.legendEntries,
this.legendColumns = 1,
this.legendRowGap = 0,
this.legendPosition = ChartLegendPosition.topRight,
this.legendPadding = 1,
this.crosshairX,
this.crosshairY,
this.crosshairStyle,
super.key,
});