RouteFactory typedef
RouteFactory =
Route? Function(RouteSettings settings)
A factory function that creates a route from settings.
Returns null if the factory cannot create a route for the given settings.
Implementation
typedef RouteFactory = Route<dynamic>? Function(RouteSettings settings);