RouteSettings class

Immutable route metadata.

Describes a route configuration with an optional name for named routing and optional arguments for passing data between routes.

final settings = RouteSettings(name: '/details', arguments: {'id': 42});

Constructors

RouteSettings({String? name, Object? arguments})
Creates route settings with the given name and arguments.
const

Properties

arguments Object?
Arbitrary arguments passed to the route.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the route (e.g., '/settings').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, Object? arguments}) RouteSettings
Creates a copy of these settings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited