ScrollController class abstract
Scroll controller interface for scrollable widgets.
Constructors
Properties
- contentExtent → int
-
Total content extent in rows.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxOffset → int
-
Maximum scroll offset.
no setter
- offset → int
-
Current scroll offset in rows.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPercent → double
-
Scroll percentage in the range
0, 1.no setter - viewportExtent → int
-
Visible viewport extent in rows.
no setter
Methods
-
addListener(
void listener()) → void - Adds a listener that fires when the scroll offset changes.
-
jumpTo(
int offset) → bool - Jumps to an absolute offset. Returns true if the offset changed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
void listener()) → void - Removes a previously added listener.
-
scrollBy(
int delta) → bool - Scrolls by a delta. Returns true if the offset changed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited