remoteSlot property
Slot name used to match remote entries.
When omitted and slot is a String, the same string value is used. For non-string local slot keys, provide this explicitly if the region should also include remote surfaces.
Implementation
final String? remoteSlot;