StandardFont class
Standard ASCII art font - 5 lines high, clean block style.
Constructors
- StandardFont()
-
const
Properties
-
glyphs
→ Map<
String, AsciiGlyph> -
Map of characters to their ASCII art representations.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The height in lines of glyphs in this font.
no setteroverride
- letterSpacing → int
-
The spacing between letters in characters.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getGlyph(
String char) → AsciiGlyph -
Get the glyph for a character, or a fallback if not found.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited