State<T extends StatefulWidget> class
abstract
Mutable state for a StatefulWidget.
Constructors
- State()
Properties
- context ↔ BuildContext
-
The build context for this state.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this state is currently mounted in the element tree.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ T
-
The current configuration for this state.
getter/setter pair
Methods
-
build(
BuildContext context) → Widget - Builds the widget subtree for this state.
-
didUpdateWidget(
covariant T oldWidget) → Cmd? - Called when the widget configuration changes.
-
dispose(
) → void - Called when this state is permanently removed from the tree.
-
handleInit(
) → Cmd? - Called once when the widget tree is first mounted.
-
handleIntercept(
Msg msg) → Cmd? - Called before children during message dispatch.
-
handleUpdate(
Msg msg) → Cmd? - Called after children during message dispatch.
-
initState(
) → void - Called when the state is inserted into the tree.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
void fn()) → void - Notifies the framework that this state's internal data has changed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited