TapDownDetails class

Details for a tap-down event.

Constructors

TapDownDetails({required Offset globalPosition, required Offset localPosition, MouseButton button = MouseButton.left, bool ctrl = false, bool alt = false, bool shift = false})
const

Properties

alt bool
Whether the Alt modifier was held.
final
button MouseButton
Which mouse button was pressed.
final
ctrl bool
Whether the Ctrl modifier was held.
final
globalPosition Offset
Position in global (terminal) coordinates.
final
hashCode int
The hash code for this object.
no setterinherited
hasModifier bool
Whether any modifier key is held.
no setter
localPosition Offset
Position in the gesture detector's local coordinate space.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift bool
Whether the Shift modifier was held.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited