cleanupWhitespace method
Cleans up trailing horizontal whitespace in the selected block, or the entire buffer when there is no selection.
Implementation
bool cleanupWhitespace({bool trimTrailingBlankLines = true}) {
final changed = _model.cleanupWhitespace(
trimTrailingBlankLines: trimTrailingBlankLines,
);
if (changed) {
notifyListeners();
}
return changed;
}