TextEditingValue class
The current state of a text field.
Constructors
- TextEditingValue({String text = '', TextSelection selection = const TextSelection.collapsed(offset: 0)})
-
Creates a text editing value.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → TextSelection
-
Current selection range.
final
- text → String
-
Current plain-text value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- empty → const TextEditingValue
- Empty value with collapsed selection at offset 0.