Threshold class
A curve that jumps from 0.0 to 1.0 when t passes threshold.
Properties
- flipped → Curve
-
Returns a new curve that is the reverse of this one.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold → double
-
The value at which the curve jumps to 1.0.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
double t) → double -
Returns the value of the curve at point
t.inherited -
transformInternal(
double t) → double -
Override this method to define the curve's behavior.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited