TimelineDelayMsg class
Message emitted by AnimationTimeline delay steps.
Constructors
- TimelineDelayMsg(Object timelineId, Object token, DateTime time)
-
const
Properties
- dropWhenInputQueued → bool
-
Whether this message can be dropped when fresher user input is queued.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → DateTime
-
The wall-clock time when the delay completed.
final
- timelineId → Object
-
Identifies which timeline scheduled this delay tick.
final
- token → Object
-
Identifies the specific pending delay within the timeline.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited