TweenSequenceItem<T> class
A single entry in a TweenSequence.
Associates a tween with a weight that determines how much of the total animation duration this segment occupies.
Constructors
-
TweenSequenceItem({required Animatable<
T> tween, required double weight}) -
Creates a tween sequence item.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tween
→ Animatable<
T> -
The tween used to produce values for this segment.
final
- weight → double
-
The relative weight of this segment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited