builder property
Called every time the valueListenable notifies.
The value is the current value of the valueListenable.
The child argument is the same widget passed to this
ValueListenableBuilder's constructor.
Implementation
final Widget Function(BuildContext context, T value, Widget? child) builder;