backgroundColorBuilder property
Optional callback to resolve terminal background color at render time.
This is useful when the app theme can change dynamically (for example via an in-app theme picker). If provided, this value takes precedence over backgroundColor and is applied to the returned View each frame.
Implementation
final Color? Function()? backgroundColorBuilder;