WidgetDegradationPriority enum
Priority values used by the render-budget engine when deciding which widgets to retain during a degraded frame.
Values
- essential → const WidgetDegradationPriority
-
Rendered at all degradation levels.
- standard → const WidgetDegradationPriority
-
Rendered while most styling and detail remains available.
- low → const WidgetDegradationPriority
-
Rendered for full, simple-border, and no-style frames.
- decorative → const WidgetDegradationPriority
-
Rendered only on full-fidelity frames.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WidgetDegradationPriority> - A constant List of the values in this enum, in order of their declaration.