WidgetDegradationSignal class
Signal controlling widget visibility under degradation.
Constructors
- WidgetDegradationSignal({WidgetDegradationPriority priority = WidgetDegradationPriority.essential, bool focusBoost = false, bool stale = false})
-
Creates a render signal for a widget.
const
Properties
- focusBoost → bool
-
Whether focused subtrees should be treated as more important.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → WidgetDegradationPriority
-
Relative render priority of this widget.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stale → bool
-
Whether this widget should be considered lower fidelity and dropped earlier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited